/****************************************************************************
** Meta object code from reading C++ file 'torrentscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/webui/api/torrentscontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'torrentscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18TorrentsControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto TorrentsController::qt_create_metaobjectdata<qt_meta_tag_ZN18TorrentsControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TorrentsController",
        "countAction",
        "",
        "infoAction",
        "propertiesAction",
        "trackersAction",
        "webseedsAction",
        "addWebSeedsAction",
        "editWebSeedAction",
        "removeWebSeedsAction",
        "filesAction",
        "pieceHashesAction",
        "pieceStatesAction",
        "pieceAvailabilityAction",
        "startAction",
        "stopAction",
        "recheckAction",
        "reannounceAction",
        "renameAction",
        "setCommentAction",
        "setCategoryAction",
        "createCategoryAction",
        "editCategoryAction",
        "removeCategoriesAction",
        "categoriesAction",
        "addTagsAction",
        "setTagsAction",
        "removeTagsAction",
        "createTagsAction",
        "deleteTagsAction",
        "tagsAction",
        "addAction",
        "deleteAction",
        "addTrackersAction",
        "editTrackerAction",
        "removeTrackersAction",
        "addPeersAction",
        "filePrioAction",
        "uploadLimitAction",
        "downloadLimitAction",
        "setUploadLimitAction",
        "setDownloadLimitAction",
        "setShareLimitsAction",
        "increasePrioAction",
        "decreasePrioAction",
        "topPrioAction",
        "bottomPrioAction",
        "setLocationAction",
        "setSavePathAction",
        "setDownloadPathAction",
        "setAutoManagementAction",
        "setSuperSeedingAction",
        "setForceStartAction",
        "toggleSequentialDownloadAction",
        "toggleFirstLastPiecePrioAction",
        "renameFileAction",
        "renameFolderAction",
        "exportAction",
        "SSLParametersAction",
        "setSSLParametersAction",
        "fetchMetadataAction",
        "parseMetadataAction",
        "saveMetadataAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'countAction'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'infoAction'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'propertiesAction'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'trackersAction'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'webseedsAction'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addWebSeedsAction'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editWebSeedAction'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeWebSeedsAction'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'filesAction'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pieceHashesAction'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pieceStatesAction'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pieceAvailabilityAction'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startAction'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopAction'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recheckAction'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reannounceAction'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameAction'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCommentAction'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCategoryAction'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createCategoryAction'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editCategoryAction'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeCategoriesAction'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'categoriesAction'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addTagsAction'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setTagsAction'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeTagsAction'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createTagsAction'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteTagsAction'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tagsAction'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addAction'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteAction'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addTrackersAction'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editTrackerAction'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeTrackersAction'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPeersAction'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'filePrioAction'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'uploadLimitAction'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadLimitAction'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setUploadLimitAction'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setDownloadLimitAction'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setShareLimitsAction'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'increasePrioAction'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'decreasePrioAction'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'topPrioAction'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bottomPrioAction'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLocationAction'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSavePathAction'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setDownloadPathAction'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAutoManagementAction'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSuperSeedingAction'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setForceStartAction'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSequentialDownloadAction'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFirstLastPiecePrioAction'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameFileAction'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameFolderAction'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportAction'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SSLParametersAction'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSSLParametersAction'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fetchMetadataAction'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'parseMetadataAction'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveMetadataAction'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TorrentsController, qt_meta_tag_ZN18TorrentsControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TorrentsController::staticMetaObject = { {
    QMetaObject::SuperData::link<APIController::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TorrentsControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TorrentsControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TorrentsControllerE_t>.metaTypes,
    nullptr
} };

void TorrentsController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TorrentsController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countAction(); break;
        case 1: _t->infoAction(); break;
        case 2: _t->propertiesAction(); break;
        case 3: _t->trackersAction(); break;
        case 4: _t->webseedsAction(); break;
        case 5: _t->addWebSeedsAction(); break;
        case 6: _t->editWebSeedAction(); break;
        case 7: _t->removeWebSeedsAction(); break;
        case 8: _t->filesAction(); break;
        case 9: _t->pieceHashesAction(); break;
        case 10: _t->pieceStatesAction(); break;
        case 11: _t->pieceAvailabilityAction(); break;
        case 12: _t->startAction(); break;
        case 13: _t->stopAction(); break;
        case 14: _t->recheckAction(); break;
        case 15: _t->reannounceAction(); break;
        case 16: _t->renameAction(); break;
        case 17: _t->setCommentAction(); break;
        case 18: _t->setCategoryAction(); break;
        case 19: _t->createCategoryAction(); break;
        case 20: _t->editCategoryAction(); break;
        case 21: _t->removeCategoriesAction(); break;
        case 22: _t->categoriesAction(); break;
        case 23: _t->addTagsAction(); break;
        case 24: _t->setTagsAction(); break;
        case 25: _t->removeTagsAction(); break;
        case 26: _t->createTagsAction(); break;
        case 27: _t->deleteTagsAction(); break;
        case 28: _t->tagsAction(); break;
        case 29: _t->addAction(); break;
        case 30: _t->deleteAction(); break;
        case 31: _t->addTrackersAction(); break;
        case 32: _t->editTrackerAction(); break;
        case 33: _t->removeTrackersAction(); break;
        case 34: _t->addPeersAction(); break;
        case 35: _t->filePrioAction(); break;
        case 36: _t->uploadLimitAction(); break;
        case 37: _t->downloadLimitAction(); break;
        case 38: _t->setUploadLimitAction(); break;
        case 39: _t->setDownloadLimitAction(); break;
        case 40: _t->setShareLimitsAction(); break;
        case 41: _t->increasePrioAction(); break;
        case 42: _t->decreasePrioAction(); break;
        case 43: _t->topPrioAction(); break;
        case 44: _t->bottomPrioAction(); break;
        case 45: _t->setLocationAction(); break;
        case 46: _t->setSavePathAction(); break;
        case 47: _t->setDownloadPathAction(); break;
        case 48: _t->setAutoManagementAction(); break;
        case 49: _t->setSuperSeedingAction(); break;
        case 50: _t->setForceStartAction(); break;
        case 51: _t->toggleSequentialDownloadAction(); break;
        case 52: _t->toggleFirstLastPiecePrioAction(); break;
        case 53: _t->renameFileAction(); break;
        case 54: _t->renameFolderAction(); break;
        case 55: _t->exportAction(); break;
        case 56: _t->SSLParametersAction(); break;
        case 57: _t->setSSLParametersAction(); break;
        case 58: _t->fetchMetadataAction(); break;
        case 59: _t->parseMetadataAction(); break;
        case 60: _t->saveMetadataAction(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *TorrentsController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TorrentsController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TorrentsControllerE_t>.strings))
        return static_cast<void*>(this);
    return APIController::qt_metacast(_clname);
}

int TorrentsController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = APIController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 61;
    }
    return _id;
}
QT_WARNING_POP
