/****************************************************************************
** Meta object code from reading C++ file 'rss_feed.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/base/rss/rss_feed.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rss_feed.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3RSS4FeedE_t {};
} // unnamed namespace

template <> constexpr inline auto RSS::Feed::qt_create_metaobjectdata<qt_meta_tag_ZN3RSS4FeedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RSS::Feed",
        "iconLoaded",
        "",
        "Feed*",
        "feed",
        "titleChanged",
        "stateChanged",
        "urlChanged",
        "oldURL",
        "refreshIntervalChanged",
        "std::chrono::seconds",
        "oldRefreshInterval",
        "handleSessionProcessingEnabledChanged",
        "enabled",
        "handleMaxArticlesPerFeedChanged",
        "n",
        "handleIconDownloadFinished",
        "Net::DownloadResult",
        "result",
        "handleDownloadFinished",
        "handleParsingFinished",
        "Private::ParsingResult",
        "handleArticleRead",
        "Article*",
        "article",
        "handleArticleLoadFinished",
        "QList<QVariantHash>",
        "articles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'iconLoaded'
        QtMocHelpers::SignalData<void(Feed *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'iconLoaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(Feed *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(Feed *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'refreshIntervalChanged'
        QtMocHelpers::SignalData<void(std::chrono::seconds)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleSessionProcessingEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'handleMaxArticlesPerFeedChanged'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'handleIconDownloadFinished'
        QtMocHelpers::SlotData<void(const Net::DownloadResult &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'handleDownloadFinished'
        QtMocHelpers::SlotData<void(const Net::DownloadResult &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'handleParsingFinished'
        QtMocHelpers::SlotData<void(const Private::ParsingResult &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 18 },
        }}),
        // Slot 'handleArticleRead'
        QtMocHelpers::SlotData<void(Article *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'handleArticleLoadFinished'
        QtMocHelpers::SlotData<void(QList<QVariantHash>)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Feed, qt_meta_tag_ZN3RSS4FeedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RSS::Feed::staticMetaObject = { {
    QMetaObject::SuperData::link<Item::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS4FeedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS4FeedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3RSS4FeedE_t>.metaTypes,
    nullptr
} };

void RSS::Feed::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Feed *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->iconLoaded((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 1: _t->iconLoaded(); break;
        case 2: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 3: _t->titleChanged(); break;
        case 4: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 5: _t->stateChanged(); break;
        case 6: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->refreshIntervalChanged((*reinterpret_cast<std::add_pointer_t<std::chrono::seconds>>(_a[1]))); break;
        case 8: _t->handleSessionProcessingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->handleMaxArticlesPerFeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->handleIconDownloadFinished((*reinterpret_cast<std::add_pointer_t<Net::DownloadResult>>(_a[1]))); break;
        case 11: _t->handleDownloadFinished((*reinterpret_cast<std::add_pointer_t<Net::DownloadResult>>(_a[1]))); break;
        case 12: _t->handleParsingFinished((*reinterpret_cast<std::add_pointer_t<Private::ParsingResult>>(_a[1]))); break;
        case 13: _t->handleArticleRead((*reinterpret_cast<std::add_pointer_t<Article*>>(_a[1]))); break;
        case 14: _t->handleArticleLoadFinished((*reinterpret_cast<std::add_pointer_t<QList<QVariantHash>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Feed* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Feed* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Feed* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(Feed * )>(_a, &Feed::iconLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(Feed * )>(_a, &Feed::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(Feed * )>(_a, &Feed::stateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::urlChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(std::chrono::seconds )>(_a, &Feed::refreshIntervalChanged, 7))
            return;
    }
}

const QMetaObject *RSS::Feed::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RSS::Feed::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS4FeedE_t>.strings))
        return static_cast<void*>(this);
    return Item::qt_metacast(_clname);
}

int RSS::Feed::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Item::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void RSS::Feed::iconLoaded(Feed * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 2
void RSS::Feed::titleChanged(Feed * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 4
void RSS::Feed::stateChanged(Feed * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 6
void RSS::Feed::urlChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void RSS::Feed::refreshIntervalChanged(std::chrono::seconds _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
