/********************************************************************************
** Form generated from reading UI file 'searchjobwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHJOBWIDGET_H
#define UI_SEARCHJOBWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SearchJobWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *resultsLbl;
    QSpacerItem *horizontalSpacer;
    QLabel *label_5;
    QComboBox *filterMode;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label;
    QSpinBox *minSeeds;
    QLabel *label_4;
    QSpinBox *maxSeeds;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_3;
    QDoubleSpinBox *minSize;
    QComboBox *minSizeUnit;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_4;
    QDoubleSpinBox *maxSize;
    QComboBox *maxSizeUnit;
    QTreeView *resultsBrowser;

    void setupUi(QWidget *SearchJobWidget)
    {
        if (SearchJobWidget->objectName().isEmpty())
            SearchJobWidget->setObjectName("SearchJobWidget");
        SearchJobWidget->resize(1216, 364);
        verticalLayout = new QVBoxLayout(SearchJobWidget);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        resultsLbl = new QLabel(SearchJobWidget);
        resultsLbl->setObjectName("resultsLbl");

        horizontalLayout->addWidget(resultsLbl);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label_5 = new QLabel(SearchJobWidget);
        label_5->setObjectName("label_5");

        horizontalLayout->addWidget(label_5);

        filterMode = new QComboBox(SearchJobWidget);
        filterMode->setObjectName("filterMode");

        horizontalLayout->addWidget(filterMode);

        horizontalSpacer_2 = new QSpacerItem(12, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        label = new QLabel(SearchJobWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        minSeeds = new QSpinBox(SearchJobWidget);
        minSeeds->setObjectName("minSeeds");
        minSeeds->setMaximum(1000);

        horizontalLayout->addWidget(minSeeds);

        label_4 = new QLabel(SearchJobWidget);
        label_4->setObjectName("label_4");

        horizontalLayout->addWidget(label_4);

        maxSeeds = new QSpinBox(SearchJobWidget);
        maxSeeds->setObjectName("maxSeeds");
        maxSeeds->setMaximum(1000);

        horizontalLayout->addWidget(maxSeeds);

        horizontalSpacer_3 = new QSpacerItem(12, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        label_3 = new QLabel(SearchJobWidget);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        minSize = new QDoubleSpinBox(SearchJobWidget);
        minSize->setObjectName("minSize");
        minSize->setMaximum(1000.000000000000000);

        horizontalLayout_3->addWidget(minSize);

        minSizeUnit = new QComboBox(SearchJobWidget);
        minSizeUnit->setObjectName("minSizeUnit");

        horizontalLayout_3->addWidget(minSizeUnit);


        horizontalLayout->addLayout(horizontalLayout_3);

        label_2 = new QLabel(SearchJobWidget);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        maxSize = new QDoubleSpinBox(SearchJobWidget);
        maxSize->setObjectName("maxSize");
        maxSize->setMaximum(1000.000000000000000);

        horizontalLayout_4->addWidget(maxSize);

        maxSizeUnit = new QComboBox(SearchJobWidget);
        maxSizeUnit->setObjectName("maxSizeUnit");

        horizontalLayout_4->addWidget(maxSizeUnit);


        horizontalLayout->addLayout(horizontalLayout_4);


        verticalLayout->addLayout(horizontalLayout);

        resultsBrowser = new QTreeView(SearchJobWidget);
        resultsBrowser->setObjectName("resultsBrowser");

        verticalLayout->addWidget(resultsBrowser);


        retranslateUi(SearchJobWidget);

        QMetaObject::connectSlotsByName(SearchJobWidget);
    } // setupUi

    void retranslateUi(QWidget *SearchJobWidget)
    {
        resultsLbl->setText(QCoreApplication::translate("SearchJobWidget", "Results(xxx)", nullptr));
        label_5->setText(QCoreApplication::translate("SearchJobWidget", "Search in:", nullptr));
#if QT_CONFIG(tooltip)
        filterMode->setToolTip(QCoreApplication::translate("SearchJobWidget", "<html><head/><body><p>Some search engines search in torrent description and in torrent file names too. Whether such results will be shown in the list below is controlled by this mode.</p><p><span style=\" font-weight:600;\">Everywhere </span>disables filtering and shows everything returned by the search engines.</p><p><span style=\" font-weight:600;\">Torrent names only</span> shows only torrents whose names match the search query.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label->setToolTip(QCoreApplication::translate("SearchJobWidget", "Set minimum and maximum allowed number of seeders", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("SearchJobWidget", "Seeds:", nullptr));
#if QT_CONFIG(tooltip)
        minSeeds->setToolTip(QCoreApplication::translate("SearchJobWidget", "Minimum number of seeds", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("SearchJobWidget", "to", nullptr));
#if QT_CONFIG(tooltip)
        maxSeeds->setToolTip(QCoreApplication::translate("SearchJobWidget", "Maximum number of seeds", nullptr));
#endif // QT_CONFIG(tooltip)
        maxSeeds->setSpecialValueText(QCoreApplication::translate("SearchJobWidget", "\342\210\236", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(QCoreApplication::translate("SearchJobWidget", "Set minimum and maximum allowed size of a torrent", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(QCoreApplication::translate("SearchJobWidget", "Size:", nullptr));
#if QT_CONFIG(tooltip)
        minSize->setToolTip(QCoreApplication::translate("SearchJobWidget", "Minimum torrent size", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("SearchJobWidget", "to", nullptr));
#if QT_CONFIG(tooltip)
        maxSize->setToolTip(QCoreApplication::translate("SearchJobWidget", "Maximum torrent size", nullptr));
#endif // QT_CONFIG(tooltip)
        maxSize->setSpecialValueText(QCoreApplication::translate("SearchJobWidget", "\342\210\236", nullptr));
        (void)SearchJobWidget;
    } // retranslateUi

};

namespace Ui {
    class SearchJobWidget: public Ui_SearchJobWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHJOBWIDGET_H
