/********************************************************************************
** Form generated from reading UI file 'aboutdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDIALOG_H
#define UI_ABOUTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AboutDialog
{
public:
    QVBoxLayout *aboutDlgLayout;
    QHBoxLayout *titleHBoxLayout;
    QLabel *logo;
    QLabel *labelName;
    QSpacerItem *horizontalSpacer_6;
    QTabWidget *tw_tabs;
    QWidget *aboutTab;
    QGridLayout *aboutTabLayout;
    QLabel *labelMascot;
    QLabel *labelAbout;
    QWidget *authorTab;
    QVBoxLayout *authorTabLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_4;
    QLabel *label_14;
    QLabel *label_17;
    QLabel *label_15;
    QLabel *label_18;
    QLabel *label_16;
    QLabel *label_19;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_5;
    QLabel *label_3;
    QLabel *label_2;
    QLabel *label_4;
    QLabel *label_7;
    QLabel *label_5;
    QLabel *label_6;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;
    QWidget *thanksTab;
    QVBoxLayout *thanksTabLayout;
    QTextBrowser *textBrowserThanks;
    QWidget *translationTab;
    QVBoxLayout *translationTabLayout;
    QTextBrowser *textBrowserTranslation;
    QWidget *licenseTab;
    QVBoxLayout *licenseTabLayout;
    QTextBrowser *textBrowserLicense;
    QWidget *SoftwareUsedTab;
    QVBoxLayout *SoftwareUsedTabLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *btnCopyToClipboard;
    QFrame *line_2;
    QGridLayout *gridLayout;
    QLabel *labelQt;
    QLabel *labelQtVer;
    QSpacerItem *horizontalSpacer_4;
    QLabel *labelLibt;
    QLabel *labelLibtVer;
    QSpacerItem *horizontalSpacer_3;
    QLabel *labelBoost;
    QLabel *labelBoostVer;
    QLabel *labelOpenssl;
    QLabel *labelOpensslVer;
    QLabel *labelZlib;
    QLabel *labelZlibVer;
    QFrame *line;
    QLabel *labelDBIP;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QDialog *AboutDialog)
    {
        if (AboutDialog->objectName().isEmpty())
            AboutDialog->setObjectName("AboutDialog");
        AboutDialog->resize(545, 295);
        aboutDlgLayout = new QVBoxLayout(AboutDialog);
        aboutDlgLayout->setObjectName("aboutDlgLayout");
        titleHBoxLayout = new QHBoxLayout();
        titleHBoxLayout->setObjectName("titleHBoxLayout");
        logo = new QLabel(AboutDialog);
        logo->setObjectName("logo");

        titleHBoxLayout->addWidget(logo);

        labelName = new QLabel(AboutDialog);
        labelName->setObjectName("labelName");
        labelName->setText(QString::fromUtf8("qBittorrent"));
        labelName->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        titleHBoxLayout->addWidget(labelName);

        horizontalSpacer_6 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        titleHBoxLayout->addItem(horizontalSpacer_6);


        aboutDlgLayout->addLayout(titleHBoxLayout);

        tw_tabs = new QTabWidget(AboutDialog);
        tw_tabs->setObjectName("tw_tabs");
        aboutTab = new QWidget();
        aboutTab->setObjectName("aboutTab");
        aboutTabLayout = new QGridLayout(aboutTab);
        aboutTabLayout->setObjectName("aboutTabLayout");
        labelMascot = new QLabel(aboutTab);
        labelMascot->setObjectName("labelMascot");

        aboutTabLayout->addWidget(labelMascot, 0, 0, 1, 1);

        labelAbout = new QLabel(aboutTab);
        labelAbout->setObjectName("labelAbout");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelAbout->sizePolicy().hasHeightForWidth());
        labelAbout->setSizePolicy(sizePolicy);
        labelAbout->setTextFormat(Qt::TextFormat::RichText);
        labelAbout->setWordWrap(true);
        labelAbout->setOpenExternalLinks(true);
        labelAbout->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        aboutTabLayout->addWidget(labelAbout, 0, 1, 1, 1);

        tw_tabs->addTab(aboutTab, QString());
        authorTab = new QWidget();
        authorTab->setObjectName("authorTab");
        authorTabLayout = new QVBoxLayout(authorTab);
        authorTabLayout->setObjectName("authorTabLayout");
        groupBox_2 = new QGroupBox(authorTab);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_4 = new QGridLayout(groupBox_2);
        gridLayout_4->setObjectName("gridLayout_4");
        label_14 = new QLabel(groupBox_2);
        label_14->setObjectName("label_14");

        gridLayout_4->addWidget(label_14, 0, 0, 1, 1);

        label_17 = new QLabel(groupBox_2);
        label_17->setObjectName("label_17");
        label_17->setText(QString::fromUtf8("Sledgehammer999"));

        gridLayout_4->addWidget(label_17, 0, 1, 1, 1);

        label_15 = new QLabel(groupBox_2);
        label_15->setObjectName("label_15");

        gridLayout_4->addWidget(label_15, 1, 0, 1, 1);

        label_18 = new QLabel(groupBox_2);
        label_18->setObjectName("label_18");

        gridLayout_4->addWidget(label_18, 1, 1, 1, 1);

        label_16 = new QLabel(groupBox_2);
        label_16->setObjectName("label_16");

        gridLayout_4->addWidget(label_16, 2, 0, 1, 1);

        label_19 = new QLabel(groupBox_2);
        label_19->setObjectName("label_19");
        label_19->setText(QString::fromUtf8("<a href=\"mailto:sledgehammer999@qbittorrent.org\">sledgehammer999@qbittorrent.org</a>"));
        label_19->setOpenExternalLinks(true);
        label_19->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout_4->addWidget(label_19, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 2, 2, 1, 1);


        authorTabLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(authorTab);
        groupBox->setObjectName("groupBox");
        gridLayout_5 = new QGridLayout(groupBox);
        gridLayout_5->setObjectName("gridLayout_5");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout_5->addWidget(label_3, 0, 0, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setText(QString::fromUtf8("Christophe Dumez"));

        gridLayout_5->addWidget(label_2, 0, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout_5->addWidget(label_4, 1, 0, 1, 1);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        gridLayout_5->addWidget(label_7, 1, 1, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout_5->addWidget(label_5, 2, 0, 1, 1);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");
        label_6->setText(QString::fromUtf8("<a href=\"mailto:chris@qbittorrent.org\">chris@qbittorrent.org</a>"));
        label_6->setOpenExternalLinks(true);
        label_6->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout_5->addWidget(label_6, 2, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_2, 2, 2, 1, 1);


        authorTabLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        authorTabLayout->addItem(verticalSpacer);

        tw_tabs->addTab(authorTab, QString());
        thanksTab = new QWidget();
        thanksTab->setObjectName("thanksTab");
        thanksTabLayout = new QVBoxLayout(thanksTab);
        thanksTabLayout->setObjectName("thanksTabLayout");
        thanksTabLayout->setContentsMargins(0, 0, 0, 0);
        textBrowserThanks = new QTextBrowser(thanksTab);
        textBrowserThanks->setObjectName("textBrowserThanks");
        textBrowserThanks->setOpenExternalLinks(true);

        thanksTabLayout->addWidget(textBrowserThanks);

        tw_tabs->addTab(thanksTab, QString());
        translationTab = new QWidget();
        translationTab->setObjectName("translationTab");
        translationTabLayout = new QVBoxLayout(translationTab);
        translationTabLayout->setObjectName("translationTabLayout");
        translationTabLayout->setContentsMargins(0, 0, 0, 0);
        textBrowserTranslation = new QTextBrowser(translationTab);
        textBrowserTranslation->setObjectName("textBrowserTranslation");
        textBrowserTranslation->setLineWrapMode(QTextEdit::LineWrapMode::NoWrap);
        textBrowserTranslation->setOpenExternalLinks(true);

        translationTabLayout->addWidget(textBrowserTranslation);

        tw_tabs->addTab(translationTab, QString());
        licenseTab = new QWidget();
        licenseTab->setObjectName("licenseTab");
        licenseTabLayout = new QVBoxLayout(licenseTab);
        licenseTabLayout->setObjectName("licenseTabLayout");
        licenseTabLayout->setContentsMargins(0, 0, 0, 0);
        textBrowserLicense = new QTextBrowser(licenseTab);
        textBrowserLicense->setObjectName("textBrowserLicense");
        textBrowserLicense->setOpenExternalLinks(true);

        licenseTabLayout->addWidget(textBrowserLicense);

        tw_tabs->addTab(licenseTab, QString());
        SoftwareUsedTab = new QWidget();
        SoftwareUsedTab->setObjectName("SoftwareUsedTab");
        SoftwareUsedTabLayout = new QVBoxLayout(SoftwareUsedTab);
        SoftwareUsedTabLayout->setObjectName("SoftwareUsedTabLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SoftwareUsedTab);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_5);

        btnCopyToClipboard = new QPushButton(SoftwareUsedTab);
        btnCopyToClipboard->setObjectName("btnCopyToClipboard");

        horizontalLayout->addWidget(btnCopyToClipboard);


        SoftwareUsedTabLayout->addLayout(horizontalLayout);

        line_2 = new QFrame(SoftwareUsedTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        SoftwareUsedTabLayout->addWidget(line_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelQt = new QLabel(SoftwareUsedTab);
        labelQt->setObjectName("labelQt");
        labelQt->setText(QString::fromUtf8("Qt:"));
        labelQt->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        labelQt->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelQt, 0, 1, 1, 1);

        labelQtVer = new QLabel(SoftwareUsedTab);
        labelQtVer->setObjectName("labelQtVer");
        labelQtVer->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelQtVer, 0, 2, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 1, 0, 1, 1);

        labelLibt = new QLabel(SoftwareUsedTab);
        labelLibt->setObjectName("labelLibt");
        labelLibt->setText(QString::fromUtf8("Libtorrent:"));
        labelLibt->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        labelLibt->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelLibt, 1, 1, 1, 1);

        labelLibtVer = new QLabel(SoftwareUsedTab);
        labelLibtVer->setObjectName("labelLibtVer");
        labelLibtVer->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelLibtVer, 1, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 3, 1, 1);

        labelBoost = new QLabel(SoftwareUsedTab);
        labelBoost->setObjectName("labelBoost");
        labelBoost->setText(QString::fromUtf8("Boost:"));
        labelBoost->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        labelBoost->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelBoost, 2, 1, 1, 1);

        labelBoostVer = new QLabel(SoftwareUsedTab);
        labelBoostVer->setObjectName("labelBoostVer");
        labelBoostVer->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelBoostVer, 2, 2, 1, 1);

        labelOpenssl = new QLabel(SoftwareUsedTab);
        labelOpenssl->setObjectName("labelOpenssl");
        labelOpenssl->setText(QString::fromUtf8("OpenSSL:"));
        labelOpenssl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        labelOpenssl->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelOpenssl, 3, 1, 1, 1);

        labelOpensslVer = new QLabel(SoftwareUsedTab);
        labelOpensslVer->setObjectName("labelOpensslVer");
        labelOpensslVer->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelOpensslVer, 3, 2, 1, 1);

        labelZlib = new QLabel(SoftwareUsedTab);
        labelZlib->setObjectName("labelZlib");
        labelZlib->setText(QString::fromUtf8("zlib:"));
        labelZlib->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        labelZlib->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelZlib, 4, 1, 1, 1);

        labelZlibVer = new QLabel(SoftwareUsedTab);
        labelZlibVer->setObjectName("labelZlibVer");
        labelZlibVer->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelZlibVer, 4, 2, 1, 1);


        SoftwareUsedTabLayout->addLayout(gridLayout);

        line = new QFrame(SoftwareUsedTab);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        SoftwareUsedTabLayout->addWidget(line);

        labelDBIP = new QLabel(SoftwareUsedTab);
        labelDBIP->setObjectName("labelDBIP");
        labelDBIP->setText(QString::fromUtf8("DB-IP license text"));
        labelDBIP->setWordWrap(true);
        labelDBIP->setOpenExternalLinks(true);
        labelDBIP->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        SoftwareUsedTabLayout->addWidget(labelDBIP);

        verticalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        SoftwareUsedTabLayout->addItem(verticalSpacer_2);

        tw_tabs->addTab(SoftwareUsedTab, QString());

        aboutDlgLayout->addWidget(tw_tabs);


        retranslateUi(AboutDialog);

        tw_tabs->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AboutDialog);
    } // setupUi

    void retranslateUi(QDialog *AboutDialog)
    {
        AboutDialog->setWindowTitle(QCoreApplication::translate("AboutDialog", "About qBittorrent", nullptr));
        tw_tabs->setTabText(tw_tabs->indexOf(aboutTab), QCoreApplication::translate("AboutDialog", "About", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("AboutDialog", "Current maintainer", nullptr));
        label_14->setText(QCoreApplication::translate("AboutDialog", "Name:", nullptr));
        label_15->setText(QCoreApplication::translate("AboutDialog", "Nationality:", nullptr));
        label_18->setText(QCoreApplication::translate("AboutDialog", "Greece", nullptr));
        label_16->setText(QCoreApplication::translate("AboutDialog", "E-mail:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("AboutDialog", "Original author", nullptr));
        label_3->setText(QCoreApplication::translate("AboutDialog", "Name:", nullptr));
        label_4->setText(QCoreApplication::translate("AboutDialog", "Nationality:", nullptr));
        label_7->setText(QCoreApplication::translate("AboutDialog", "France", nullptr));
        label_5->setText(QCoreApplication::translate("AboutDialog", "E-mail:", nullptr));
        tw_tabs->setTabText(tw_tabs->indexOf(authorTab), QCoreApplication::translate("AboutDialog", "Authors", nullptr));
        tw_tabs->setTabText(tw_tabs->indexOf(thanksTab), QCoreApplication::translate("AboutDialog", "Special Thanks", nullptr));
        tw_tabs->setTabText(tw_tabs->indexOf(translationTab), QCoreApplication::translate("AboutDialog", "Translators", nullptr));
        tw_tabs->setTabText(tw_tabs->indexOf(licenseTab), QCoreApplication::translate("AboutDialog", "License", nullptr));
        label->setText(QCoreApplication::translate("AboutDialog", "qBittorrent was built with the following libraries:", nullptr));
        btnCopyToClipboard->setText(QCoreApplication::translate("AboutDialog", "Copy to clipboard", nullptr));
        tw_tabs->setTabText(tw_tabs->indexOf(SoftwareUsedTab), QCoreApplication::translate("AboutDialog", "Software Used", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutDialog: public Ui_AboutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTDIALOG_H
