/********************************************************************************
** Form generated from reading UI file 'addnewtorrentdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDNEWTORRENTDIALOG_H
#define UI_ADDNEWTORRENTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/fspathedit.h"
#include "gui/torrentcontentwidget.h"

QT_BEGIN_NAMESPACE

class Ui_AddNewTorrentDialog
{
public:
    QVBoxLayout *AddNewTorrentDialogLayout;
    QScrollArea *scrollArea_2;
    QWidget *scrollAreaWidgetContents_2;
    QVBoxLayout *verticalLayout_6;
    QSplitter *splitter;
    QFrame *torrentoptionsFrame;
    QVBoxLayout *mainlayout_addui;
    QHBoxLayout *managementLayout;
    QLabel *labelTorrentManagementMode;
    QComboBox *comboTMM;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBoxSavePath;
    QVBoxLayout *verticalLayout;
    FileSystemPathComboEdit *savePath;
    QGroupBox *groupBoxDownloadPath;
    QVBoxLayout *verticalLayout_4;
    FileSystemPathComboEdit *downloadPath;
    QHBoxLayout *layoutRememberLastSavePath;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *checkBoxRememberLastSavePath;
    QGroupBox *groupBoxSettings;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *categoryLayout;
    QLabel *labelCategory;
    QComboBox *categoryComboBox;
    QCheckBox *defaultCategoryCheckbox;
    QHBoxLayout *tagsLayout;
    QLabel *tagsLabel;
    QLineEdit *tagsLineEdit;
    QToolButton *tagsEditButton;
    QGridLayout *gridLayout;
    QCheckBox *startTorrentCheckBox;
    QHBoxLayout *stopConditionLayout;
    QLabel *stopConditionLabel;
    QComboBox *stopConditionComboBox;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *addToQueueTopCheckBox;
    QCheckBox *skipCheckingCheckBox;
    QCheckBox *sequentialCheckBox;
    QCheckBox *firstLastCheckBox;
    QCheckBox *doNotDeleteTorrentCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *contentLayoutLabel;
    QComboBox *contentLayoutComboBox;
    QSpacerItem *horizontalSpacer_4;
    QGroupBox *infoGroup;
    QGridLayout *gridLayout_2;
    QLabel *labelSize;
    QLabel *labelSizeData;
    QLabel *labelDate;
    QLabel *labelDateData;
    QLabel *labelInfohash1;
    QLabel *labelInfohash1Data;
    QLabel *labelInfohash2;
    QLabel *labelInfohash2Data;
    QLabel *labelComment;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QLabel *labelCommentData;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *contentFilterLayout;
    QPushButton *buttonSelectAll;
    QPushButton *buttonSelectNone;
    QSpacerItem *horizontalSpacer_6;
    TorrentContentWidget *contentTreeView;
    QHBoxLayout *buttonsHLayout;
    QCheckBox *checkBoxNeverShow;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *metadataLayout;
    QProgressBar *progMetaLoading;
    QLabel *lblMetaLoading;
    QPushButton *buttonSave;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AddNewTorrentDialog)
    {
        if (AddNewTorrentDialog->objectName().isEmpty())
            AddNewTorrentDialog->setObjectName("AddNewTorrentDialog");
        AddNewTorrentDialog->resize(900, 680);
        AddNewTorrentDialogLayout = new QVBoxLayout(AddNewTorrentDialog);
        AddNewTorrentDialogLayout->setObjectName("AddNewTorrentDialogLayout");
        scrollArea_2 = new QScrollArea(AddNewTorrentDialog);
        scrollArea_2->setObjectName("scrollArea_2");
        scrollArea_2->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea_2->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContents);
        scrollArea_2->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 882, 598));
        verticalLayout_6 = new QVBoxLayout(scrollAreaWidgetContents_2);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        splitter = new QSplitter(scrollAreaWidgetContents_2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Orientation::Horizontal);
        splitter->setChildrenCollapsible(false);
        torrentoptionsFrame = new QFrame(splitter);
        torrentoptionsFrame->setObjectName("torrentoptionsFrame");
        mainlayout_addui = new QVBoxLayout(torrentoptionsFrame);
        mainlayout_addui->setObjectName("mainlayout_addui");
        mainlayout_addui->setContentsMargins(0, 0, 0, 0);
        managementLayout = new QHBoxLayout();
        managementLayout->setObjectName("managementLayout");
        labelTorrentManagementMode = new QLabel(torrentoptionsFrame);
        labelTorrentManagementMode->setObjectName("labelTorrentManagementMode");

        managementLayout->addWidget(labelTorrentManagementMode);

        comboTMM = new QComboBox(torrentoptionsFrame);
        comboTMM->addItem(QString());
        comboTMM->addItem(QString());
        comboTMM->setObjectName("comboTMM");

        managementLayout->addWidget(comboTMM);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        managementLayout->addItem(horizontalSpacer);


        mainlayout_addui->addLayout(managementLayout);

        groupBoxSavePath = new QGroupBox(torrentoptionsFrame);
        groupBoxSavePath->setObjectName("groupBoxSavePath");
        verticalLayout = new QVBoxLayout(groupBoxSavePath);
        verticalLayout->setObjectName("verticalLayout");
        savePath = new FileSystemPathComboEdit(groupBoxSavePath);
        savePath->setObjectName("savePath");

        verticalLayout->addWidget(savePath);

        groupBoxDownloadPath = new QGroupBox(groupBoxSavePath);
        groupBoxDownloadPath->setObjectName("groupBoxDownloadPath");
        groupBoxDownloadPath->setCheckable(true);
        groupBoxDownloadPath->setChecked(false);
        verticalLayout_4 = new QVBoxLayout(groupBoxDownloadPath);
        verticalLayout_4->setObjectName("verticalLayout_4");
        downloadPath = new FileSystemPathComboEdit(groupBoxDownloadPath);
        downloadPath->setObjectName("downloadPath");

        verticalLayout_4->addWidget(downloadPath);


        verticalLayout->addWidget(groupBoxDownloadPath);

        layoutRememberLastSavePath = new QHBoxLayout();
        layoutRememberLastSavePath->setObjectName("layoutRememberLastSavePath");
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutRememberLastSavePath->addItem(horizontalSpacer_5);

        checkBoxRememberLastSavePath = new QCheckBox(groupBoxSavePath);
        checkBoxRememberLastSavePath->setObjectName("checkBoxRememberLastSavePath");

        layoutRememberLastSavePath->addWidget(checkBoxRememberLastSavePath);


        verticalLayout->addLayout(layoutRememberLastSavePath);


        mainlayout_addui->addWidget(groupBoxSavePath);

        groupBoxSettings = new QGroupBox(torrentoptionsFrame);
        groupBoxSettings->setObjectName("groupBoxSettings");
        verticalLayout_3 = new QVBoxLayout(groupBoxSettings);
        verticalLayout_3->setObjectName("verticalLayout_3");
        categoryLayout = new QHBoxLayout();
        categoryLayout->setObjectName("categoryLayout");
        labelCategory = new QLabel(groupBoxSettings);
        labelCategory->setObjectName("labelCategory");

        categoryLayout->addWidget(labelCategory);

        categoryComboBox = new QComboBox(groupBoxSettings);
        categoryComboBox->setObjectName("categoryComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(categoryComboBox->sizePolicy().hasHeightForWidth());
        categoryComboBox->setSizePolicy(sizePolicy);
        categoryComboBox->setEditable(true);
        categoryComboBox->setInsertPolicy(QComboBox::InsertPolicy::InsertAtTop);

        categoryLayout->addWidget(categoryComboBox);


        verticalLayout_3->addLayout(categoryLayout);

        defaultCategoryCheckbox = new QCheckBox(groupBoxSettings);
        defaultCategoryCheckbox->setObjectName("defaultCategoryCheckbox");

        verticalLayout_3->addWidget(defaultCategoryCheckbox, 0, Qt::AlignmentFlag::AlignRight);

        tagsLayout = new QHBoxLayout();
        tagsLayout->setObjectName("tagsLayout");
        tagsLabel = new QLabel(groupBoxSettings);
        tagsLabel->setObjectName("tagsLabel");

        tagsLayout->addWidget(tagsLabel);

        tagsLineEdit = new QLineEdit(groupBoxSettings);
        tagsLineEdit->setObjectName("tagsLineEdit");
        sizePolicy.setHeightForWidth(tagsLineEdit->sizePolicy().hasHeightForWidth());
        tagsLineEdit->setSizePolicy(sizePolicy);
        tagsLineEdit->setReadOnly(true);
        tagsLineEdit->setClearButtonEnabled(false);

        tagsLayout->addWidget(tagsLineEdit);

        tagsEditButton = new QToolButton(groupBoxSettings);
        tagsEditButton->setObjectName("tagsEditButton");

        tagsLayout->addWidget(tagsEditButton);


        verticalLayout_3->addLayout(tagsLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        startTorrentCheckBox = new QCheckBox(groupBoxSettings);
        startTorrentCheckBox->setObjectName("startTorrentCheckBox");

        gridLayout->addWidget(startTorrentCheckBox, 0, 0, 1, 1);

        stopConditionLayout = new QHBoxLayout();
        stopConditionLayout->setObjectName("stopConditionLayout");
        stopConditionLabel = new QLabel(groupBoxSettings);
        stopConditionLabel->setObjectName("stopConditionLabel");

        stopConditionLayout->addWidget(stopConditionLabel);

        stopConditionComboBox = new QComboBox(groupBoxSettings);
        stopConditionComboBox->setObjectName("stopConditionComboBox");

        stopConditionLayout->addWidget(stopConditionComboBox);


        gridLayout->addLayout(stopConditionLayout, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        addToQueueTopCheckBox = new QCheckBox(groupBoxSettings);
        addToQueueTopCheckBox->setObjectName("addToQueueTopCheckBox");

        gridLayout->addWidget(addToQueueTopCheckBox, 1, 0, 1, 1);

        skipCheckingCheckBox = new QCheckBox(groupBoxSettings);
        skipCheckingCheckBox->setObjectName("skipCheckingCheckBox");

        gridLayout->addWidget(skipCheckingCheckBox, 1, 1, 1, 1);

        sequentialCheckBox = new QCheckBox(groupBoxSettings);
        sequentialCheckBox->setObjectName("sequentialCheckBox");

        gridLayout->addWidget(sequentialCheckBox, 2, 0, 1, 1);

        firstLastCheckBox = new QCheckBox(groupBoxSettings);
        firstLastCheckBox->setObjectName("firstLastCheckBox");

        gridLayout->addWidget(firstLastCheckBox, 2, 1, 1, 1);

        doNotDeleteTorrentCheckBox = new QCheckBox(groupBoxSettings);
        doNotDeleteTorrentCheckBox->setObjectName("doNotDeleteTorrentCheckBox");

        gridLayout->addWidget(doNotDeleteTorrentCheckBox, 3, 0, 1, 1);


        verticalLayout_3->addLayout(gridLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        contentLayoutLabel = new QLabel(groupBoxSettings);
        contentLayoutLabel->setObjectName("contentLayoutLabel");

        horizontalLayout_2->addWidget(contentLayoutLabel);

        contentLayoutComboBox = new QComboBox(groupBoxSettings);
        contentLayoutComboBox->addItem(QString());
        contentLayoutComboBox->addItem(QString());
        contentLayoutComboBox->addItem(QString());
        contentLayoutComboBox->setObjectName("contentLayoutComboBox");

        horizontalLayout_2->addWidget(contentLayoutComboBox);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout_3->addLayout(horizontalLayout_2);


        mainlayout_addui->addWidget(groupBoxSettings);

        infoGroup = new QGroupBox(torrentoptionsFrame);
        infoGroup->setObjectName("infoGroup");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(infoGroup->sizePolicy().hasHeightForWidth());
        infoGroup->setSizePolicy(sizePolicy1);
        gridLayout_2 = new QGridLayout(infoGroup);
        gridLayout_2->setObjectName("gridLayout_2");
        labelSize = new QLabel(infoGroup);
        labelSize->setObjectName("labelSize");

        gridLayout_2->addWidget(labelSize, 0, 0, 1, 1);

        labelSizeData = new QLabel(infoGroup);
        labelSizeData->setObjectName("labelSizeData");

        gridLayout_2->addWidget(labelSizeData, 0, 1, 1, 1);

        labelDate = new QLabel(infoGroup);
        labelDate->setObjectName("labelDate");

        gridLayout_2->addWidget(labelDate, 1, 0, 1, 1);

        labelDateData = new QLabel(infoGroup);
        labelDateData->setObjectName("labelDateData");

        gridLayout_2->addWidget(labelDateData, 1, 1, 1, 1);

        labelInfohash1 = new QLabel(infoGroup);
        labelInfohash1->setObjectName("labelInfohash1");

        gridLayout_2->addWidget(labelInfohash1, 2, 0, 1, 1);

        labelInfohash1Data = new QLabel(infoGroup);
        labelInfohash1Data->setObjectName("labelInfohash1Data");
        labelInfohash1Data->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout_2->addWidget(labelInfohash1Data, 2, 1, 1, 1);

        labelInfohash2 = new QLabel(infoGroup);
        labelInfohash2->setObjectName("labelInfohash2");

        gridLayout_2->addWidget(labelInfohash2, 3, 0, 1, 1);

        labelInfohash2Data = new QLabel(infoGroup);
        labelInfohash2Data->setObjectName("labelInfohash2Data");
        labelInfohash2Data->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout_2->addWidget(labelInfohash2Data, 3, 1, 1, 1);

        labelComment = new QLabel(infoGroup);
        labelComment->setObjectName("labelComment");
        labelComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_2->addWidget(labelComment, 4, 0, 1, 1);

        scrollArea = new QScrollArea(infoGroup);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContents);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 411, 70));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        labelCommentData = new QLabel(scrollAreaWidgetContents);
        labelCommentData->setObjectName("labelCommentData");
        labelCommentData->setTextFormat(Qt::TextFormat::RichText);
        labelCommentData->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        labelCommentData->setWordWrap(true);
        labelCommentData->setOpenExternalLinks(true);
        labelCommentData->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        verticalLayout_2->addWidget(labelCommentData);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout_2->addWidget(scrollArea, 4, 1, 1, 1);


        mainlayout_addui->addWidget(infoGroup);

        splitter->addWidget(torrentoptionsFrame);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout_5 = new QVBoxLayout(layoutWidget);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        contentFilterLayout = new QHBoxLayout();
        contentFilterLayout->setObjectName("contentFilterLayout");
        buttonSelectAll = new QPushButton(layoutWidget);
        buttonSelectAll->setObjectName("buttonSelectAll");

        contentFilterLayout->addWidget(buttonSelectAll);

        buttonSelectNone = new QPushButton(layoutWidget);
        buttonSelectNone->setObjectName("buttonSelectNone");

        contentFilterLayout->addWidget(buttonSelectNone);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        contentFilterLayout->addItem(horizontalSpacer_6);


        verticalLayout_5->addLayout(contentFilterLayout);

        contentTreeView = new TorrentContentWidget(layoutWidget);
        contentTreeView->setObjectName("contentTreeView");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(contentTreeView->sizePolicy().hasHeightForWidth());
        contentTreeView->setSizePolicy(sizePolicy2);
        contentTreeView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        contentTreeView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        contentTreeView->setSortingEnabled(true);

        verticalLayout_5->addWidget(contentTreeView);

        splitter->addWidget(layoutWidget);

        verticalLayout_6->addWidget(splitter);

        scrollArea_2->setWidget(scrollAreaWidgetContents_2);

        AddNewTorrentDialogLayout->addWidget(scrollArea_2);

        buttonsHLayout = new QHBoxLayout();
        buttonsHLayout->setObjectName("buttonsHLayout");
        checkBoxNeverShow = new QCheckBox(AddNewTorrentDialog);
        checkBoxNeverShow->setObjectName("checkBoxNeverShow");

        buttonsHLayout->addWidget(checkBoxNeverShow);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        buttonsHLayout->addItem(horizontalSpacer_2);


        AddNewTorrentDialogLayout->addLayout(buttonsHLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        metadataLayout = new QHBoxLayout();
        metadataLayout->setObjectName("metadataLayout");
        progMetaLoading = new QProgressBar(AddNewTorrentDialog);
        progMetaLoading->setObjectName("progMetaLoading");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(progMetaLoading->sizePolicy().hasHeightForWidth());
        progMetaLoading->setSizePolicy(sizePolicy3);
        progMetaLoading->setMaximum(0);
        progMetaLoading->setValue(-1);
        progMetaLoading->setTextVisible(false);

        metadataLayout->addWidget(progMetaLoading);

        lblMetaLoading = new QLabel(AddNewTorrentDialog);
        lblMetaLoading->setObjectName("lblMetaLoading");

        metadataLayout->addWidget(lblMetaLoading);

        buttonSave = new QPushButton(AddNewTorrentDialog);
        buttonSave->setObjectName("buttonSave");

        metadataLayout->addWidget(buttonSave);


        horizontalLayout->addLayout(metadataLayout);

        buttonBox = new QDialogButtonBox(AddNewTorrentDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        horizontalLayout->addWidget(buttonBox);


        AddNewTorrentDialogLayout->addLayout(horizontalLayout);


        retranslateUi(AddNewTorrentDialog);

        contentLayoutComboBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AddNewTorrentDialog);
    } // setupUi

    void retranslateUi(QDialog *AddNewTorrentDialog)
    {
        labelTorrentManagementMode->setText(QCoreApplication::translate("AddNewTorrentDialog", "Torrent Management Mode:", nullptr));
        comboTMM->setItemText(0, QCoreApplication::translate("AddNewTorrentDialog", "Manual", nullptr));
        comboTMM->setItemText(1, QCoreApplication::translate("AddNewTorrentDialog", "Automatic", nullptr));

#if QT_CONFIG(tooltip)
        comboTMM->setToolTip(QCoreApplication::translate("AddNewTorrentDialog", "Automatic mode means that various torrent properties(eg save path) will be decided by the associated category", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxSavePath->setTitle(QCoreApplication::translate("AddNewTorrentDialog", "Save at", nullptr));
        groupBoxDownloadPath->setTitle(QCoreApplication::translate("AddNewTorrentDialog", "Use another path for incomplete torrent", nullptr));
        checkBoxRememberLastSavePath->setText(QCoreApplication::translate("AddNewTorrentDialog", "Remember last used save path", nullptr));
        groupBoxSettings->setTitle(QCoreApplication::translate("AddNewTorrentDialog", "Torrent options", nullptr));
        labelCategory->setText(QCoreApplication::translate("AddNewTorrentDialog", "Category:", nullptr));
        defaultCategoryCheckbox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Set as default category", nullptr));
        tagsLabel->setText(QCoreApplication::translate("AddNewTorrentDialog", "Tags:", nullptr));
        tagsLineEdit->setPlaceholderText(QCoreApplication::translate("AddNewTorrentDialog", "Click [...] button to add/remove tags.", nullptr));
#if QT_CONFIG(tooltip)
        tagsEditButton->setToolTip(QCoreApplication::translate("AddNewTorrentDialog", "Add/remove tags", nullptr));
#endif // QT_CONFIG(tooltip)
        tagsEditButton->setText(QCoreApplication::translate("AddNewTorrentDialog", "...", nullptr));
        startTorrentCheckBox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Start torrent", nullptr));
        stopConditionLabel->setText(QCoreApplication::translate("AddNewTorrentDialog", "Stop condition:", nullptr));
        addToQueueTopCheckBox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Add to top of queue", nullptr));
        skipCheckingCheckBox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Skip hash check", nullptr));
        sequentialCheckBox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Download in sequential order", nullptr));
        firstLastCheckBox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Download first and last pieces first", nullptr));
#if QT_CONFIG(tooltip)
        doNotDeleteTorrentCheckBox->setToolTip(QCoreApplication::translate("AddNewTorrentDialog", "When checked, the .torrent file will not be deleted regardless of the settings at the \"Download\" page of the Options dialog", nullptr));
#endif // QT_CONFIG(tooltip)
        doNotDeleteTorrentCheckBox->setText(QCoreApplication::translate("AddNewTorrentDialog", "Do not delete .torrent file", nullptr));
        contentLayoutLabel->setText(QCoreApplication::translate("AddNewTorrentDialog", "Content layout:", nullptr));
        contentLayoutComboBox->setItemText(0, QCoreApplication::translate("AddNewTorrentDialog", "Original", nullptr));
        contentLayoutComboBox->setItemText(1, QCoreApplication::translate("AddNewTorrentDialog", "Create subfolder", nullptr));
        contentLayoutComboBox->setItemText(2, QCoreApplication::translate("AddNewTorrentDialog", "Don't create subfolder", nullptr));

        infoGroup->setTitle(QCoreApplication::translate("AddNewTorrentDialog", "Torrent information", nullptr));
        labelSize->setText(QCoreApplication::translate("AddNewTorrentDialog", "Size:", nullptr));
        labelDate->setText(QCoreApplication::translate("AddNewTorrentDialog", "Date:", nullptr));
        labelInfohash1->setText(QCoreApplication::translate("AddNewTorrentDialog", "Info hash v1:", nullptr));
        labelInfohash2->setText(QCoreApplication::translate("AddNewTorrentDialog", "Info hash v2:", nullptr));
        labelComment->setText(QCoreApplication::translate("AddNewTorrentDialog", "Comment:", nullptr));
        buttonSelectAll->setText(QCoreApplication::translate("AddNewTorrentDialog", "Select All", nullptr));
        buttonSelectNone->setText(QCoreApplication::translate("AddNewTorrentDialog", "Select None", nullptr));
        checkBoxNeverShow->setText(QCoreApplication::translate("AddNewTorrentDialog", "Never show again", nullptr));
        lblMetaLoading->setText(QString());
        buttonSave->setText(QCoreApplication::translate("AddNewTorrentDialog", "Save as .torrent file...", nullptr));
        (void)AddNewTorrentDialog;
    } // retranslateUi

};

namespace Ui {
    class AddNewTorrentDialog: public Ui_AddNewTorrentDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDNEWTORRENTDIALOG_H
