/****************************************************************************
** Meta object code from reading C++ file 'addnewtorrentdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/addnewtorrentdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addnewtorrentdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AddNewTorrentDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto AddNewTorrentDialog::qt_create_metaobjectdata<qt_meta_tag_ZN19AddNewTorrentDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AddNewTorrentDialog",
        "torrentAccepted",
        "",
        "BitTorrent::TorrentDescriptor",
        "torrentDescriptor",
        "BitTorrent::AddTorrentParams",
        "addTorrentParams",
        "torrentRejected",
        "accept",
        "reject",
        "done",
        "result",
        "updateDiskSpaceLabel",
        "onSavePathChanged",
        "Path",
        "newPath",
        "onDownloadPathChanged",
        "onUseDownloadPathChanged",
        "checked",
        "TMMChanged",
        "index",
        "categoryChanged",
        "contentLayoutChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'torrentAccepted'
        QtMocHelpers::SignalData<void(const BitTorrent::TorrentDescriptor &, const BitTorrent::AddTorrentParams &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'torrentRejected'
        QtMocHelpers::SignalData<void(const BitTorrent::TorrentDescriptor &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'done'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'updateDiskSpaceLabel'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSavePathChanged'
        QtMocHelpers::SlotData<void(const Path &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onDownloadPathChanged'
        QtMocHelpers::SlotData<void(const Path &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onUseDownloadPathChanged'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'TMMChanged'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'categoryChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'contentLayoutChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddNewTorrentDialog, qt_meta_tag_ZN19AddNewTorrentDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AddNewTorrentDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AddNewTorrentDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AddNewTorrentDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AddNewTorrentDialogE_t>.metaTypes,
    nullptr
} };

void AddNewTorrentDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddNewTorrentDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->torrentAccepted((*reinterpret_cast<std::add_pointer_t<BitTorrent::TorrentDescriptor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<BitTorrent::AddTorrentParams>>(_a[2]))); break;
        case 1: _t->torrentRejected((*reinterpret_cast<std::add_pointer_t<BitTorrent::TorrentDescriptor>>(_a[1]))); break;
        case 2: _t->accept(); break;
        case 3: _t->reject(); break;
        case 4: _t->done((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->updateDiskSpaceLabel(); break;
        case 6: _t->onSavePathChanged((*reinterpret_cast<std::add_pointer_t<Path>>(_a[1]))); break;
        case 7: _t->onDownloadPathChanged((*reinterpret_cast<std::add_pointer_t<Path>>(_a[1]))); break;
        case 8: _t->onUseDownloadPathChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->TMMChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->categoryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->contentLayoutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Path >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Path >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AddNewTorrentDialog::*)(const BitTorrent::TorrentDescriptor & , const BitTorrent::AddTorrentParams & )>(_a, &AddNewTorrentDialog::torrentAccepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddNewTorrentDialog::*)(const BitTorrent::TorrentDescriptor & )>(_a, &AddNewTorrentDialog::torrentRejected, 1))
            return;
    }
}

const QMetaObject *AddNewTorrentDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AddNewTorrentDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AddNewTorrentDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int AddNewTorrentDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void AddNewTorrentDialog::torrentAccepted(const BitTorrent::TorrentDescriptor & _t1, const BitTorrent::AddTorrentParams & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void AddNewTorrentDialog::torrentRejected(const BitTorrent::TorrentDescriptor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
