/********************************************************************************
** Form generated from reading UI file 'uithemedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UITHEMEDIALOG_H
#define UI_UITHEMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_UIThemeDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *colorsTab;
    QVBoxLayout *verticalLayout_2;
    QScrollArea *colorsScrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_3;
    QLabel *colorsWarningLabel;
    QGridLayout *colorsLayout;
    QLabel *colorIDLabel;
    QLabel *lightModeColorLabel;
    QLabel *darkModeColorLabel;
    QSpacerItem *colorsSpacer;
    QWidget *iconsTab;
    QVBoxLayout *verticalLayout_5;
    QScrollArea *iconsScrollArea;
    QWidget *scrollAreaWidgetContents_2;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *iconsLayout;
    QLabel *iconIDLabel;
    QLabel *lightModeIconLabel;
    QLabel *darkModeIconLabel;
    QSpacerItem *iconsSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UIThemeDialog)
    {
        if (UIThemeDialog->objectName().isEmpty())
            UIThemeDialog->setObjectName("UIThemeDialog");
        UIThemeDialog->resize(451, 348);
        verticalLayout = new QVBoxLayout(UIThemeDialog);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(UIThemeDialog);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setTabBarAutoHide(true);
        colorsTab = new QWidget();
        colorsTab->setObjectName("colorsTab");
        verticalLayout_2 = new QVBoxLayout(colorsTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        colorsScrollArea = new QScrollArea(colorsTab);
        colorsScrollArea->setObjectName("colorsScrollArea");
        sizePolicy.setHeightForWidth(colorsScrollArea->sizePolicy().hasHeightForWidth());
        colorsScrollArea->setSizePolicy(sizePolicy);
        colorsScrollArea->setFrameShape(QFrame::Shape::NoFrame);
        colorsScrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContentsOnFirstShow);
        colorsScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 427, 271));
        verticalLayout_3 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_3->setObjectName("verticalLayout_3");
        colorsWarningLabel = new QLabel(scrollAreaWidgetContents);
        colorsWarningLabel->setObjectName("colorsWarningLabel");
        colorsWarningLabel->setWordWrap(true);
        QFont font;
        font.setItalic(true);
        colorsWarningLabel->setFont(font);

        verticalLayout_3->addWidget(colorsWarningLabel);

        colorsLayout = new QGridLayout();
        colorsLayout->setObjectName("colorsLayout");
        colorIDLabel = new QLabel(scrollAreaWidgetContents);
        colorIDLabel->setObjectName("colorIDLabel");
        QFont font1;
        font1.setBold(true);
        colorIDLabel->setFont(font1);

        colorsLayout->addWidget(colorIDLabel, 0, 0, 1, 1);

        lightModeColorLabel = new QLabel(scrollAreaWidgetContents);
        lightModeColorLabel->setObjectName("lightModeColorLabel");
        lightModeColorLabel->setFont(font1);

        colorsLayout->addWidget(lightModeColorLabel, 0, 2, 1, 1);

        darkModeColorLabel = new QLabel(scrollAreaWidgetContents);
        darkModeColorLabel->setObjectName("darkModeColorLabel");
        darkModeColorLabel->setFont(font1);

        colorsLayout->addWidget(darkModeColorLabel, 0, 4, 1, 1);

        colorsLayout->setColumnStretch(0, 1);
        colorsLayout->setColumnMinimumWidth(1, 15);
        colorsLayout->setColumnMinimumWidth(3, 15);

        verticalLayout_3->addLayout(colorsLayout);

        colorsSpacer = new QSpacerItem(20, 203, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(colorsSpacer);

        colorsScrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(colorsScrollArea);

        tabWidget->addTab(colorsTab, QString());
        iconsTab = new QWidget();
        iconsTab->setObjectName("iconsTab");
        verticalLayout_5 = new QVBoxLayout(iconsTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        iconsScrollArea = new QScrollArea(iconsTab);
        iconsScrollArea->setObjectName("iconsScrollArea");
        sizePolicy.setHeightForWidth(iconsScrollArea->sizePolicy().hasHeightForWidth());
        iconsScrollArea->setSizePolicy(sizePolicy);
        iconsScrollArea->setFrameShape(QFrame::Shape::NoFrame);
        iconsScrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContentsOnFirstShow);
        iconsScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 427, 271));
        verticalLayout_4 = new QVBoxLayout(scrollAreaWidgetContents_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        iconsLayout = new QGridLayout();
        iconsLayout->setObjectName("iconsLayout");
        iconIDLabel = new QLabel(scrollAreaWidgetContents_2);
        iconIDLabel->setObjectName("iconIDLabel");
        iconIDLabel->setFont(font1);

        iconsLayout->addWidget(iconIDLabel, 0, 0, 1, 1);

        lightModeIconLabel = new QLabel(scrollAreaWidgetContents_2);
        lightModeIconLabel->setObjectName("lightModeIconLabel");
        lightModeIconLabel->setFont(font1);

        iconsLayout->addWidget(lightModeIconLabel, 0, 2, 1, 1);

        darkModeIconLabel = new QLabel(scrollAreaWidgetContents_2);
        darkModeIconLabel->setObjectName("darkModeIconLabel");
        darkModeIconLabel->setFont(font1);

        iconsLayout->addWidget(darkModeIconLabel, 0, 4, 1, 1);

        iconsLayout->setColumnStretch(0, 1);
        iconsLayout->setColumnMinimumWidth(1, 15);
        iconsLayout->setColumnMinimumWidth(3, 15);

        verticalLayout_4->addLayout(iconsLayout);

        iconsSpacer = new QSpacerItem(20, 203, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(iconsSpacer);

        iconsScrollArea->setWidget(scrollAreaWidgetContents_2);

        verticalLayout_5->addWidget(iconsScrollArea);

        tabWidget->addTab(iconsTab, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(UIThemeDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(UIThemeDialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(UIThemeDialog);
    } // setupUi

    void retranslateUi(QDialog *UIThemeDialog)
    {
        UIThemeDialog->setWindowTitle(QCoreApplication::translate("UIThemeDialog", "UI Theme Configuration", nullptr));
        colorsWarningLabel->setText(QCoreApplication::translate("UIThemeDialog", "Note that some custom colors may not be applied in some desktop environments.", nullptr));
        colorIDLabel->setText(QCoreApplication::translate("UIThemeDialog", "Color ID", nullptr));
        lightModeColorLabel->setText(QCoreApplication::translate("UIThemeDialog", "Light Mode", nullptr));
        darkModeColorLabel->setText(QCoreApplication::translate("UIThemeDialog", "Dark Mode", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(colorsTab), QCoreApplication::translate("UIThemeDialog", "Colors", nullptr));
        iconIDLabel->setText(QCoreApplication::translate("UIThemeDialog", "Icon ID", nullptr));
        lightModeIconLabel->setText(QCoreApplication::translate("UIThemeDialog", "Light Mode", nullptr));
        darkModeIconLabel->setText(QCoreApplication::translate("UIThemeDialog", "Dark Mode", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(iconsTab), QCoreApplication::translate("UIThemeDialog", "Icons", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UIThemeDialog: public Ui_UIThemeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_UITHEMEDIALOG_H
