/****************************************************************************
** Meta object code from reading C++ file 'preferences.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/base/preferences.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'preferences.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PreferencesE_t {};
} // unnamed namespace

template <> constexpr inline auto Preferences::qt_create_metaobjectdata<qt_meta_tag_ZN11PreferencesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Preferences",
        "changed",
        "",
        "setStatusFilterState",
        "checked",
        "setCategoryFilterState",
        "setTagFilterState",
        "setTrackerFilterState",
        "setTrackerStatusFilterState",
        "apply"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setStatusFilterState'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'setCategoryFilterState'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'setTagFilterState'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'setTrackerFilterState'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'setTrackerStatusFilterState'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'apply'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Preferences, qt_meta_tag_ZN11PreferencesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Preferences::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PreferencesE_t>.metaTypes,
    nullptr
} };

void Preferences::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Preferences *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->setStatusFilterState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->setCategoryFilterState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setTagFilterState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setTrackerFilterState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setTrackerStatusFilterState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->apply(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::changed, 0))
            return;
    }
}

const QMetaObject *Preferences::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Preferences::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Preferences::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Preferences::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN9SchedulerE_t {};
} // unnamed namespace

template <> constexpr inline auto Scheduler::qt_create_metaobjectdata<qt_meta_tag_ZN9SchedulerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Scheduler",
        "Days",
        "EveryDay",
        "Weekday",
        "Weekend",
        "Monday",
        "Tuesday",
        "Wednesday",
        "Thursday",
        "Friday",
        "Saturday",
        "Sunday"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Days'
        QtMocHelpers::EnumData<Days>(1, 1, QMC::EnumIsScoped).add({
            {    2, Days::EveryDay },
            {    3, Days::Weekday },
            {    4, Days::Weekend },
            {    5, Days::Monday },
            {    6, Days::Tuesday },
            {    7, Days::Wednesday },
            {    8, Days::Thursday },
            {    9, Days::Friday },
            {   10, Days::Saturday },
            {   11, Days::Sunday },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9SchedulerE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN9SchedulerE =
    Scheduler::qt_create_metaobjectdata<qt_meta_tag_ZN9SchedulerE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9SchedulerE =
    qt_staticMetaObjectContent_ZN9SchedulerE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9SchedulerE =
    qt_staticMetaObjectContent_ZN9SchedulerE.relocatingData;

Q_CONSTINIT const QMetaObject Scheduler::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9SchedulerE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9SchedulerE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9SchedulerE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3DNSE_t {};
} // unnamed namespace

template <> constexpr inline auto DNS::qt_create_metaobjectdata<qt_meta_tag_ZN3DNSE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DNS",
        "Service",
        "DynDNS",
        "NoIP",
        "None"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Service'
        QtMocHelpers::EnumData<Service>(1, 1, QMC::EnumIsScoped).add({
            {    2, Service::DynDNS },
            {    3, Service::NoIP },
            {    4, Service::None },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN3DNSE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN3DNSE =
    DNS::qt_create_metaobjectdata<qt_meta_tag_ZN3DNSE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN3DNSE =
    qt_staticMetaObjectContent_ZN3DNSE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN3DNSE =
    qt_staticMetaObjectContent_ZN3DNSE.relocatingData;

Q_CONSTINIT const QMetaObject DNS::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN3DNSE.stringdata,
    qt_staticMetaObjectStaticContent_ZN3DNSE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN3DNSE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN8TrayIconE_t {};
} // unnamed namespace

template <> constexpr inline auto TrayIcon::qt_create_metaobjectdata<qt_meta_tag_ZN8TrayIconE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrayIcon",
        "Style",
        "Normal",
        "MonoDark",
        "MonoLight"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Style'
        QtMocHelpers::EnumData<Style>(1, 1, QMC::EnumIsScoped).add({
            {    2, Style::Normal },
            {    3, Style::MonoDark },
            {    4, Style::MonoLight },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN8TrayIconE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN8TrayIconE =
    TrayIcon::qt_create_metaobjectdata<qt_meta_tag_ZN8TrayIconE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN8TrayIconE =
    qt_staticMetaObjectContent_ZN8TrayIconE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN8TrayIconE =
    qt_staticMetaObjectContent_ZN8TrayIconE.relocatingData;

Q_CONSTINIT const QMetaObject TrayIcon::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN8TrayIconE.stringdata,
    qt_staticMetaObjectStaticContent_ZN8TrayIconE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN8TrayIconE.metaTypes,
    nullptr
} };

QT_WARNING_POP
