/********************************************************************************
** Form generated from reading UI file 'torrenttagsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TORRENTTAGSDIALOG_H
#define UI_TORRENTTAGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TorrentTagsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TorrentTagsDialog)
    {
        if (TorrentTagsDialog->objectName().isEmpty())
            TorrentTagsDialog->setObjectName("TorrentTagsDialog");
        TorrentTagsDialog->resize(484, 313);
        verticalLayout = new QVBoxLayout(TorrentTagsDialog);
        verticalLayout->setObjectName("verticalLayout");
        scrollArea = new QScrollArea(TorrentTagsDialog);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 464, 263));
        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        buttonBox = new QDialogButtonBox(TorrentTagsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TorrentTagsDialog);

        QMetaObject::connectSlotsByName(TorrentTagsDialog);
    } // setupUi

    void retranslateUi(QDialog *TorrentTagsDialog)
    {
        TorrentTagsDialog->setWindowTitle(QCoreApplication::translate("TorrentTagsDialog", "Torrent Tags", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TorrentTagsDialog: public Ui_TorrentTagsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TORRENTTAGSDIALOG_H
