/****************************************************************************
** Meta object code from reading C++ file 'transferlistwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/transferlistwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferlistwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18TransferListWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferListWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18TransferListWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferListWidget",
        "currentTorrentChanged",
        "",
        "BitTorrent::Torrent*",
        "torrent",
        "setSelectionCategory",
        "category",
        "addSelectionTag",
        "Tag",
        "tag",
        "removeSelectionTag",
        "clearSelectionTags",
        "setSelectedTorrentsLocation",
        "pauseSession",
        "resumeSession",
        "startSelectedTorrents",
        "forceStartSelectedTorrents",
        "startVisibleTorrents",
        "stopSelectedTorrents",
        "stopVisibleTorrents",
        "softDeleteSelectedTorrents",
        "permDeleteSelectedTorrents",
        "deleteSelectedTorrents",
        "deleteLocalFiles",
        "deleteVisibleTorrents",
        "increaseQueuePosSelectedTorrents",
        "decreaseQueuePosSelectedTorrents",
        "topQueuePosSelectedTorrents",
        "bottomQueuePosSelectedTorrents",
        "copySelectedMagnetURIs",
        "copySelectedNames",
        "copyContentPaths",
        "copySelectedInfohashes",
        "CopyInfohashPolicy",
        "policy",
        "copySelectedIDs",
        "copySelectedComments",
        "openSelectedTorrentsFolder",
        "openDestinationFolder",
        "const BitTorrent::Torrent*",
        "recheckSelectedTorrents",
        "reannounceSelectedTorrents",
        "setTorrentOptions",
        "previewSelectedTorrents",
        "hideQueuePosColumn",
        "hide",
        "applyFilter",
        "name",
        "TransferListModel::Column",
        "type",
        "applyStatusFilter",
        "filterIndex",
        "applyCategoryFilter",
        "applyTagFilter",
        "std::optional<Tag>",
        "applyTrackerFilter",
        "std::optional<QString>",
        "trackerHost",
        "applyAnnounceStatusFilter",
        "std::optional<BitTorrent::TorrentAnnounceStatus>",
        "announceStatus",
        "previewFile",
        "Path",
        "filePath",
        "renameSelectedTorrent",
        "torrentDoubleClicked",
        "displayListMenu",
        "displayColumnHeaderMenu",
        "currentChanged",
        "QModelIndex",
        "current",
        "previous",
        "setSelectedTorrentsSuperSeeding",
        "enabled",
        "setSelectedTorrentsSequentialDownload",
        "setSelectedFirstLastPiecePrio",
        "setSelectedAutoTMMEnabled",
        "askNewCategoryForSelection",
        "saveSettings"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTorrentChanged'
        QtMocHelpers::SignalData<void(BitTorrent::Torrent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setSelectionCategory'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'addSelectionTag'
        QtMocHelpers::SlotData<void(const Tag &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'removeSelectionTag'
        QtMocHelpers::SlotData<void(const Tag &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'clearSelectionTags'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSelectedTorrentsLocation'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pauseSession'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resumeSession'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startSelectedTorrents'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceStartSelectedTorrents'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startVisibleTorrents'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopSelectedTorrents'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopVisibleTorrents'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'softDeleteSelectedTorrents'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'permDeleteSelectedTorrents'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteSelectedTorrents'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'deleteVisibleTorrents'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'increaseQueuePosSelectedTorrents'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decreaseQueuePosSelectedTorrents'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'topQueuePosSelectedTorrents'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'bottomQueuePosSelectedTorrents'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelectedMagnetURIs'
        QtMocHelpers::SlotData<void() const>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelectedNames'
        QtMocHelpers::SlotData<void() const>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyContentPaths'
        QtMocHelpers::SlotData<void() const>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelectedInfohashes'
        QtMocHelpers::SlotData<void(CopyInfohashPolicy) const>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'copySelectedIDs'
        QtMocHelpers::SlotData<void() const>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelectedComments'
        QtMocHelpers::SlotData<void() const>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openSelectedTorrentsFolder'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openDestinationFolder'
        QtMocHelpers::SlotData<void(const BitTorrent::Torrent *)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 4 },
        }}),
        // Slot 'recheckSelectedTorrents'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reannounceSelectedTorrents'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTorrentOptions'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previewSelectedTorrents'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideQueuePosColumn'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'applyFilter'
        QtMocHelpers::SlotData<void(const QString &, const TransferListModel::Column &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'applyStatusFilter'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 51 },
        }}),
        // Slot 'applyCategoryFilter'
        QtMocHelpers::SlotData<void(const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'applyTagFilter'
        QtMocHelpers::SlotData<void(const std::optional<Tag> &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 9 },
        }}),
        // Slot 'applyTrackerFilter'
        QtMocHelpers::SlotData<void(const std::optional<QString> &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'applyAnnounceStatusFilter'
        QtMocHelpers::SlotData<void(const std::optional<BitTorrent::TorrentAnnounceStatus> &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'previewFile'
        QtMocHelpers::SlotData<void(const Path &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Slot 'renameSelectedTorrent'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'torrentDoubleClicked'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayListMenu'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayColumnHeaderMenu'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'currentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 70 }, { 0x80000000 | 69, 71 },
        }}),
        // Slot 'setSelectedTorrentsSuperSeeding'
        QtMocHelpers::SlotData<void(bool) const>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'setSelectedTorrentsSequentialDownload'
        QtMocHelpers::SlotData<void(bool) const>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'setSelectedFirstLastPiecePrio'
        QtMocHelpers::SlotData<void(bool) const>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'setSelectedAutoTMMEnabled'
        QtMocHelpers::SlotData<void(bool)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'askNewCategoryForSelection'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSettings'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferListWidget, qt_meta_tag_ZN18TransferListWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferListWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<GUIApplicationComponent<QTreeView>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferListWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferListWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TransferListWidgetE_t>.metaTypes,
    nullptr
} };

void TransferListWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferListWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTorrentChanged((*reinterpret_cast<std::add_pointer_t<BitTorrent::Torrent*>>(_a[1]))); break;
        case 1: _t->setSelectionCategory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->addSelectionTag((*reinterpret_cast<std::add_pointer_t<Tag>>(_a[1]))); break;
        case 3: _t->removeSelectionTag((*reinterpret_cast<std::add_pointer_t<Tag>>(_a[1]))); break;
        case 4: _t->clearSelectionTags(); break;
        case 5: _t->setSelectedTorrentsLocation(); break;
        case 6: _t->pauseSession(); break;
        case 7: _t->resumeSession(); break;
        case 8: _t->startSelectedTorrents(); break;
        case 9: _t->forceStartSelectedTorrents(); break;
        case 10: _t->startVisibleTorrents(); break;
        case 11: _t->stopSelectedTorrents(); break;
        case 12: _t->stopVisibleTorrents(); break;
        case 13: _t->softDeleteSelectedTorrents(); break;
        case 14: _t->permDeleteSelectedTorrents(); break;
        case 15: _t->deleteSelectedTorrents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->deleteVisibleTorrents(); break;
        case 17: _t->increaseQueuePosSelectedTorrents(); break;
        case 18: _t->decreaseQueuePosSelectedTorrents(); break;
        case 19: _t->topQueuePosSelectedTorrents(); break;
        case 20: _t->bottomQueuePosSelectedTorrents(); break;
        case 21: _t->copySelectedMagnetURIs(); break;
        case 22: _t->copySelectedNames(); break;
        case 23: _t->copyContentPaths(); break;
        case 24: _t->copySelectedInfohashes((*reinterpret_cast<std::add_pointer_t<CopyInfohashPolicy>>(_a[1]))); break;
        case 25: _t->copySelectedIDs(); break;
        case 26: _t->copySelectedComments(); break;
        case 27: _t->openSelectedTorrentsFolder(); break;
        case 28: _t->openDestinationFolder((*reinterpret_cast<std::add_pointer_t<const BitTorrent::Torrent*>>(_a[1]))); break;
        case 29: _t->recheckSelectedTorrents(); break;
        case 30: _t->reannounceSelectedTorrents(); break;
        case 31: _t->setTorrentOptions(); break;
        case 32: _t->previewSelectedTorrents(); break;
        case 33: _t->hideQueuePosColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->applyFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TransferListModel::Column>>(_a[2]))); break;
        case 35: _t->applyStatusFilter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->applyCategoryFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->applyTagFilter((*reinterpret_cast<std::add_pointer_t<std::optional<Tag>>>(_a[1]))); break;
        case 38: _t->applyTrackerFilter((*reinterpret_cast<std::add_pointer_t<std::optional<QString>>>(_a[1]))); break;
        case 39: _t->applyAnnounceStatusFilter((*reinterpret_cast<std::add_pointer_t<std::optional<BitTorrent::TorrentAnnounceStatus>>>(_a[1]))); break;
        case 40: _t->previewFile((*reinterpret_cast<std::add_pointer_t<Path>>(_a[1]))); break;
        case 41: _t->renameSelectedTorrent(); break;
        case 42: _t->torrentDoubleClicked(); break;
        case 43: _t->displayListMenu(); break;
        case 44: _t->displayColumnHeaderMenu(); break;
        case 45: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 46: _t->setSelectedTorrentsSuperSeeding((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->setSelectedTorrentsSequentialDownload((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->setSelectedFirstLastPiecePrio((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->setSelectedAutoTMMEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->askNewCategoryForSelection(); break;
        case 51: _t->saveSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BitTorrent::Torrent* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Tag >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Tag >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferListModel::Column >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferListWidget::*)(BitTorrent::Torrent * )>(_a, &TransferListWidget::currentTorrentChanged, 0))
            return;
    }
}

const QMetaObject *TransferListWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferListWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferListWidgetE_t>.strings))
        return static_cast<void*>(this);
    return GUIApplicationComponent<QTreeView>::qt_metacast(_clname);
}

int TransferListWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GUIApplicationComponent<QTreeView>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    return _id;
}

// SIGNAL 0
void TransferListWidget::currentTorrentChanged(BitTorrent::Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
