/********************************************************************************
** Form generated from reading UI file 'statsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STATSDIALOG_H
#define UI_STATSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_StatsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupUser;
    QGridLayout *gridLayout_2;
    QLabel *labelAlltimeULText;
    QLabel *labelAlltimeUL;
    QLabel *labelAlltimeDLText;
    QLabel *labelAlltimeDL;
    QLabel *labelGlobalRatioText;
    QLabel *labelGlobalRatio;
    QLabel *labelWasteText;
    QLabel *labelWaste;
    QLabel *labelPeersText;
    QLabel *labelPeers;
    QGroupBox *groupCache;
    QGridLayout *gridLayout;
    QLabel *labelCacheHitsText;
    QLabel *labelCacheHits;
    QLabel *labelTotalBufText;
    QLabel *labelTotalBuf;
    QGroupBox *groupPerf;
    QGridLayout *gridLayout_3;
    QLabel *labelWriteStarveText;
    QLabel *labelWriteStarve;
    QLabel *labelReadStarveText;
    QLabel *labelReadStarve;
    QLabel *labelQueuedJobsText;
    QLabel *labelQueuedJobs;
    QLabel *labelJobsTimeText;
    QLabel *labelJobsTime;
    QLabel *labelQueuedBytesText;
    QLabel *labelQueuedBytes;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *StatsDialog)
    {
        if (StatsDialog->objectName().isEmpty())
            StatsDialog->setObjectName("StatsDialog");
        StatsDialog->resize(286, 401);
        verticalLayout = new QVBoxLayout(StatsDialog);
        verticalLayout->setObjectName("verticalLayout");
        groupUser = new QGroupBox(StatsDialog);
        groupUser->setObjectName("groupUser");
        gridLayout_2 = new QGridLayout(groupUser);
        gridLayout_2->setObjectName("gridLayout_2");
        labelAlltimeULText = new QLabel(groupUser);
        labelAlltimeULText->setObjectName("labelAlltimeULText");

        gridLayout_2->addWidget(labelAlltimeULText, 0, 0, 1, 1);

        labelAlltimeUL = new QLabel(groupUser);
        labelAlltimeUL->setObjectName("labelAlltimeUL");
        labelAlltimeUL->setText(QString::fromUtf8("TextLabel"));

        gridLayout_2->addWidget(labelAlltimeUL, 0, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelAlltimeDLText = new QLabel(groupUser);
        labelAlltimeDLText->setObjectName("labelAlltimeDLText");

        gridLayout_2->addWidget(labelAlltimeDLText, 1, 0, 1, 1);

        labelAlltimeDL = new QLabel(groupUser);
        labelAlltimeDL->setObjectName("labelAlltimeDL");
        labelAlltimeDL->setText(QString::fromUtf8("TextLabel"));

        gridLayout_2->addWidget(labelAlltimeDL, 1, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelGlobalRatioText = new QLabel(groupUser);
        labelGlobalRatioText->setObjectName("labelGlobalRatioText");

        gridLayout_2->addWidget(labelGlobalRatioText, 2, 0, 1, 1);

        labelGlobalRatio = new QLabel(groupUser);
        labelGlobalRatio->setObjectName("labelGlobalRatio");
        labelGlobalRatio->setText(QString::fromUtf8("TextLabel"));

        gridLayout_2->addWidget(labelGlobalRatio, 2, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelWasteText = new QLabel(groupUser);
        labelWasteText->setObjectName("labelWasteText");

        gridLayout_2->addWidget(labelWasteText, 3, 0, 1, 1);

        labelWaste = new QLabel(groupUser);
        labelWaste->setObjectName("labelWaste");
        labelWaste->setText(QString::fromUtf8("TextLabel"));

        gridLayout_2->addWidget(labelWaste, 3, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelPeersText = new QLabel(groupUser);
        labelPeersText->setObjectName("labelPeersText");

        gridLayout_2->addWidget(labelPeersText, 4, 0, 1, 1);

        labelPeers = new QLabel(groupUser);
        labelPeers->setObjectName("labelPeers");
        labelPeers->setText(QString::fromUtf8("TextLabel"));

        gridLayout_2->addWidget(labelPeers, 4, 1, 1, 1, Qt::AlignmentFlag::AlignRight);


        verticalLayout->addWidget(groupUser);

        groupCache = new QGroupBox(StatsDialog);
        groupCache->setObjectName("groupCache");
        gridLayout = new QGridLayout(groupCache);
        gridLayout->setObjectName("gridLayout");
        labelCacheHitsText = new QLabel(groupCache);
        labelCacheHitsText->setObjectName("labelCacheHitsText");

        gridLayout->addWidget(labelCacheHitsText, 0, 0, 1, 1);

        labelCacheHits = new QLabel(groupCache);
        labelCacheHits->setObjectName("labelCacheHits");
        labelCacheHits->setText(QString::fromUtf8("TextLabel"));

        gridLayout->addWidget(labelCacheHits, 0, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelTotalBufText = new QLabel(groupCache);
        labelTotalBufText->setObjectName("labelTotalBufText");

        gridLayout->addWidget(labelTotalBufText, 1, 0, 1, 1);

        labelTotalBuf = new QLabel(groupCache);
        labelTotalBuf->setObjectName("labelTotalBuf");
        labelTotalBuf->setText(QString::fromUtf8("TextLabel"));

        gridLayout->addWidget(labelTotalBuf, 1, 1, 1, 1, Qt::AlignmentFlag::AlignRight);


        verticalLayout->addWidget(groupCache);

        groupPerf = new QGroupBox(StatsDialog);
        groupPerf->setObjectName("groupPerf");
        gridLayout_3 = new QGridLayout(groupPerf);
        gridLayout_3->setObjectName("gridLayout_3");
        labelWriteStarveText = new QLabel(groupPerf);
        labelWriteStarveText->setObjectName("labelWriteStarveText");

        gridLayout_3->addWidget(labelWriteStarveText, 0, 0, 1, 1);

        labelWriteStarve = new QLabel(groupPerf);
        labelWriteStarve->setObjectName("labelWriteStarve");
        labelWriteStarve->setText(QString::fromUtf8("TextLabel"));

        gridLayout_3->addWidget(labelWriteStarve, 0, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelReadStarveText = new QLabel(groupPerf);
        labelReadStarveText->setObjectName("labelReadStarveText");

        gridLayout_3->addWidget(labelReadStarveText, 1, 0, 1, 1);

        labelReadStarve = new QLabel(groupPerf);
        labelReadStarve->setObjectName("labelReadStarve");
        labelReadStarve->setText(QString::fromUtf8("TextLabel"));

        gridLayout_3->addWidget(labelReadStarve, 1, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelQueuedJobsText = new QLabel(groupPerf);
        labelQueuedJobsText->setObjectName("labelQueuedJobsText");

        gridLayout_3->addWidget(labelQueuedJobsText, 2, 0, 1, 1);

        labelQueuedJobs = new QLabel(groupPerf);
        labelQueuedJobs->setObjectName("labelQueuedJobs");
        labelQueuedJobs->setText(QString::fromUtf8("TextLabel"));

        gridLayout_3->addWidget(labelQueuedJobs, 2, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelJobsTimeText = new QLabel(groupPerf);
        labelJobsTimeText->setObjectName("labelJobsTimeText");

        gridLayout_3->addWidget(labelJobsTimeText, 3, 0, 1, 1);

        labelJobsTime = new QLabel(groupPerf);
        labelJobsTime->setObjectName("labelJobsTime");
        labelJobsTime->setText(QString::fromUtf8("TextLabel"));

        gridLayout_3->addWidget(labelJobsTime, 3, 1, 1, 1, Qt::AlignmentFlag::AlignRight);

        labelQueuedBytesText = new QLabel(groupPerf);
        labelQueuedBytesText->setObjectName("labelQueuedBytesText");

        gridLayout_3->addWidget(labelQueuedBytesText, 4, 0, 1, 1);

        labelQueuedBytes = new QLabel(groupPerf);
        labelQueuedBytes->setObjectName("labelQueuedBytes");
        labelQueuedBytes->setText(QString::fromUtf8("TextLabel"));

        gridLayout_3->addWidget(labelQueuedBytes, 4, 1, 1, 1, Qt::AlignmentFlag::AlignRight);


        verticalLayout->addWidget(groupPerf);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(StatsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(StatsDialog);

        QMetaObject::connectSlotsByName(StatsDialog);
    } // setupUi

    void retranslateUi(QDialog *StatsDialog)
    {
        StatsDialog->setWindowTitle(QCoreApplication::translate("StatsDialog", "Statistics", nullptr));
        groupUser->setTitle(QCoreApplication::translate("StatsDialog", "User statistics", nullptr));
        labelAlltimeULText->setText(QCoreApplication::translate("StatsDialog", "All-time upload:", nullptr));
        labelAlltimeDLText->setText(QCoreApplication::translate("StatsDialog", "All-time download:", nullptr));
        labelGlobalRatioText->setText(QCoreApplication::translate("StatsDialog", "All-time share ratio:", nullptr));
        labelWasteText->setText(QCoreApplication::translate("StatsDialog", "Session waste:", nullptr));
        labelPeersText->setText(QCoreApplication::translate("StatsDialog", "Connected peers:", nullptr));
        groupCache->setTitle(QCoreApplication::translate("StatsDialog", "Cache statistics", nullptr));
        labelCacheHitsText->setText(QCoreApplication::translate("StatsDialog", "Read cache hits:", nullptr));
        labelTotalBufText->setText(QCoreApplication::translate("StatsDialog", "Total buffer size:", nullptr));
        groupPerf->setTitle(QCoreApplication::translate("StatsDialog", "Performance statistics", nullptr));
        labelWriteStarveText->setText(QCoreApplication::translate("StatsDialog", "Write cache overload:", nullptr));
        labelReadStarveText->setText(QCoreApplication::translate("StatsDialog", "Read cache overload:", nullptr));
        labelQueuedJobsText->setText(QCoreApplication::translate("StatsDialog", "Queued I/O jobs:", nullptr));
        labelJobsTimeText->setText(QCoreApplication::translate("StatsDialog", "Average time in queue:", nullptr));
        labelQueuedBytesText->setText(QCoreApplication::translate("StatsDialog", "Total queued size:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StatsDialog: public Ui_StatsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STATSDIALOG_H
