/********************************************************************************
** Form generated from reading UI file 'torrentcategorydialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TORRENTCATEGORYDIALOG_H
#define UI_TORRENTCATEGORYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "gui/fspathedit.h"
#include "gui/torrentsharelimitswidget.h"

QT_BEGIN_NAMESPACE

class Ui_TorrentCategoryDialog
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QGridLayout *gridLayout;
    QLabel *labelCategoryName;
    QLineEdit *textCategoryName;
    QLabel *labelSavePath;
    FileSystemPathComboEdit *comboSavePath;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *labelUseDownloadPath;
    QComboBox *comboUseDownloadPath;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *labelDownloadPath;
    FileSystemPathComboEdit *comboDownloadPath;
    QGroupBox *torrentShareLimitsBox;
    QVBoxLayout *torrentShareLimitsBoxLayout;
    TorrentShareLimitsWidget *torrentShareLimitsWidget;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TorrentCategoryDialog)
    {
        if (TorrentCategoryDialog->objectName().isEmpty())
            TorrentCategoryDialog->setObjectName("TorrentCategoryDialog");
        TorrentCategoryDialog->resize(493, 268);
        verticalLayout = new QVBoxLayout(TorrentCategoryDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelCategoryName = new QLabel(TorrentCategoryDialog);
        labelCategoryName->setObjectName("labelCategoryName");

        gridLayout->addWidget(labelCategoryName, 0, 0, 1, 1);

        textCategoryName = new QLineEdit(TorrentCategoryDialog);
        textCategoryName->setObjectName("textCategoryName");

        gridLayout->addWidget(textCategoryName, 0, 1, 1, 1);

        labelSavePath = new QLabel(TorrentCategoryDialog);
        labelSavePath->setObjectName("labelSavePath");

        gridLayout->addWidget(labelSavePath, 1, 0, 1, 1);

        comboSavePath = new FileSystemPathComboEdit(TorrentCategoryDialog);
        comboSavePath->setObjectName("comboSavePath");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboSavePath->sizePolicy().hasHeightForWidth());
        comboSavePath->setSizePolicy(sizePolicy);

        gridLayout->addWidget(comboSavePath, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        groupBox = new QGroupBox(TorrentCategoryDialog);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        labelUseDownloadPath = new QLabel(groupBox);
        labelUseDownloadPath->setObjectName("labelUseDownloadPath");

        horizontalLayout->addWidget(labelUseDownloadPath);

        comboUseDownloadPath = new QComboBox(groupBox);
        comboUseDownloadPath->addItem(QString());
        comboUseDownloadPath->addItem(QString());
        comboUseDownloadPath->addItem(QString());
        comboUseDownloadPath->setObjectName("comboUseDownloadPath");
        comboUseDownloadPath->setMaxVisibleItems(3);

        horizontalLayout->addWidget(comboUseDownloadPath);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        labelDownloadPath = new QLabel(groupBox);
        labelDownloadPath->setObjectName("labelDownloadPath");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelDownloadPath->sizePolicy().hasHeightForWidth());
        labelDownloadPath->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(labelDownloadPath);

        comboDownloadPath = new FileSystemPathComboEdit(groupBox);
        comboDownloadPath->setObjectName("comboDownloadPath");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(comboDownloadPath->sizePolicy().hasHeightForWidth());
        comboDownloadPath->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(comboDownloadPath);


        verticalLayout_2->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(groupBox);

        torrentShareLimitsBox = new QGroupBox(TorrentCategoryDialog);
        torrentShareLimitsBox->setObjectName("torrentShareLimitsBox");
        torrentShareLimitsBoxLayout = new QVBoxLayout(torrentShareLimitsBox);
        torrentShareLimitsBoxLayout->setObjectName("torrentShareLimitsBoxLayout");
        torrentShareLimitsWidget = new TorrentShareLimitsWidget(torrentShareLimitsBox);
        torrentShareLimitsWidget->setObjectName("torrentShareLimitsWidget");

        torrentShareLimitsBoxLayout->addWidget(torrentShareLimitsWidget);


        verticalLayout->addWidget(torrentShareLimitsBox);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        buttonBox = new QDialogButtonBox(TorrentCategoryDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TorrentCategoryDialog);

        QMetaObject::connectSlotsByName(TorrentCategoryDialog);
    } // setupUi

    void retranslateUi(QDialog *TorrentCategoryDialog)
    {
        TorrentCategoryDialog->setWindowTitle(QCoreApplication::translate("TorrentCategoryDialog", "Torrent Category Properties", nullptr));
        labelCategoryName->setText(QCoreApplication::translate("TorrentCategoryDialog", "Name:", nullptr));
        labelSavePath->setText(QCoreApplication::translate("TorrentCategoryDialog", "Save path:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("TorrentCategoryDialog", "Save path for incomplete torrents:", nullptr));
        labelUseDownloadPath->setText(QCoreApplication::translate("TorrentCategoryDialog", "Use another path for incomplete torrents:", nullptr));
        comboUseDownloadPath->setItemText(0, QCoreApplication::translate("TorrentCategoryDialog", "Default", nullptr));
        comboUseDownloadPath->setItemText(1, QCoreApplication::translate("TorrentCategoryDialog", "Yes", nullptr));
        comboUseDownloadPath->setItemText(2, QCoreApplication::translate("TorrentCategoryDialog", "No", nullptr));

        labelDownloadPath->setText(QCoreApplication::translate("TorrentCategoryDialog", "Path:", nullptr));
        torrentShareLimitsBox->setTitle(QCoreApplication::translate("TorrentCategoryDialog", "Torrent share limits", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TorrentCategoryDialog: public Ui_TorrentCategoryDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TORRENTCATEGORYDIALOG_H
