/********************************************************************************
** Form generated from reading UI file 'searchwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHWIDGET_H
#define UI_SEARCHWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/lineedit.h"

QT_BEGIN_NAMESPACE

class Ui_SearchWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *searchBarLayout;
    LineEdit *lineEditSearchPattern;
    QComboBox *comboCategory;
    QComboBox *selectPlugin;
    QPushButton *searchButton;
    QPushButton *stopButton;
    QStackedWidget *stackedPages;
    QWidget *emptyPage;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QWidget *searchPage;
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QHBoxLayout *layout2;
    QSpacerItem *spacer2;
    QPushButton *pluginsButton;

    void setupUi(QWidget *SearchWidget)
    {
        if (SearchWidget->objectName().isEmpty())
            SearchWidget->setObjectName("SearchWidget");
        SearchWidget->resize(843, 669);
        verticalLayout_3 = new QVBoxLayout(SearchWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        searchBarLayout = new QHBoxLayout();
        searchBarLayout->setObjectName("searchBarLayout");
        lineEditSearchPattern = new LineEdit(SearchWidget);
        lineEditSearchPattern->setObjectName("lineEditSearchPattern");

        searchBarLayout->addWidget(lineEditSearchPattern);

        comboCategory = new QComboBox(SearchWidget);
        comboCategory->setObjectName("comboCategory");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboCategory->sizePolicy().hasHeightForWidth());
        comboCategory->setSizePolicy(sizePolicy);

        searchBarLayout->addWidget(comboCategory);

        selectPlugin = new QComboBox(SearchWidget);
        selectPlugin->setObjectName("selectPlugin");
        sizePolicy.setHeightForWidth(selectPlugin->sizePolicy().hasHeightForWidth());
        selectPlugin->setSizePolicy(sizePolicy);

        searchBarLayout->addWidget(selectPlugin);

        searchButton = new QPushButton(SearchWidget);
        searchButton->setObjectName("searchButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(searchButton->sizePolicy().hasHeightForWidth());
        searchButton->setSizePolicy(sizePolicy1);

        searchBarLayout->addWidget(searchButton);

        stopButton = new QPushButton(SearchWidget);
        stopButton->setObjectName("stopButton");

        searchBarLayout->addWidget(stopButton);


        verticalLayout_3->addLayout(searchBarLayout);

        stackedPages = new QStackedWidget(SearchWidget);
        stackedPages->setObjectName("stackedPages");
        emptyPage = new QWidget();
        emptyPage->setObjectName("emptyPage");
        verticalLayout = new QVBoxLayout(emptyPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(emptyPage);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label);

        stackedPages->addWidget(emptyPage);
        searchPage = new QWidget();
        searchPage->setObjectName("searchPage");
        verticalLayout_2 = new QVBoxLayout(searchPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(searchPage);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setTabsClosable(true);
        tabWidget->setMovable(true);

        verticalLayout_2->addWidget(tabWidget);

        stackedPages->addWidget(searchPage);

        verticalLayout_3->addWidget(stackedPages);

        layout2 = new QHBoxLayout();
        layout2->setObjectName("layout2");
        spacer2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layout2->addItem(spacer2);

        pluginsButton = new QPushButton(SearchWidget);
        pluginsButton->setObjectName("pluginsButton");

        layout2->addWidget(pluginsButton);


        verticalLayout_3->addLayout(layout2);


        retranslateUi(SearchWidget);

        stackedPages->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(SearchWidget);
    } // setupUi

    void retranslateUi(QWidget *SearchWidget)
    {
        SearchWidget->setWindowTitle(QCoreApplication::translate("SearchWidget", "Search", nullptr));
        searchButton->setText(QCoreApplication::translate("SearchWidget", "Search", nullptr));
        stopButton->setText(QCoreApplication::translate("SearchWidget", "Stop", nullptr));
        label->setText(QCoreApplication::translate("SearchWidget", "There aren't any search plugins installed.\n"
"Click the \"Search plugins...\" button at the bottom right of the window to install some.", nullptr));
        pluginsButton->setText(QCoreApplication::translate("SearchWidget", "Search plugins...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SearchWidget: public Ui_SearchWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHWIDGET_H
