/****************************************************************************
** Meta object code from reading C++ file 'rsswidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/rss/rsswidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rsswidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9RSSWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto RSSWidget::qt_create_metaobjectdata<qt_meta_tag_ZN9RSSWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RSSWidget",
        "unreadCountUpdated",
        "",
        "count",
        "deleteSelectedItems",
        "updateRefreshInterval",
        "val",
        "on_newFeedButton_clicked",
        "refreshAllFeeds",
        "on_markReadButton_clicked",
        "displayRSSListMenu",
        "QPoint",
        "pos",
        "displayItemsListMenu",
        "renameSelectedRSSItem",
        "editSelectedRSSFeed",
        "refreshSelectedItems",
        "copySelectedFeedsURL",
        "handleCurrentFeedItemChanged",
        "QTreeWidgetItem*",
        "currentItem",
        "handleCurrentArticleItemChanged",
        "QListWidgetItem*",
        "previousItem",
        "openSelectedArticlesUrls",
        "downloadSelectedTorrents",
        "saveSlidersPosition",
        "restoreSlidersPosition",
        "askNewFolder",
        "saveFoldersOpenState",
        "loadFoldersOpenState",
        "on_rssDownloaderBtn_clicked",
        "handleSessionProcessingStateChanged",
        "enabled",
        "handleUnreadCountChanged",
        "handleRSSFilterTextChanged",
        "newFilter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'unreadCountUpdated'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'deleteSelectedItems'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateRefreshInterval'
        QtMocHelpers::SlotData<void(int) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'on_newFeedButton_clicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshAllFeeds'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_markReadButton_clicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayRSSListMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'displayItemsListMenu'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameSelectedRSSItem'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editSelectedRSSFeed'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshSelectedItems'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copySelectedFeedsURL'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleCurrentFeedItemChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'handleCurrentArticleItemChanged'
        QtMocHelpers::SlotData<void(QListWidgetItem *, QListWidgetItem *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 20 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'openSelectedArticlesUrls'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadSelectedTorrents'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSlidersPosition'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'restoreSlidersPosition'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'askNewFolder'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveFoldersOpenState'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadFoldersOpenState'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_rssDownloaderBtn_clicked'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSessionProcessingStateChanged'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'handleUnreadCountChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRSSFilterTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RSSWidget, qt_meta_tag_ZN9RSSWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RSSWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<GUIApplicationComponent<QWidget>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RSSWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RSSWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9RSSWidgetE_t>.metaTypes,
    nullptr
} };

void RSSWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RSSWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->unreadCountUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->deleteSelectedItems(); break;
        case 2: _t->updateRefreshInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->on_newFeedButton_clicked(); break;
        case 4: _t->refreshAllFeeds(); break;
        case 5: _t->on_markReadButton_clicked(); break;
        case 6: _t->displayRSSListMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 7: _t->displayItemsListMenu(); break;
        case 8: _t->renameSelectedRSSItem(); break;
        case 9: _t->editSelectedRSSFeed(); break;
        case 10: _t->refreshSelectedItems(); break;
        case 11: _t->copySelectedFeedsURL(); break;
        case 12: _t->handleCurrentFeedItemChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 13: _t->handleCurrentArticleItemChanged((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[2]))); break;
        case 14: _t->openSelectedArticlesUrls(); break;
        case 15: _t->downloadSelectedTorrents(); break;
        case 16: _t->saveSlidersPosition(); break;
        case 17: _t->restoreSlidersPosition(); break;
        case 18: _t->askNewFolder(); break;
        case 19: _t->saveFoldersOpenState(); break;
        case 20: _t->loadFoldersOpenState(); break;
        case 21: _t->on_rssDownloaderBtn_clicked(); break;
        case 22: _t->handleSessionProcessingStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->handleUnreadCountChanged(); break;
        case 24: _t->handleRSSFilterTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RSSWidget::*)(int )>(_a, &RSSWidget::unreadCountUpdated, 0))
            return;
    }
}

const QMetaObject *RSSWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RSSWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RSSWidgetE_t>.strings))
        return static_cast<void*>(this);
    return GUIApplicationComponent<QWidget>::qt_metacast(_clname);
}

int RSSWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GUIApplicationComponent<QWidget>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void RSSWidget::unreadCountUpdated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
