/****************************************************************************
** Meta object code from reading C++ file 'rss_session.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/base/rss/rss_session.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rss_session.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3RSS7SessionE_t {};
} // unnamed namespace

template <> constexpr inline auto RSS::Session::qt_create_metaobjectdata<qt_meta_tag_ZN3RSS7SessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RSS::Session",
        "processingStateChanged",
        "",
        "enabled",
        "maxArticlesPerFeedChanged",
        "n",
        "itemAdded",
        "Item*",
        "item",
        "itemPathChanged",
        "itemAboutToBeRemoved",
        "feedIconLoaded",
        "Feed*",
        "feed",
        "feedStateChanged",
        "feedURLChanged",
        "oldURL",
        "handleItemAboutToBeDestroyed",
        "handleFeedTitleChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'processingStateChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'maxArticlesPerFeedChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(Item *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'itemPathChanged'
        QtMocHelpers::SignalData<void(Item *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'itemAboutToBeRemoved'
        QtMocHelpers::SignalData<void(Item *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'feedIconLoaded'
        QtMocHelpers::SignalData<void(Feed *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'feedStateChanged'
        QtMocHelpers::SignalData<void(Feed *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'feedURLChanged'
        QtMocHelpers::SignalData<void(Feed *, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'handleItemAboutToBeDestroyed'
        QtMocHelpers::SlotData<void(Item *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'handleFeedTitleChanged'
        QtMocHelpers::SlotData<void(Feed *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Session, qt_meta_tag_ZN3RSS7SessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RSS::Session::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS7SessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS7SessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3RSS7SessionE_t>.metaTypes,
    nullptr
} };

void RSS::Session::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Session *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->processingStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->maxArticlesPerFeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<Item*>>(_a[1]))); break;
        case 3: _t->itemPathChanged((*reinterpret_cast<std::add_pointer_t<Item*>>(_a[1]))); break;
        case 4: _t->itemAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<Item*>>(_a[1]))); break;
        case 5: _t->feedIconLoaded((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 6: _t->feedStateChanged((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 7: _t->feedURLChanged((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->handleItemAboutToBeDestroyed((*reinterpret_cast<std::add_pointer_t<Item*>>(_a[1]))); break;
        case 9: _t->handleFeedTitleChanged((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Session::*)(bool )>(_a, &Session::processingStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(int )>(_a, &Session::maxArticlesPerFeedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Item * )>(_a, &Session::itemAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Item * )>(_a, &Session::itemPathChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Item * )>(_a, &Session::itemAboutToBeRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Feed * )>(_a, &Session::feedIconLoaded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Feed * )>(_a, &Session::feedStateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Feed * , const QString & )>(_a, &Session::feedURLChanged, 7))
            return;
    }
}

const QMetaObject *RSS::Session::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RSS::Session::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS7SessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RSS::Session::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void RSS::Session::processingStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void RSS::Session::maxArticlesPerFeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void RSS::Session::itemAdded(Item * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void RSS::Session::itemPathChanged(Item * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void RSS::Session::itemAboutToBeRemoved(Item * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void RSS::Session::feedIconLoaded(Feed * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void RSS::Session::feedStateChanged(Feed * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void RSS::Session::feedURLChanged(Feed * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
