/****************************************************************************
** Meta object code from reading C++ file 'optionsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/optionsdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'optionsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13OptionsDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto OptionsDialog::qt_create_metaobjectdata<qt_meta_tag_ZN13OptionsDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OptionsDialog",
        "showConnectionTab",
        "",
        "adjustProxyOptions",
        "on_buttonBox_accepted",
        "on_buttonBox_rejected",
        "enableApplyButton",
        "toggleComboRatioLimitAct",
        "changePage",
        "QListWidgetItem*",
        "loadSplitterState",
        "handleWatchedFolderViewSelectionChanged",
        "editWatchedFolderOptions",
        "QModelIndex",
        "index",
        "on_IpFilterRefreshBtn_clicked",
        "handleIPFilterParsed",
        "error",
        "ruleCount",
        "on_banListButton_clicked",
        "on_IPSubnetWhitelistButton_clicked",
        "on_randomButton_clicked",
        "on_addWatchedFolderButton_clicked",
        "on_editWatchedFolderButton_clicked",
        "on_removeWatchedFolderButton_clicked",
        "setLocale",
        "localeStr",
        "webUIHttpsCertChanged",
        "Path",
        "path",
        "webUIHttpsKeyChanged",
        "on_registerDNSBtn_clicked",
        "onBtnWebUIAPIKeyCopyClicked",
        "onBtnWebUIAPIKeyRotateClicked",
        "onBtnWebUIAPIKeyDeleteClicked",
        "setupWebUIAPIKey"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showConnectionTab'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adjustProxyOptions'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_buttonBox_accepted'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_buttonBox_rejected'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableApplyButton'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleComboRatioLimitAct'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changePage'
        QtMocHelpers::SlotData<void(QListWidgetItem *, QListWidgetItem *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Slot 'loadSplitterState'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleWatchedFolderViewSelectionChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editWatchedFolderOptions'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'on_IpFilterRefreshBtn_clicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleIPFilterParsed'
        QtMocHelpers::SlotData<void(bool, int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'on_banListButton_clicked'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_IPSubnetWhitelistButton_clicked'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_randomButton_clicked'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_addWatchedFolderButton_clicked'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_editWatchedFolderButton_clicked'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_removeWatchedFolderButton_clicked'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLocale'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'webUIHttpsCertChanged'
        QtMocHelpers::SlotData<void(const Path &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'webUIHttpsKeyChanged'
        QtMocHelpers::SlotData<void(const Path &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'on_registerDNSBtn_clicked'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBtnWebUIAPIKeyCopyClicked'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBtnWebUIAPIKeyRotateClicked'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBtnWebUIAPIKeyDeleteClicked'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setupWebUIAPIKey'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OptionsDialog, qt_meta_tag_ZN13OptionsDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OptionsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<GUIApplicationComponent<QDialog>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13OptionsDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13OptionsDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13OptionsDialogE_t>.metaTypes,
    nullptr
} };

void OptionsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OptionsDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showConnectionTab(); break;
        case 1: _t->adjustProxyOptions(); break;
        case 2: _t->on_buttonBox_accepted(); break;
        case 3: _t->on_buttonBox_rejected(); break;
        case 4: _t->enableApplyButton(); break;
        case 5: _t->toggleComboRatioLimitAct(); break;
        case 6: _t->changePage((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[2]))); break;
        case 7: _t->loadSplitterState(); break;
        case 8: _t->handleWatchedFolderViewSelectionChanged(); break;
        case 9: _t->editWatchedFolderOptions((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->on_IpFilterRefreshBtn_clicked(); break;
        case 11: _t->handleIPFilterParsed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->on_banListButton_clicked(); break;
        case 13: _t->on_IPSubnetWhitelistButton_clicked(); break;
        case 14: _t->on_randomButton_clicked(); break;
        case 15: _t->on_addWatchedFolderButton_clicked(); break;
        case 16: _t->on_editWatchedFolderButton_clicked(); break;
        case 17: _t->on_removeWatchedFolderButton_clicked(); break;
        case 18: _t->setLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->webUIHttpsCertChanged((*reinterpret_cast<std::add_pointer_t<Path>>(_a[1]))); break;
        case 20: _t->webUIHttpsKeyChanged((*reinterpret_cast<std::add_pointer_t<Path>>(_a[1]))); break;
        case 21: _t->on_registerDNSBtn_clicked(); break;
        case 22: _t->onBtnWebUIAPIKeyCopyClicked(); break;
        case 23: _t->onBtnWebUIAPIKeyRotateClicked(); break;
        case 24: _t->onBtnWebUIAPIKeyDeleteClicked(); break;
        case 25: _t->setupWebUIAPIKey(); break;
        default: ;
        }
    }
}

const QMetaObject *OptionsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OptionsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13OptionsDialogE_t>.strings))
        return static_cast<void*>(this);
    return GUIApplicationComponent<QDialog>::qt_metacast(_clname);
}

int OptionsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GUIApplicationComponent<QDialog>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}
QT_WARNING_POP
