/****************************************************************************
** Meta object code from reading C++ file 'propertieswidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/properties/propertieswidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'propertieswidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16PropertiesWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto PropertiesWidget::qt_create_metaobjectdata<qt_meta_tag_ZN16PropertiesWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PropertiesWidget",
        "setVisibility",
        "",
        "visible",
        "loadTorrentInfos",
        "BitTorrent::Torrent*",
        "torrent",
        "loadDynamicData",
        "clear",
        "readSettings",
        "saveSettings",
        "reloadPreferences",
        "updateTorrentInfos",
        "loadUrlSeeds",
        "askWebSeed",
        "deleteSelectedUrlSeeds",
        "copySelectedWebSeedsToClipboard",
        "editWebSeed",
        "displayWebSeedListMenu",
        "showPiecesDownloaded",
        "show",
        "showPiecesAvailability",
        "configure",
        "updateSavePath"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setVisibility'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'loadTorrentInfos'
        QtMocHelpers::SlotData<void(BitTorrent::Torrent *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'loadDynamicData'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveSettings'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadPreferences'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTorrentInfos'
        QtMocHelpers::SlotData<void(BitTorrent::Torrent *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'loadUrlSeeds'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'askWebSeed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'deleteSelectedUrlSeeds'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'copySelectedWebSeedsToClipboard'
        QtMocHelpers::SlotData<void() const>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'editWebSeed'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'displayWebSeedListMenu'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showPiecesDownloaded'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'showPiecesAvailability'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'configure'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSavePath'
        QtMocHelpers::SlotData<void(BitTorrent::Torrent *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PropertiesWidget, qt_meta_tag_ZN16PropertiesWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PropertiesWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PropertiesWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PropertiesWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16PropertiesWidgetE_t>.metaTypes,
    nullptr
} };

void PropertiesWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PropertiesWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->loadTorrentInfos((*reinterpret_cast<std::add_pointer_t<BitTorrent::Torrent*>>(_a[1]))); break;
        case 2: _t->loadDynamicData(); break;
        case 3: _t->clear(); break;
        case 4: _t->readSettings(); break;
        case 5: _t->saveSettings(); break;
        case 6: _t->reloadPreferences(); break;
        case 7: _t->updateTorrentInfos((*reinterpret_cast<std::add_pointer_t<BitTorrent::Torrent*>>(_a[1]))); break;
        case 8: _t->loadUrlSeeds(); break;
        case 9: _t->askWebSeed(); break;
        case 10: _t->deleteSelectedUrlSeeds(); break;
        case 11: _t->copySelectedWebSeedsToClipboard(); break;
        case 12: _t->editWebSeed(); break;
        case 13: _t->displayWebSeedListMenu(); break;
        case 14: _t->showPiecesDownloaded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->showPiecesAvailability((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->configure(); break;
        case 17: _t->updateSavePath((*reinterpret_cast<std::add_pointer_t<BitTorrent::Torrent*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PropertiesWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PropertiesWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PropertiesWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int PropertiesWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
