/********************************************************************************
** Form generated from reading UI file 'addtorrentparamswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDTORRENTPARAMSWIDGET_H
#define UI_ADDTORRENTPARAMSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/fspathedit.h"
#include "gui/torrentsharelimitswidget.h"

QT_BEGIN_NAMESPACE

class Ui_AddTorrentParamsWidget
{
public:
    QVBoxLayout *mainLayout;
    QHBoxLayout *managementLayout;
    QLabel *labelTorrentManagementMode;
    QComboBox *comboTTM;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBoxSavePath;
    QVBoxLayout *verticalLayout;
    QLabel *defaultsNoteLabel;
    FileSystemPathLineEdit *savePathEdit;
    QHBoxLayout *downloadPathLayout;
    QLabel *useDownloadPathLabel;
    QComboBox *useDownloadPathComboBox;
    QSpacerItem *downloadPathSpacer;
    FileSystemPathLineEdit *downloadPathEdit;
    QHBoxLayout *categoryLayout;
    QLabel *labelCategory;
    QComboBox *categoryComboBox;
    QSpacerItem *categorySpacer;
    QHBoxLayout *tagsLayout;
    QLabel *tagsLabel;
    QLineEdit *tagsLineEdit;
    QToolButton *tagsEditButton;
    QWidget *miscParamsWidget;
    QWidget *startTorrentWidget;
    QHBoxLayout *horizontalLayout_2;
    QLabel *startTorrentLabel;
    QComboBox *startTorrentComboBox;
    QWidget *contentLayoutWidget;
    QHBoxLayout *contentLayoutLayout;
    QLabel *contentLayoutLabel;
    QComboBox *contentLayoutComboBox;
    QWidget *stopConditionWidget;
    QHBoxLayout *stopConditionLayout;
    QLabel *stopConditionLabel;
    QComboBox *stopConditionComboBox;
    QWidget *addToQueueTopWidget;
    QHBoxLayout *addToQueueTopLayout;
    QLabel *addToQueueTopLabel;
    QComboBox *addToQueueTopComboBox;
    QCheckBox *skipCheckingCheckBox;
    QGroupBox *torrentShareLimitsBox;
    QVBoxLayout *torrentShareLimitsBoxLayout;
    TorrentShareLimitsWidget *torrentShareLimitsWidget;

    void setupUi(QWidget *AddTorrentParamsWidget)
    {
        if (AddTorrentParamsWidget->objectName().isEmpty())
            AddTorrentParamsWidget->setObjectName("AddTorrentParamsWidget");
        AddTorrentParamsWidget->resize(503, 440);
        mainLayout = new QVBoxLayout(AddTorrentParamsWidget);
        mainLayout->setObjectName("mainLayout");
        managementLayout = new QHBoxLayout();
        managementLayout->setObjectName("managementLayout");
        labelTorrentManagementMode = new QLabel(AddTorrentParamsWidget);
        labelTorrentManagementMode->setObjectName("labelTorrentManagementMode");

        managementLayout->addWidget(labelTorrentManagementMode);

        comboTTM = new QComboBox(AddTorrentParamsWidget);
        comboTTM->setObjectName("comboTTM");

        managementLayout->addWidget(comboTTM);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        managementLayout->addItem(horizontalSpacer);


        mainLayout->addLayout(managementLayout);

        groupBoxSavePath = new QGroupBox(AddTorrentParamsWidget);
        groupBoxSavePath->setObjectName("groupBoxSavePath");
        verticalLayout = new QVBoxLayout(groupBoxSavePath);
        verticalLayout->setObjectName("verticalLayout");
        defaultsNoteLabel = new QLabel(groupBoxSavePath);
        defaultsNoteLabel->setObjectName("defaultsNoteLabel");
        QFont font;
        font.setItalic(true);
        defaultsNoteLabel->setFont(font);

        verticalLayout->addWidget(defaultsNoteLabel);

        savePathEdit = new FileSystemPathLineEdit(groupBoxSavePath);
        savePathEdit->setObjectName("savePathEdit");

        verticalLayout->addWidget(savePathEdit);

        downloadPathLayout = new QHBoxLayout();
        downloadPathLayout->setObjectName("downloadPathLayout");
        useDownloadPathLabel = new QLabel(groupBoxSavePath);
        useDownloadPathLabel->setObjectName("useDownloadPathLabel");

        downloadPathLayout->addWidget(useDownloadPathLabel);

        useDownloadPathComboBox = new QComboBox(groupBoxSavePath);
        useDownloadPathComboBox->setObjectName("useDownloadPathComboBox");

        downloadPathLayout->addWidget(useDownloadPathComboBox);

        downloadPathSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        downloadPathLayout->addItem(downloadPathSpacer);


        verticalLayout->addLayout(downloadPathLayout);

        downloadPathEdit = new FileSystemPathLineEdit(groupBoxSavePath);
        downloadPathEdit->setObjectName("downloadPathEdit");

        verticalLayout->addWidget(downloadPathEdit);


        mainLayout->addWidget(groupBoxSavePath);

        categoryLayout = new QHBoxLayout();
        categoryLayout->setObjectName("categoryLayout");
        labelCategory = new QLabel(AddTorrentParamsWidget);
        labelCategory->setObjectName("labelCategory");

        categoryLayout->addWidget(labelCategory);

        categoryComboBox = new QComboBox(AddTorrentParamsWidget);
        categoryComboBox->setObjectName("categoryComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(categoryComboBox->sizePolicy().hasHeightForWidth());
        categoryComboBox->setSizePolicy(sizePolicy);
        categoryComboBox->setEditable(true);
        categoryComboBox->setInsertPolicy(QComboBox::InsertPolicy::InsertAtTop);

        categoryLayout->addWidget(categoryComboBox);

        categorySpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        categoryLayout->addItem(categorySpacer);

        categoryLayout->setStretch(1, 2);
        categoryLayout->setStretch(2, 1);

        mainLayout->addLayout(categoryLayout);

        tagsLayout = new QHBoxLayout();
        tagsLayout->setObjectName("tagsLayout");
        tagsLabel = new QLabel(AddTorrentParamsWidget);
        tagsLabel->setObjectName("tagsLabel");

        tagsLayout->addWidget(tagsLabel);

        tagsLineEdit = new QLineEdit(AddTorrentParamsWidget);
        tagsLineEdit->setObjectName("tagsLineEdit");
        sizePolicy.setHeightForWidth(tagsLineEdit->sizePolicy().hasHeightForWidth());
        tagsLineEdit->setSizePolicy(sizePolicy);
        tagsLineEdit->setReadOnly(true);
        tagsLineEdit->setClearButtonEnabled(false);

        tagsLayout->addWidget(tagsLineEdit);

        tagsEditButton = new QToolButton(AddTorrentParamsWidget);
        tagsEditButton->setObjectName("tagsEditButton");

        tagsLayout->addWidget(tagsEditButton);


        mainLayout->addLayout(tagsLayout);

        miscParamsWidget = new QWidget(AddTorrentParamsWidget);
        miscParamsWidget->setObjectName("miscParamsWidget");
        startTorrentWidget = new QWidget(miscParamsWidget);
        startTorrentWidget->setObjectName("startTorrentWidget");
        startTorrentWidget->setGeometry(QRect(9, 65, 143, 22));
        horizontalLayout_2 = new QHBoxLayout(startTorrentWidget);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 2, 0);
        startTorrentLabel = new QLabel(startTorrentWidget);
        startTorrentLabel->setObjectName("startTorrentLabel");

        horizontalLayout_2->addWidget(startTorrentLabel);

        startTorrentComboBox = new QComboBox(startTorrentWidget);
        startTorrentComboBox->setObjectName("startTorrentComboBox");

        horizontalLayout_2->addWidget(startTorrentComboBox);

        contentLayoutWidget = new QWidget(miscParamsWidget);
        contentLayoutWidget->setObjectName("contentLayoutWidget");
        contentLayoutWidget->setGeometry(QRect(9, 9, 159, 22));
        contentLayoutLayout = new QHBoxLayout(contentLayoutWidget);
        contentLayoutLayout->setObjectName("contentLayoutLayout");
        contentLayoutLayout->setContentsMargins(0, 0, 2, 0);
        contentLayoutLabel = new QLabel(contentLayoutWidget);
        contentLayoutLabel->setObjectName("contentLayoutLabel");

        contentLayoutLayout->addWidget(contentLayoutLabel);

        contentLayoutComboBox = new QComboBox(contentLayoutWidget);
        contentLayoutComboBox->setObjectName("contentLayoutComboBox");

        contentLayoutLayout->addWidget(contentLayoutComboBox);

        stopConditionWidget = new QWidget(miscParamsWidget);
        stopConditionWidget->setObjectName("stopConditionWidget");
        stopConditionWidget->setGeometry(QRect(9, 93, 158, 22));
        stopConditionLayout = new QHBoxLayout(stopConditionWidget);
        stopConditionLayout->setObjectName("stopConditionLayout");
        stopConditionLayout->setContentsMargins(0, 0, 2, 0);
        stopConditionLabel = new QLabel(stopConditionWidget);
        stopConditionLabel->setObjectName("stopConditionLabel");

        stopConditionLayout->addWidget(stopConditionLabel);

        stopConditionComboBox = new QComboBox(stopConditionWidget);
        stopConditionComboBox->setObjectName("stopConditionComboBox");

        stopConditionLayout->addWidget(stopConditionComboBox);

        addToQueueTopWidget = new QWidget(miscParamsWidget);
        addToQueueTopWidget->setObjectName("addToQueueTopWidget");
        addToQueueTopWidget->setGeometry(QRect(9, 121, 187, 22));
        addToQueueTopLayout = new QHBoxLayout(addToQueueTopWidget);
        addToQueueTopLayout->setObjectName("addToQueueTopLayout");
        addToQueueTopLayout->setContentsMargins(0, 0, 2, 0);
        addToQueueTopLabel = new QLabel(addToQueueTopWidget);
        addToQueueTopLabel->setObjectName("addToQueueTopLabel");

        addToQueueTopLayout->addWidget(addToQueueTopLabel);

        addToQueueTopComboBox = new QComboBox(addToQueueTopWidget);
        addToQueueTopComboBox->setObjectName("addToQueueTopComboBox");

        addToQueueTopLayout->addWidget(addToQueueTopComboBox);

        skipCheckingCheckBox = new QCheckBox(miscParamsWidget);
        skipCheckingCheckBox->setObjectName("skipCheckingCheckBox");
        skipCheckingCheckBox->setGeometry(QRect(10, 30, 83, 21));

        mainLayout->addWidget(miscParamsWidget);

        torrentShareLimitsBox = new QGroupBox(AddTorrentParamsWidget);
        torrentShareLimitsBox->setObjectName("torrentShareLimitsBox");
        torrentShareLimitsBoxLayout = new QVBoxLayout(torrentShareLimitsBox);
        torrentShareLimitsBoxLayout->setObjectName("torrentShareLimitsBoxLayout");
        torrentShareLimitsWidget = new TorrentShareLimitsWidget(torrentShareLimitsBox);
        torrentShareLimitsWidget->setObjectName("torrentShareLimitsWidget");

        torrentShareLimitsBoxLayout->addWidget(torrentShareLimitsWidget);


        mainLayout->addWidget(torrentShareLimitsBox);


        retranslateUi(AddTorrentParamsWidget);

        startTorrentComboBox->setCurrentIndex(-1);
        contentLayoutComboBox->setCurrentIndex(-1);
        stopConditionComboBox->setCurrentIndex(-1);
        addToQueueTopComboBox->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(AddTorrentParamsWidget);
    } // setupUi

    void retranslateUi(QWidget *AddTorrentParamsWidget)
    {
        AddTorrentParamsWidget->setWindowTitle(QCoreApplication::translate("AddTorrentParamsWidget", "Form", nullptr));
        labelTorrentManagementMode->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Torrent Management Mode:", nullptr));
#if QT_CONFIG(tooltip)
        comboTTM->setToolTip(QCoreApplication::translate("AddTorrentParamsWidget", "Automatic mode means that various torrent properties(eg save path) will be decided by the associated category", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxSavePath->setTitle(QCoreApplication::translate("AddTorrentParamsWidget", "Save at", nullptr));
        defaultsNoteLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Note: the current defaults are displayed for reference.", nullptr));
        useDownloadPathLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Use another path for incomplete torrents:", nullptr));
        labelCategory->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Category:", nullptr));
        tagsLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Tags:", nullptr));
        tagsLineEdit->setPlaceholderText(QCoreApplication::translate("AddTorrentParamsWidget", "Click [...] button to add/remove tags.", nullptr));
#if QT_CONFIG(tooltip)
        tagsEditButton->setToolTip(QCoreApplication::translate("AddTorrentParamsWidget", "Add/remove tags", nullptr));
#endif // QT_CONFIG(tooltip)
        tagsEditButton->setText(QCoreApplication::translate("AddTorrentParamsWidget", "...", nullptr));
        startTorrentLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Start torrent:", nullptr));
        contentLayoutLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Content layout:", nullptr));
        stopConditionLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Stop condition:", nullptr));
        addToQueueTopLabel->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Add to top of queue:", nullptr));
        skipCheckingCheckBox->setText(QCoreApplication::translate("AddTorrentParamsWidget", "Skip hash check", nullptr));
        torrentShareLimitsBox->setTitle(QCoreApplication::translate("AddTorrentParamsWidget", "Torrent share limits", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddTorrentParamsWidget: public Ui_AddTorrentParamsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDTORRENTPARAMSWIDGET_H
