/********************************************************************************
** Form generated from reading UI file 'automatedrssdownloader.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOMATEDRSSDOWNLOADER_H
#define UI_AUTOMATEDRSSDOWNLOADER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AutomatedRssDownloader
{
public:
    QVBoxLayout *verticalLayout_4;
    QLabel *labelWarn;
    QSplitter *mainSplitter;
    QWidget *ruleListLayoutWidget;
    QVBoxLayout *ruleListLayout;
    QHBoxLayout *ruleListHeaderLayout;
    QLabel *ruleListLabel;
    QToolButton *renameRuleBtn;
    QToolButton *removeRuleBtn;
    QToolButton *addRuleBtn;
    QListWidget *ruleList;
    QSplitter *ruleDefSplitter;
    QScrollArea *ruleScrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *priorityLayout;
    QLabel *priorityLabel;
    QSpinBox *prioritySpinBox;
    QSpacerItem *prioritySpacer;
    QCheckBox *checkRegex;
    QGridLayout *gridLayout;
    QLabel *labelMustContain;
    QLineEdit *lineContains;
    QLabel *labelMustStat;
    QLabel *labelMustNotContain;
    QLineEdit *lineNotContains;
    QLabel *labelMustNotStat;
    QLabel *lblEFilter;
    QLineEdit *lineEFilter;
    QLabel *lblEFilterStat;
    QLabel *labelEpFilterStat;
    QCheckBox *checkSmart;
    QHBoxLayout *ignorePeriodLayout;
    QLabel *lblIgnoreDays;
    QSpinBox *spinIgnorePeriod;
    QLabel *lblLastMatch;
    QGroupBox *torrentParametersGroupBox;
    QVBoxLayout *verticalLayout_7;
    QSpacerItem *verticalSpacer;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QLabel *lblListFeeds;
    QListWidget *listFeeds;
    QWidget *matchingArticlesLayoutWidget;
    QVBoxLayout *matchingArticlesLayout;
    QLabel *matchingArticlesLabel;
    QTreeWidget *matchingArticlesTree;
    QHBoxLayout *buttonsLayout;
    QPushButton *importBtn;
    QPushButton *exportBtn;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AutomatedRssDownloader)
    {
        if (AutomatedRssDownloader->objectName().isEmpty())
            AutomatedRssDownloader->setObjectName("AutomatedRssDownloader");
        AutomatedRssDownloader->resize(818, 588);
        verticalLayout_4 = new QVBoxLayout(AutomatedRssDownloader);
        verticalLayout_4->setObjectName("verticalLayout_4");
        labelWarn = new QLabel(AutomatedRssDownloader);
        labelWarn->setObjectName("labelWarn");
        QFont font;
        font.setItalic(true);
        labelWarn->setFont(font);
        labelWarn->setStyleSheet(QString::fromUtf8("color: red;"));
        labelWarn->setWordWrap(true);

        verticalLayout_4->addWidget(labelWarn);

        mainSplitter = new QSplitter(AutomatedRssDownloader);
        mainSplitter->setObjectName("mainSplitter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mainSplitter->sizePolicy().hasHeightForWidth());
        mainSplitter->setSizePolicy(sizePolicy);
        mainSplitter->setOrientation(Qt::Orientation::Horizontal);
        ruleListLayoutWidget = new QWidget(mainSplitter);
        ruleListLayoutWidget->setObjectName("ruleListLayoutWidget");
        ruleListLayout = new QVBoxLayout(ruleListLayoutWidget);
        ruleListLayout->setObjectName("ruleListLayout");
        ruleListLayout->setContentsMargins(0, 0, 0, 0);
        ruleListHeaderLayout = new QHBoxLayout();
        ruleListHeaderLayout->setObjectName("ruleListHeaderLayout");
        ruleListLabel = new QLabel(ruleListLayoutWidget);
        ruleListLabel->setObjectName("ruleListLabel");
        QFont font1;
        font1.setBold(true);
        ruleListLabel->setFont(font1);

        ruleListHeaderLayout->addWidget(ruleListLabel);

        renameRuleBtn = new QToolButton(ruleListLayoutWidget);
        renameRuleBtn->setObjectName("renameRuleBtn");
        renameRuleBtn->setEnabled(false);
        renameRuleBtn->setIconSize(QSize(24, 20));

        ruleListHeaderLayout->addWidget(renameRuleBtn);

        removeRuleBtn = new QToolButton(ruleListLayoutWidget);
        removeRuleBtn->setObjectName("removeRuleBtn");
        removeRuleBtn->setIconSize(QSize(24, 20));

        ruleListHeaderLayout->addWidget(removeRuleBtn);

        addRuleBtn = new QToolButton(ruleListLayoutWidget);
        addRuleBtn->setObjectName("addRuleBtn");
        addRuleBtn->setIconSize(QSize(24, 20));

        ruleListHeaderLayout->addWidget(addRuleBtn);


        ruleListLayout->addLayout(ruleListHeaderLayout);

        ruleList = new QListWidget(ruleListLayoutWidget);
        ruleList->setObjectName("ruleList");
        ruleList->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);

        ruleListLayout->addWidget(ruleList);

        mainSplitter->addWidget(ruleListLayoutWidget);
        ruleDefSplitter = new QSplitter(mainSplitter);
        ruleDefSplitter->setObjectName("ruleDefSplitter");
        ruleDefSplitter->setOrientation(Qt::Orientation::Vertical);
        ruleScrollArea = new QScrollArea(ruleDefSplitter);
        ruleScrollArea->setObjectName("ruleScrollArea");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ruleScrollArea->sizePolicy().hasHeightForWidth());
        ruleScrollArea->setSizePolicy(sizePolicy1);
        ruleScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOn);
        ruleScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAsNeeded);
        ruleScrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContentsOnFirstShow);
        ruleScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 370, 277));
        verticalLayout_8 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_8->setObjectName("verticalLayout_8");
        priorityLayout = new QHBoxLayout();
        priorityLayout->setObjectName("priorityLayout");
        priorityLabel = new QLabel(scrollAreaWidgetContents);
        priorityLabel->setObjectName("priorityLabel");

        priorityLayout->addWidget(priorityLabel);

        prioritySpinBox = new QSpinBox(scrollAreaWidgetContents);
        prioritySpinBox->setObjectName("prioritySpinBox");

        priorityLayout->addWidget(prioritySpinBox);

        prioritySpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        priorityLayout->addItem(prioritySpacer);


        verticalLayout_8->addLayout(priorityLayout);

        checkRegex = new QCheckBox(scrollAreaWidgetContents);
        checkRegex->setObjectName("checkRegex");

        verticalLayout_8->addWidget(checkRegex);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelMustContain = new QLabel(scrollAreaWidgetContents);
        labelMustContain->setObjectName("labelMustContain");

        gridLayout->addWidget(labelMustContain, 0, 0, 1, 1);

        lineContains = new QLineEdit(scrollAreaWidgetContents);
        lineContains->setObjectName("lineContains");

        gridLayout->addWidget(lineContains, 0, 1, 1, 1);

        labelMustStat = new QLabel(scrollAreaWidgetContents);
        labelMustStat->setObjectName("labelMustStat");
        labelMustStat->setMaximumSize(QSize(18, 18));

        gridLayout->addWidget(labelMustStat, 0, 2, 1, 1);

        labelMustNotContain = new QLabel(scrollAreaWidgetContents);
        labelMustNotContain->setObjectName("labelMustNotContain");

        gridLayout->addWidget(labelMustNotContain, 1, 0, 1, 1);

        lineNotContains = new QLineEdit(scrollAreaWidgetContents);
        lineNotContains->setObjectName("lineNotContains");

        gridLayout->addWidget(lineNotContains, 1, 1, 1, 1);

        labelMustNotStat = new QLabel(scrollAreaWidgetContents);
        labelMustNotStat->setObjectName("labelMustNotStat");
        labelMustNotStat->setMaximumSize(QSize(18, 18));

        gridLayout->addWidget(labelMustNotStat, 1, 2, 1, 1);

        lblEFilter = new QLabel(scrollAreaWidgetContents);
        lblEFilter->setObjectName("lblEFilter");

        gridLayout->addWidget(lblEFilter, 2, 0, 1, 1);

        lineEFilter = new QLineEdit(scrollAreaWidgetContents);
        lineEFilter->setObjectName("lineEFilter");

        gridLayout->addWidget(lineEFilter, 2, 1, 1, 1);

        lblEFilterStat = new QLabel(scrollAreaWidgetContents);
        lblEFilterStat->setObjectName("lblEFilterStat");
        lblEFilterStat->setMaximumSize(QSize(18, 18));

        gridLayout->addWidget(lblEFilterStat, 2, 2, 1, 1);

        labelEpFilterStat = new QLabel(scrollAreaWidgetContents);
        labelEpFilterStat->setObjectName("labelEpFilterStat");
        labelEpFilterStat->setMaximumSize(QSize(18, 18));

        gridLayout->addWidget(labelEpFilterStat, 2, 2, 1, 1);


        verticalLayout_8->addLayout(gridLayout);

        checkSmart = new QCheckBox(scrollAreaWidgetContents);
        checkSmart->setObjectName("checkSmart");

        verticalLayout_8->addWidget(checkSmart);

        ignorePeriodLayout = new QHBoxLayout();
        ignorePeriodLayout->setObjectName("ignorePeriodLayout");
        lblIgnoreDays = new QLabel(scrollAreaWidgetContents);
        lblIgnoreDays->setObjectName("lblIgnoreDays");

        ignorePeriodLayout->addWidget(lblIgnoreDays);

        spinIgnorePeriod = new QSpinBox(scrollAreaWidgetContents);
        spinIgnorePeriod->setObjectName("spinIgnorePeriod");
        spinIgnorePeriod->setEnabled(true);
        spinIgnorePeriod->setMinimum(0);
        spinIgnorePeriod->setMaximum(365);

        ignorePeriodLayout->addWidget(spinIgnorePeriod);


        verticalLayout_8->addLayout(ignorePeriodLayout);

        lblLastMatch = new QLabel(scrollAreaWidgetContents);
        lblLastMatch->setObjectName("lblLastMatch");
        lblLastMatch->setEnabled(true);
        lblLastMatch->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        verticalLayout_8->addWidget(lblLastMatch);

        torrentParametersGroupBox = new QGroupBox(scrollAreaWidgetContents);
        torrentParametersGroupBox->setObjectName("torrentParametersGroupBox");
        torrentParametersGroupBox->setFlat(true);
        verticalLayout_7 = new QVBoxLayout(torrentParametersGroupBox);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);

        verticalLayout_8->addWidget(torrentParametersGroupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer);

        verticalLayout_8->setStretch(7, 1);
        ruleScrollArea->setWidget(scrollAreaWidgetContents);
        ruleDefSplitter->addWidget(ruleScrollArea);
        layoutWidget = new QWidget(ruleDefSplitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        lblListFeeds = new QLabel(layoutWidget);
        lblListFeeds->setObjectName("lblListFeeds");
        QFont font2;
        font2.setBold(false);
        lblListFeeds->setFont(font2);

        verticalLayout->addWidget(lblListFeeds);

        listFeeds = new QListWidget(layoutWidget);
        listFeeds->setObjectName("listFeeds");

        verticalLayout->addWidget(listFeeds);

        ruleDefSplitter->addWidget(layoutWidget);
        mainSplitter->addWidget(ruleDefSplitter);
        matchingArticlesLayoutWidget = new QWidget(mainSplitter);
        matchingArticlesLayoutWidget->setObjectName("matchingArticlesLayoutWidget");
        matchingArticlesLayout = new QVBoxLayout(matchingArticlesLayoutWidget);
        matchingArticlesLayout->setObjectName("matchingArticlesLayout");
        matchingArticlesLayout->setContentsMargins(0, 0, 0, 0);
        matchingArticlesLabel = new QLabel(matchingArticlesLayoutWidget);
        matchingArticlesLabel->setObjectName("matchingArticlesLabel");
        matchingArticlesLabel->setFont(font1);

        matchingArticlesLayout->addWidget(matchingArticlesLabel);

        matchingArticlesTree = new QTreeWidget(matchingArticlesLayoutWidget);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        matchingArticlesTree->setHeaderItem(__qtreewidgetitem);
        matchingArticlesTree->setObjectName("matchingArticlesTree");
        matchingArticlesTree->header()->setVisible(false);

        matchingArticlesLayout->addWidget(matchingArticlesTree);

        mainSplitter->addWidget(matchingArticlesLayoutWidget);

        verticalLayout_4->addWidget(mainSplitter);

        buttonsLayout = new QHBoxLayout();
        buttonsLayout->setObjectName("buttonsLayout");
        importBtn = new QPushButton(AutomatedRssDownloader);
        importBtn->setObjectName("importBtn");
        importBtn->setEnabled(true);

        buttonsLayout->addWidget(importBtn);

        exportBtn = new QPushButton(AutomatedRssDownloader);
        exportBtn->setObjectName("exportBtn");
        exportBtn->setEnabled(true);

        buttonsLayout->addWidget(exportBtn);

        buttonBox = new QDialogButtonBox(AutomatedRssDownloader);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Close);

        buttonsLayout->addWidget(buttonBox);


        verticalLayout_4->addLayout(buttonsLayout);


        retranslateUi(AutomatedRssDownloader);

        QMetaObject::connectSlotsByName(AutomatedRssDownloader);
    } // setupUi

    void retranslateUi(QDialog *AutomatedRssDownloader)
    {
        AutomatedRssDownloader->setWindowTitle(QCoreApplication::translate("AutomatedRssDownloader", "RSS Downloader", nullptr));
        labelWarn->setText(QCoreApplication::translate("AutomatedRssDownloader", "Auto downloading of RSS torrents is currently disabled. You can enable it in application settings.", nullptr));
        ruleListLabel->setText(QCoreApplication::translate("AutomatedRssDownloader", "Download Rules", nullptr));
#if QT_CONFIG(tooltip)
        renameRuleBtn->setToolTip(QCoreApplication::translate("AutomatedRssDownloader", "Rename selected rule. You can also use the F2 hotkey to rename.", nullptr));
#endif // QT_CONFIG(tooltip)
        priorityLabel->setText(QCoreApplication::translate("AutomatedRssDownloader", "Priority:", nullptr));
        checkRegex->setText(QCoreApplication::translate("AutomatedRssDownloader", "Use Regular Expressions", nullptr));
        labelMustContain->setText(QCoreApplication::translate("AutomatedRssDownloader", "Must Contain:", nullptr));
        labelMustNotContain->setText(QCoreApplication::translate("AutomatedRssDownloader", "Must Not Contain:", nullptr));
        lblEFilter->setText(QCoreApplication::translate("AutomatedRssDownloader", "Episode Filter:", nullptr));
#if QT_CONFIG(tooltip)
        checkSmart->setToolTip(QCoreApplication::translate("AutomatedRssDownloader", "Smart Episode Filter will check the episode number to prevent downloading of duplicates.\n"
"Supports the formats: S01E01, 1x1, 2017.12.31 and 31.12.2017 (Date formats also support - as a separator)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkSmart->setText(QCoreApplication::translate("AutomatedRssDownloader", "Use Smart Episode Filter", nullptr));
        lblIgnoreDays->setText(QCoreApplication::translate("AutomatedRssDownloader", "Ignore Subsequent Matches for (0 to Disable)", nullptr));
        spinIgnorePeriod->setSpecialValueText(QCoreApplication::translate("AutomatedRssDownloader", "Disabled", nullptr));
        spinIgnorePeriod->setSuffix(QCoreApplication::translate("AutomatedRssDownloader", " days", nullptr));
        torrentParametersGroupBox->setTitle(QCoreApplication::translate("AutomatedRssDownloader", "Torrent parameters", nullptr));
        lblListFeeds->setText(QCoreApplication::translate("AutomatedRssDownloader", "Apply Rule to Feeds:", nullptr));
        matchingArticlesLabel->setText(QCoreApplication::translate("AutomatedRssDownloader", "Matching RSS Articles", nullptr));
        importBtn->setText(QCoreApplication::translate("AutomatedRssDownloader", "&Import...", nullptr));
        exportBtn->setText(QCoreApplication::translate("AutomatedRssDownloader", "&Export...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AutomatedRssDownloader: public Ui_AutomatedRssDownloader {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOMATEDRSSDOWNLOADER_H
