/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/mainwindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "showFilterContextMenu",
        "",
        "desktopNotificationClicked",
        "saveSettings",
        "loadSettings",
        "saveSplitterSettings",
        "tabChanged",
        "newTab",
        "defineUILockPassword",
        "clearUILockPassword",
        "unlockUI",
        "notifyOfUpdate",
        "showConnectionSettings",
        "minimizeWindow",
        "createKeyboardShortcuts",
        "displayTransferTab",
        "displaySearchTab",
        "displayRSSTab",
        "displayExecutionLogTab",
        "toggleFocusBetweenLineEdits",
        "loadSessionStats",
        "reloadTorrentStats",
        "QList<BitTorrent::Torrent*>",
        "torrents",
        "loadPreferences",
        "optionsSaved",
        "toggleAlternativeSpeeds",
        "addToolbarContextMenu",
        "manageCookies",
        "downloadFromURLList",
        "urlList",
        "updateAltSpeedsBtn",
        "alternative",
        "updateNbTorrents",
        "handleRSSUnreadCountUpdated",
        "count",
        "on_actionSearchWidget_triggered",
        "on_actionRSSReader_triggered",
        "on_actionSpeedInTitleBar_triggered",
        "on_actionTopToolBar_triggered",
        "on_actionShowStatusbar_triggered",
        "on_actionShowFiltersSidebar_triggered",
        "checked",
        "on_actionDonateMoney_triggered",
        "on_actionExecutionLogs_triggered",
        "on_actionNormalMessages_triggered",
        "on_actionInformationMessages_triggered",
        "on_actionWarningMessages_triggered",
        "on_actionCriticalMessages_triggered",
        "on_actionAutoExit_toggled",
        "on_actionAutoSuspend_toggled",
        "on_actionAutoHibernate_toggled",
        "on_actionAutoShutdown_toggled",
        "on_actionAutoReboot_toggled",
        "on_actionAbout_triggered",
        "on_actionStatistics_triggered",
        "on_actionCreateTorrent_triggered",
        "on_actionOptions_triggered",
        "on_actionSetGlobalSpeedLimits_triggered",
        "on_actionDocumentation_triggered",
        "on_actionOpen_triggered",
        "on_actionDownloadFromURL_triggered",
        "on_actionExit_triggered",
        "on_actionLock_triggered",
        "updatePowerManagementState",
        "toolbarMenuRequested",
        "toolbarIconsOnly",
        "toolbarTextOnly",
        "toolbarTextBeside",
        "toolbarTextUnder",
        "toolbarFollowSystem",
        "toggleVisibility"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showFilterContextMenu'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'desktopNotificationClicked'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSettings'
        QtMocHelpers::SlotData<void() const>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSplitterSettings'
        QtMocHelpers::SlotData<void() const>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tabChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'defineUILockPassword'
        QtMocHelpers::SlotData<bool()>(9, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'clearUILockPassword'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unlockUI'
        QtMocHelpers::SlotData<bool()>(11, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'notifyOfUpdate'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'showConnectionSettings'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'minimizeWindow'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createKeyboardShortcuts'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayTransferTab'
        QtMocHelpers::SlotData<void() const>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displaySearchTab'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayRSSTab'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayExecutionLogTab'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFocusBetweenLineEdits'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadSessionStats'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadTorrentStats'
        QtMocHelpers::SlotData<void(const QList<BitTorrent::Torrent*> &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'loadPreferences'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'optionsSaved'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleAlternativeSpeeds'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addToolbarContextMenu'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'manageCookies'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadFromURLList'
        QtMocHelpers::SlotData<void(const QStringList &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 31 },
        }}),
        // Slot 'updateAltSpeedsBtn'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'updateNbTorrents'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRSSUnreadCountUpdated'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'on_actionSearchWidget_triggered'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRSSReader_triggered'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSpeedInTitleBar_triggered'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionTopToolBar_triggered'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShowStatusbar_triggered'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShowFiltersSidebar_triggered'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'on_actionDonateMoney_triggered'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExecutionLogs_triggered'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'on_actionNormalMessages_triggered'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'on_actionInformationMessages_triggered'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'on_actionWarningMessages_triggered'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'on_actionCriticalMessages_triggered'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'on_actionAutoExit_toggled'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'on_actionAutoSuspend_toggled'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'on_actionAutoHibernate_toggled'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'on_actionAutoShutdown_toggled'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'on_actionAutoReboot_toggled'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'on_actionAbout_triggered'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionStatistics_triggered'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCreateTorrent_triggered'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOptions_triggered'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetGlobalSpeedLimits_triggered'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDocumentation_triggered'
        QtMocHelpers::SlotData<void() const>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOpen_triggered'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDownloadFromURL_triggered'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExit_triggered'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLock_triggered'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePowerManagementState'
        QtMocHelpers::SlotData<void() const>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarMenuRequested'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarIconsOnly'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarTextOnly'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarTextBeside'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarTextUnder'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarFollowSystem'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleVisibility'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<GUIApplicationComponent<QMainWindow>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showFilterContextMenu(); break;
        case 1: _t->desktopNotificationClicked(); break;
        case 2: _t->saveSettings(); break;
        case 3: _t->loadSettings(); break;
        case 4: _t->saveSplitterSettings(); break;
        case 5: _t->tabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: { bool _r = _t->defineUILockPassword();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->clearUILockPassword(); break;
        case 8: { bool _r = _t->unlockUI();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->notifyOfUpdate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->showConnectionSettings(); break;
        case 11: _t->minimizeWindow(); break;
        case 12: _t->createKeyboardShortcuts(); break;
        case 13: _t->displayTransferTab(); break;
        case 14: _t->displaySearchTab(); break;
        case 15: _t->displayRSSTab(); break;
        case 16: _t->displayExecutionLogTab(); break;
        case 17: _t->toggleFocusBetweenLineEdits(); break;
        case 18: _t->loadSessionStats(); break;
        case 19: _t->reloadTorrentStats((*reinterpret_cast<std::add_pointer_t<QList<BitTorrent::Torrent*>>>(_a[1]))); break;
        case 20: _t->loadPreferences(); break;
        case 21: _t->optionsSaved(); break;
        case 22: _t->toggleAlternativeSpeeds(); break;
        case 23: _t->addToolbarContextMenu(); break;
        case 24: _t->manageCookies(); break;
        case 25: _t->downloadFromURLList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 26: _t->updateAltSpeedsBtn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->updateNbTorrents(); break;
        case 28: _t->handleRSSUnreadCountUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->on_actionSearchWidget_triggered(); break;
        case 30: _t->on_actionRSSReader_triggered(); break;
        case 31: _t->on_actionSpeedInTitleBar_triggered(); break;
        case 32: _t->on_actionTopToolBar_triggered(); break;
        case 33: _t->on_actionShowStatusbar_triggered(); break;
        case 34: _t->on_actionShowFiltersSidebar_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->on_actionDonateMoney_triggered(); break;
        case 36: _t->on_actionExecutionLogs_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->on_actionNormalMessages_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->on_actionInformationMessages_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->on_actionWarningMessages_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->on_actionCriticalMessages_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->on_actionAutoExit_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->on_actionAutoSuspend_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->on_actionAutoHibernate_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->on_actionAutoShutdown_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->on_actionAutoReboot_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->on_actionAbout_triggered(); break;
        case 47: _t->on_actionStatistics_triggered(); break;
        case 48: _t->on_actionCreateTorrent_triggered(); break;
        case 49: _t->on_actionOptions_triggered(); break;
        case 50: _t->on_actionSetGlobalSpeedLimits_triggered(); break;
        case 51: _t->on_actionDocumentation_triggered(); break;
        case 52: _t->on_actionOpen_triggered(); break;
        case 53: _t->on_actionDownloadFromURL_triggered(); break;
        case 54: _t->on_actionExit_triggered(); break;
        case 55: _t->on_actionLock_triggered(); break;
        case 56: _t->updatePowerManagementState(); break;
        case 57: _t->toolbarMenuRequested(); break;
        case 58: _t->toolbarIconsOnly(); break;
        case 59: _t->toolbarTextOnly(); break;
        case 60: _t->toolbarTextBeside(); break;
        case 61: _t->toolbarTextUnder(); break;
        case 62: _t->toolbarFollowSystem(); break;
        case 63: _t->toggleVisibility(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<BitTorrent::Torrent*> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return GUIApplicationComponent<QMainWindow>::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GUIApplicationComponent<QMainWindow>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    return _id;
}
QT_WARNING_POP
