/********************************************************************************
** Form generated from reading UI file 'stacktracedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STACKTRACEDIALOG_H
#define UI_STACKTRACEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_StacktraceDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTextBrowser *errorText;

    void setupUi(QDialog *StacktraceDialog)
    {
        if (StacktraceDialog->objectName().isEmpty())
            StacktraceDialog->setObjectName("StacktraceDialog");
        StacktraceDialog->resize(640, 480);
        verticalLayout = new QVBoxLayout(StacktraceDialog);
        verticalLayout->setObjectName("verticalLayout");
        errorText = new QTextBrowser(StacktraceDialog);
        errorText->setObjectName("errorText");
        errorText->setOpenExternalLinks(true);

        verticalLayout->addWidget(errorText);


        retranslateUi(StacktraceDialog);

        QMetaObject::connectSlotsByName(StacktraceDialog);
    } // setupUi

    void retranslateUi(QDialog *StacktraceDialog)
    {
        StacktraceDialog->setWindowTitle(QCoreApplication::translate("StacktraceDialog", "Crash info", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StacktraceDialog: public Ui_StacktraceDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STACKTRACEDIALOG_H
