/********************************************************************************
** Form generated from reading UI file 'watchedfolderoptionsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WATCHEDFOLDEROPTIONSDIALOG_H
#define UI_WATCHEDFOLDEROPTIONSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_WatchedFolderOptionsDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *checkBoxRecursive;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBoxParameters;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *WatchedFolderOptionsDialog)
    {
        if (WatchedFolderOptionsDialog->objectName().isEmpty())
            WatchedFolderOptionsDialog->setObjectName("WatchedFolderOptionsDialog");
        WatchedFolderOptionsDialog->resize(462, 392);
        verticalLayout_3 = new QVBoxLayout(WatchedFolderOptionsDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        checkBoxRecursive = new QCheckBox(WatchedFolderOptionsDialog);
        checkBoxRecursive->setObjectName("checkBoxRecursive");

        horizontalLayout_6->addWidget(checkBoxRecursive);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout_6);

        groupBoxParameters = new QGroupBox(WatchedFolderOptionsDialog);
        groupBoxParameters->setObjectName("groupBoxParameters");
        verticalLayout_2 = new QVBoxLayout(groupBoxParameters);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);

        verticalLayout_3->addWidget(groupBoxParameters);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonBox = new QDialogButtonBox(WatchedFolderOptionsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout_3->addLayout(horizontalLayout);


        retranslateUi(WatchedFolderOptionsDialog);

        QMetaObject::connectSlotsByName(WatchedFolderOptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *WatchedFolderOptionsDialog)
    {
        WatchedFolderOptionsDialog->setWindowTitle(QCoreApplication::translate("WatchedFolderOptionsDialog", "Watched Folder Options", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRecursive->setToolTip(QCoreApplication::translate("WatchedFolderOptionsDialog", "<html><head/><body><p>Will watch the folder and all its subfolders. In Manual torrent management mode it will also add subfolder name to the selected Save path.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxRecursive->setText(QCoreApplication::translate("WatchedFolderOptionsDialog", "Recursive mode", nullptr));
        groupBoxParameters->setTitle(QCoreApplication::translate("WatchedFolderOptionsDialog", "Torrent parameters", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WatchedFolderOptionsDialog: public Ui_WatchedFolderOptionsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WATCHEDFOLDEROPTIONSDIALOG_H
