/********************************************************************************
** Form generated from reading UI file 'propertieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROPERTIESWIDGET_H
#define UI_PROPERTIESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/torrentcontentwidget.h"

QT_BEGIN_NAMESPACE

class Ui_PropertiesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackedProperties;
    QWidget *pageGeneral;
    QVBoxLayout *verticalLayout_7;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QWidget *groupBar;
    QGridLayout *groupBarLayout;
    QLabel *labelDownloadedPieces;
    QLabel *tempProgressBarArea;
    QLabel *labelProgressVal;
    QLabel *labelPiecesAvailability;
    QLabel *tempAvailabilityBarArea;
    QLabel *labelAverageAvailabilityVal;
    QFrame *lineBelowBars;
    QGroupBox *groupTransferBox;
    QGridLayout *gridLayout_2;
    QLabel *labelTimeActive;
    QLabel *labelElapsedVal;
    QLabel *labelETA;
    QLabel *labelETAVal;
    QLabel *labelConnections;
    QLabel *labelConnectionsVal;
    QLabel *labelDownloaded;
    QLabel *labelDlTotalVal;
    QLabel *labelUploaded;
    QLabel *labelUpTotalVal;
    QLabel *labelSeeds;
    QLabel *labelSeedsVal;
    QLabel *labelDlSpeed;
    QLabel *labelDlSpeedVal;
    QLabel *labelUpSpeed;
    QLabel *labelUpSpeedVal;
    QLabel *labelPeers;
    QLabel *labelPeersVal;
    QLabel *labelDlLimit;
    QLabel *labelDlLimitVal;
    QLabel *labelUpLimit;
    QLabel *labelUpLimitVal;
    QLabel *labelWasted;
    QLabel *labelWastedVal;
    QLabel *labelRatio;
    QLabel *labelShareRatioVal;
    QLabel *labelReannounceIn;
    QLabel *labelReannounceInVal;
    QLabel *labelLastSeenComplete;
    QLabel *labelLastSeenCompleteVal;
    QLabel *labelPopularity;
    QLabel *labelPopularityVal;
    QGroupBox *groupInfosBox;
    QGridLayout *gridLayout;
    QLabel *labelTotalSize;
    QLabel *labelTotalSizeVal;
    QLabel *labelTotalPieces;
    QLabel *labelTotalPiecesVal;
    QLabel *labelCreatedBy;
    QLabel *labelCreatedByVal;
    QLabel *labelAddedOn;
    QLabel *labelAddedOnVal;
    QLabel *labelCompletedOn;
    QLabel *labelCompletedOnVal;
    QLabel *labelCreatedOn;
    QLabel *labelCreatedOnVal;
    QLabel *labelPrivate;
    QLabel *labelPrivateVal;
    QLabel *labelInfohash1;
    QLabel *labelInfohash1Val;
    QLabel *labelInfohash2;
    QLabel *labelInfohash2Val;
    QLabel *labelSavePath;
    QLabel *labelSavePathVal;
    QLabel *labelComment;
    QLabel *labelCommentVal;
    QWidget *pageTrackers;
    QHBoxLayout *hBoxLayoutTrackers;
    QVBoxLayout *verticalLayout_10;
    QSpacerItem *verticalSpacer_2;
    QPushButton *trackerUpButton;
    QPushButton *trackerDownButton;
    QSpacerItem *verticalSpacer_3;
    QWidget *pagePeers;
    QVBoxLayout *vBoxLayoutPeerPage;
    QWidget *pageSources;
    QVBoxLayout *verticalLayout_9;
    QListWidget *listWebSeeds;
    QWidget *pageContents;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *contentFilterLayout;
    QPushButton *selectAllButton;
    QPushButton *selectNoneButton;
    QSpacerItem *horizontalSpacer;
    TorrentContentWidget *filesList;
    QWidget *pageSpeed;
    QVBoxLayout *speedLayout;

    void setupUi(QWidget *PropertiesWidget)
    {
        if (PropertiesWidget->objectName().isEmpty())
            PropertiesWidget->setObjectName("PropertiesWidget");
        PropertiesWidget->resize(551, 452);
        verticalLayout = new QVBoxLayout(PropertiesWidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        stackedProperties = new QStackedWidget(PropertiesWidget);
        stackedProperties->setObjectName("stackedProperties");
        pageGeneral = new QWidget();
        pageGeneral->setObjectName("pageGeneral");
        verticalLayout_7 = new QVBoxLayout(pageGeneral);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(pageGeneral);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 549, 450));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBar = new QWidget(scrollAreaWidgetContents);
        groupBar->setObjectName("groupBar");
        groupBarLayout = new QGridLayout(groupBar);
        groupBarLayout->setObjectName("groupBarLayout");
        groupBarLayout->setContentsMargins(-1, 4, -1, 4);
        labelDownloadedPieces = new QLabel(groupBar);
        labelDownloadedPieces->setObjectName("labelDownloadedPieces");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelDownloadedPieces->sizePolicy().hasHeightForWidth());
        labelDownloadedPieces->setSizePolicy(sizePolicy);
        labelDownloadedPieces->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        groupBarLayout->addWidget(labelDownloadedPieces, 0, 0, 1, 1);

        tempProgressBarArea = new QLabel(groupBar);
        tempProgressBarArea->setObjectName("tempProgressBarArea");
        tempProgressBarArea->setTextFormat(Qt::TextFormat::PlainText);

        groupBarLayout->addWidget(tempProgressBarArea, 0, 1, 1, 1);

        labelProgressVal = new QLabel(groupBar);
        labelProgressVal->setObjectName("labelProgressVal");
        sizePolicy.setHeightForWidth(labelProgressVal->sizePolicy().hasHeightForWidth());
        labelProgressVal->setSizePolicy(sizePolicy);
        labelProgressVal->setTextFormat(Qt::TextFormat::PlainText);

        groupBarLayout->addWidget(labelProgressVal, 0, 2, 1, 1);

        labelPiecesAvailability = new QLabel(groupBar);
        labelPiecesAvailability->setObjectName("labelPiecesAvailability");
        sizePolicy.setHeightForWidth(labelPiecesAvailability->sizePolicy().hasHeightForWidth());
        labelPiecesAvailability->setSizePolicy(sizePolicy);
        labelPiecesAvailability->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        groupBarLayout->addWidget(labelPiecesAvailability, 1, 0, 1, 1);

        tempAvailabilityBarArea = new QLabel(groupBar);
        tempAvailabilityBarArea->setObjectName("tempAvailabilityBarArea");
        tempAvailabilityBarArea->setTextFormat(Qt::TextFormat::PlainText);

        groupBarLayout->addWidget(tempAvailabilityBarArea, 1, 1, 1, 1);

        labelAverageAvailabilityVal = new QLabel(groupBar);
        labelAverageAvailabilityVal->setObjectName("labelAverageAvailabilityVal");
        sizePolicy.setHeightForWidth(labelAverageAvailabilityVal->sizePolicy().hasHeightForWidth());
        labelAverageAvailabilityVal->setSizePolicy(sizePolicy);
        labelAverageAvailabilityVal->setTextFormat(Qt::TextFormat::PlainText);

        groupBarLayout->addWidget(labelAverageAvailabilityVal, 1, 2, 1, 1);


        verticalLayout_2->addWidget(groupBar);

        lineBelowBars = new QFrame(scrollAreaWidgetContents);
        lineBelowBars->setObjectName("lineBelowBars");
        lineBelowBars->setFrameShape(QFrame::Shape::HLine);
        lineBelowBars->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(lineBelowBars);

        groupTransferBox = new QGroupBox(scrollAreaWidgetContents);
        groupTransferBox->setObjectName("groupTransferBox");
        gridLayout_2 = new QGridLayout(groupTransferBox);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(-1, 4, -1, 4);
        labelTimeActive = new QLabel(groupTransferBox);
        labelTimeActive->setObjectName("labelTimeActive");
        sizePolicy.setHeightForWidth(labelTimeActive->sizePolicy().hasHeightForWidth());
        labelTimeActive->setSizePolicy(sizePolicy);
        labelTimeActive->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelTimeActive, 0, 0, 1, 1);

        labelElapsedVal = new QLabel(groupTransferBox);
        labelElapsedVal->setObjectName("labelElapsedVal");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelElapsedVal->sizePolicy().hasHeightForWidth());
        labelElapsedVal->setSizePolicy(sizePolicy1);
        labelElapsedVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelElapsedVal, 0, 1, 1, 1);

        labelETA = new QLabel(groupTransferBox);
        labelETA->setObjectName("labelETA");
        sizePolicy.setHeightForWidth(labelETA->sizePolicy().hasHeightForWidth());
        labelETA->setSizePolicy(sizePolicy);
        labelETA->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelETA, 0, 2, 1, 1);

        labelETAVal = new QLabel(groupTransferBox);
        labelETAVal->setObjectName("labelETAVal");
        sizePolicy1.setHeightForWidth(labelETAVal->sizePolicy().hasHeightForWidth());
        labelETAVal->setSizePolicy(sizePolicy1);
        labelETAVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelETAVal, 0, 3, 1, 1);

        labelConnections = new QLabel(groupTransferBox);
        labelConnections->setObjectName("labelConnections");
        sizePolicy.setHeightForWidth(labelConnections->sizePolicy().hasHeightForWidth());
        labelConnections->setSizePolicy(sizePolicy);
        labelConnections->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelConnections, 0, 4, 1, 1);

        labelConnectionsVal = new QLabel(groupTransferBox);
        labelConnectionsVal->setObjectName("labelConnectionsVal");
        sizePolicy1.setHeightForWidth(labelConnectionsVal->sizePolicy().hasHeightForWidth());
        labelConnectionsVal->setSizePolicy(sizePolicy1);
        labelConnectionsVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelConnectionsVal, 0, 5, 1, 1);

        labelDownloaded = new QLabel(groupTransferBox);
        labelDownloaded->setObjectName("labelDownloaded");
        sizePolicy.setHeightForWidth(labelDownloaded->sizePolicy().hasHeightForWidth());
        labelDownloaded->setSizePolicy(sizePolicy);
        labelDownloaded->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelDownloaded, 1, 0, 1, 1);

        labelDlTotalVal = new QLabel(groupTransferBox);
        labelDlTotalVal->setObjectName("labelDlTotalVal");
        sizePolicy1.setHeightForWidth(labelDlTotalVal->sizePolicy().hasHeightForWidth());
        labelDlTotalVal->setSizePolicy(sizePolicy1);
        labelDlTotalVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelDlTotalVal, 1, 1, 1, 1);

        labelUploaded = new QLabel(groupTransferBox);
        labelUploaded->setObjectName("labelUploaded");
        sizePolicy.setHeightForWidth(labelUploaded->sizePolicy().hasHeightForWidth());
        labelUploaded->setSizePolicy(sizePolicy);
        labelUploaded->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelUploaded, 1, 2, 1, 1);

        labelUpTotalVal = new QLabel(groupTransferBox);
        labelUpTotalVal->setObjectName("labelUpTotalVal");
        sizePolicy1.setHeightForWidth(labelUpTotalVal->sizePolicy().hasHeightForWidth());
        labelUpTotalVal->setSizePolicy(sizePolicy1);
        labelUpTotalVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelUpTotalVal, 1, 3, 1, 1);

        labelSeeds = new QLabel(groupTransferBox);
        labelSeeds->setObjectName("labelSeeds");
        sizePolicy.setHeightForWidth(labelSeeds->sizePolicy().hasHeightForWidth());
        labelSeeds->setSizePolicy(sizePolicy);
        labelSeeds->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelSeeds, 1, 4, 1, 1);

        labelSeedsVal = new QLabel(groupTransferBox);
        labelSeedsVal->setObjectName("labelSeedsVal");
        sizePolicy1.setHeightForWidth(labelSeedsVal->sizePolicy().hasHeightForWidth());
        labelSeedsVal->setSizePolicy(sizePolicy1);
        labelSeedsVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelSeedsVal, 1, 5, 1, 1);

        labelDlSpeed = new QLabel(groupTransferBox);
        labelDlSpeed->setObjectName("labelDlSpeed");
        sizePolicy.setHeightForWidth(labelDlSpeed->sizePolicy().hasHeightForWidth());
        labelDlSpeed->setSizePolicy(sizePolicy);
        labelDlSpeed->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelDlSpeed, 2, 0, 1, 1);

        labelDlSpeedVal = new QLabel(groupTransferBox);
        labelDlSpeedVal->setObjectName("labelDlSpeedVal");
        sizePolicy1.setHeightForWidth(labelDlSpeedVal->sizePolicy().hasHeightForWidth());
        labelDlSpeedVal->setSizePolicy(sizePolicy1);
        labelDlSpeedVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelDlSpeedVal, 2, 1, 1, 1);

        labelUpSpeed = new QLabel(groupTransferBox);
        labelUpSpeed->setObjectName("labelUpSpeed");
        sizePolicy.setHeightForWidth(labelUpSpeed->sizePolicy().hasHeightForWidth());
        labelUpSpeed->setSizePolicy(sizePolicy);
        labelUpSpeed->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelUpSpeed, 2, 2, 1, 1);

        labelUpSpeedVal = new QLabel(groupTransferBox);
        labelUpSpeedVal->setObjectName("labelUpSpeedVal");
        sizePolicy1.setHeightForWidth(labelUpSpeedVal->sizePolicy().hasHeightForWidth());
        labelUpSpeedVal->setSizePolicy(sizePolicy1);
        labelUpSpeedVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelUpSpeedVal, 2, 3, 1, 1);

        labelPeers = new QLabel(groupTransferBox);
        labelPeers->setObjectName("labelPeers");
        sizePolicy.setHeightForWidth(labelPeers->sizePolicy().hasHeightForWidth());
        labelPeers->setSizePolicy(sizePolicy);
        labelPeers->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelPeers, 2, 4, 1, 1);

        labelPeersVal = new QLabel(groupTransferBox);
        labelPeersVal->setObjectName("labelPeersVal");
        sizePolicy1.setHeightForWidth(labelPeersVal->sizePolicy().hasHeightForWidth());
        labelPeersVal->setSizePolicy(sizePolicy1);
        labelPeersVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelPeersVal, 2, 5, 1, 1);

        labelDlLimit = new QLabel(groupTransferBox);
        labelDlLimit->setObjectName("labelDlLimit");
        sizePolicy.setHeightForWidth(labelDlLimit->sizePolicy().hasHeightForWidth());
        labelDlLimit->setSizePolicy(sizePolicy);
        labelDlLimit->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelDlLimit, 3, 0, 1, 1);

        labelDlLimitVal = new QLabel(groupTransferBox);
        labelDlLimitVal->setObjectName("labelDlLimitVal");
        sizePolicy1.setHeightForWidth(labelDlLimitVal->sizePolicy().hasHeightForWidth());
        labelDlLimitVal->setSizePolicy(sizePolicy1);
        labelDlLimitVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelDlLimitVal, 3, 1, 1, 1);

        labelUpLimit = new QLabel(groupTransferBox);
        labelUpLimit->setObjectName("labelUpLimit");
        sizePolicy.setHeightForWidth(labelUpLimit->sizePolicy().hasHeightForWidth());
        labelUpLimit->setSizePolicy(sizePolicy);
        labelUpLimit->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelUpLimit, 3, 2, 1, 1);

        labelUpLimitVal = new QLabel(groupTransferBox);
        labelUpLimitVal->setObjectName("labelUpLimitVal");
        sizePolicy1.setHeightForWidth(labelUpLimitVal->sizePolicy().hasHeightForWidth());
        labelUpLimitVal->setSizePolicy(sizePolicy1);
        labelUpLimitVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelUpLimitVal, 3, 3, 1, 1);

        labelWasted = new QLabel(groupTransferBox);
        labelWasted->setObjectName("labelWasted");
        sizePolicy.setHeightForWidth(labelWasted->sizePolicy().hasHeightForWidth());
        labelWasted->setSizePolicy(sizePolicy);
        labelWasted->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelWasted, 3, 4, 1, 1);

        labelWastedVal = new QLabel(groupTransferBox);
        labelWastedVal->setObjectName("labelWastedVal");
        sizePolicy1.setHeightForWidth(labelWastedVal->sizePolicy().hasHeightForWidth());
        labelWastedVal->setSizePolicy(sizePolicy1);
        labelWastedVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelWastedVal, 3, 5, 1, 1);

        labelRatio = new QLabel(groupTransferBox);
        labelRatio->setObjectName("labelRatio");
        sizePolicy.setHeightForWidth(labelRatio->sizePolicy().hasHeightForWidth());
        labelRatio->setSizePolicy(sizePolicy);
        labelRatio->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelRatio, 4, 0, 1, 1);

        labelShareRatioVal = new QLabel(groupTransferBox);
        labelShareRatioVal->setObjectName("labelShareRatioVal");
        sizePolicy1.setHeightForWidth(labelShareRatioVal->sizePolicy().hasHeightForWidth());
        labelShareRatioVal->setSizePolicy(sizePolicy1);
        labelShareRatioVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelShareRatioVal, 4, 1, 1, 1);

        labelReannounceIn = new QLabel(groupTransferBox);
        labelReannounceIn->setObjectName("labelReannounceIn");
        sizePolicy.setHeightForWidth(labelReannounceIn->sizePolicy().hasHeightForWidth());
        labelReannounceIn->setSizePolicy(sizePolicy);
        labelReannounceIn->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelReannounceIn, 4, 2, 1, 1);

        labelReannounceInVal = new QLabel(groupTransferBox);
        labelReannounceInVal->setObjectName("labelReannounceInVal");
        sizePolicy1.setHeightForWidth(labelReannounceInVal->sizePolicy().hasHeightForWidth());
        labelReannounceInVal->setSizePolicy(sizePolicy1);
        labelReannounceInVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelReannounceInVal, 4, 3, 1, 1);

        labelLastSeenComplete = new QLabel(groupTransferBox);
        labelLastSeenComplete->setObjectName("labelLastSeenComplete");
        sizePolicy.setHeightForWidth(labelLastSeenComplete->sizePolicy().hasHeightForWidth());
        labelLastSeenComplete->setSizePolicy(sizePolicy);
        labelLastSeenComplete->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelLastSeenComplete, 4, 4, 1, 1);

        labelLastSeenCompleteVal = new QLabel(groupTransferBox);
        labelLastSeenCompleteVal->setObjectName("labelLastSeenCompleteVal");
        sizePolicy1.setHeightForWidth(labelLastSeenCompleteVal->sizePolicy().hasHeightForWidth());
        labelLastSeenCompleteVal->setSizePolicy(sizePolicy1);
        labelLastSeenCompleteVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelLastSeenCompleteVal, 4, 5, 1, 1);

        labelPopularity = new QLabel(groupTransferBox);
        labelPopularity->setObjectName("labelPopularity");
        sizePolicy.setHeightForWidth(labelPopularity->sizePolicy().hasHeightForWidth());
        labelPopularity->setSizePolicy(sizePolicy);
        labelPopularity->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(labelPopularity, 5, 0, 1, 1);

        labelPopularityVal = new QLabel(groupTransferBox);
        labelPopularityVal->setObjectName("labelPopularityVal");
        sizePolicy1.setHeightForWidth(labelPopularityVal->sizePolicy().hasHeightForWidth());
        labelPopularityVal->setSizePolicy(sizePolicy1);
        labelPopularityVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout_2->addWidget(labelPopularityVal, 5, 1, 1, 1);


        verticalLayout_2->addWidget(groupTransferBox);

        groupInfosBox = new QGroupBox(scrollAreaWidgetContents);
        groupInfosBox->setObjectName("groupInfosBox");
        gridLayout = new QGridLayout(groupInfosBox);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(-1, 4, -1, 2);
        labelTotalSize = new QLabel(groupInfosBox);
        labelTotalSize->setObjectName("labelTotalSize");
        sizePolicy.setHeightForWidth(labelTotalSize->sizePolicy().hasHeightForWidth());
        labelTotalSize->setSizePolicy(sizePolicy);
        labelTotalSize->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelTotalSize, 0, 0, 1, 1);

        labelTotalSizeVal = new QLabel(groupInfosBox);
        labelTotalSizeVal->setObjectName("labelTotalSizeVal");
        sizePolicy1.setHeightForWidth(labelTotalSizeVal->sizePolicy().hasHeightForWidth());
        labelTotalSizeVal->setSizePolicy(sizePolicy1);
        labelTotalSizeVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout->addWidget(labelTotalSizeVal, 0, 1, 1, 1);

        labelTotalPieces = new QLabel(groupInfosBox);
        labelTotalPieces->setObjectName("labelTotalPieces");
        sizePolicy.setHeightForWidth(labelTotalPieces->sizePolicy().hasHeightForWidth());
        labelTotalPieces->setSizePolicy(sizePolicy);
        labelTotalPieces->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelTotalPieces, 0, 2, 1, 1);

        labelTotalPiecesVal = new QLabel(groupInfosBox);
        labelTotalPiecesVal->setObjectName("labelTotalPiecesVal");
        sizePolicy1.setHeightForWidth(labelTotalPiecesVal->sizePolicy().hasHeightForWidth());
        labelTotalPiecesVal->setSizePolicy(sizePolicy1);
        labelTotalPiecesVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout->addWidget(labelTotalPiecesVal, 0, 3, 1, 1);

        labelCreatedBy = new QLabel(groupInfosBox);
        labelCreatedBy->setObjectName("labelCreatedBy");
        sizePolicy.setHeightForWidth(labelCreatedBy->sizePolicy().hasHeightForWidth());
        labelCreatedBy->setSizePolicy(sizePolicy);
        labelCreatedBy->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelCreatedBy, 0, 4, 1, 1);

        labelCreatedByVal = new QLabel(groupInfosBox);
        labelCreatedByVal->setObjectName("labelCreatedByVal");
        sizePolicy1.setHeightForWidth(labelCreatedByVal->sizePolicy().hasHeightForWidth());
        labelCreatedByVal->setSizePolicy(sizePolicy1);
        labelCreatedByVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout->addWidget(labelCreatedByVal, 0, 5, 1, 1);

        labelAddedOn = new QLabel(groupInfosBox);
        labelAddedOn->setObjectName("labelAddedOn");
        sizePolicy.setHeightForWidth(labelAddedOn->sizePolicy().hasHeightForWidth());
        labelAddedOn->setSizePolicy(sizePolicy);
        labelAddedOn->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelAddedOn, 1, 0, 1, 1);

        labelAddedOnVal = new QLabel(groupInfosBox);
        labelAddedOnVal->setObjectName("labelAddedOnVal");
        sizePolicy1.setHeightForWidth(labelAddedOnVal->sizePolicy().hasHeightForWidth());
        labelAddedOnVal->setSizePolicy(sizePolicy1);
        labelAddedOnVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout->addWidget(labelAddedOnVal, 1, 1, 1, 1);

        labelCompletedOn = new QLabel(groupInfosBox);
        labelCompletedOn->setObjectName("labelCompletedOn");
        sizePolicy.setHeightForWidth(labelCompletedOn->sizePolicy().hasHeightForWidth());
        labelCompletedOn->setSizePolicy(sizePolicy);
        labelCompletedOn->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelCompletedOn, 1, 2, 1, 1);

        labelCompletedOnVal = new QLabel(groupInfosBox);
        labelCompletedOnVal->setObjectName("labelCompletedOnVal");
        sizePolicy1.setHeightForWidth(labelCompletedOnVal->sizePolicy().hasHeightForWidth());
        labelCompletedOnVal->setSizePolicy(sizePolicy1);
        labelCompletedOnVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout->addWidget(labelCompletedOnVal, 1, 3, 1, 1);

        labelCreatedOn = new QLabel(groupInfosBox);
        labelCreatedOn->setObjectName("labelCreatedOn");
        sizePolicy.setHeightForWidth(labelCreatedOn->sizePolicy().hasHeightForWidth());
        labelCreatedOn->setSizePolicy(sizePolicy);
        labelCreatedOn->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelCreatedOn, 1, 4, 1, 1);

        labelCreatedOnVal = new QLabel(groupInfosBox);
        labelCreatedOnVal->setObjectName("labelCreatedOnVal");
        sizePolicy1.setHeightForWidth(labelCreatedOnVal->sizePolicy().hasHeightForWidth());
        labelCreatedOnVal->setSizePolicy(sizePolicy1);
        labelCreatedOnVal->setTextFormat(Qt::TextFormat::PlainText);

        gridLayout->addWidget(labelCreatedOnVal, 1, 5, 1, 1);

        labelPrivate = new QLabel(groupInfosBox);
        labelPrivate->setObjectName("labelPrivate");
        sizePolicy.setHeightForWidth(labelPrivate->sizePolicy().hasHeightForWidth());
        labelPrivate->setSizePolicy(sizePolicy);
        labelPrivate->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelPrivate, 2, 0, 1, 1);

        labelPrivateVal = new QLabel(groupInfosBox);
        labelPrivateVal->setObjectName("labelPrivateVal");
        sizePolicy1.setHeightForWidth(labelPrivateVal->sizePolicy().hasHeightForWidth());
        labelPrivateVal->setSizePolicy(sizePolicy1);
        labelPrivateVal->setTextFormat(Qt::TextFormat::PlainText);
        labelPrivateVal->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelPrivateVal, 2, 1, 1, 5);

        labelInfohash1 = new QLabel(groupInfosBox);
        labelInfohash1->setObjectName("labelInfohash1");
        sizePolicy.setHeightForWidth(labelInfohash1->sizePolicy().hasHeightForWidth());
        labelInfohash1->setSizePolicy(sizePolicy);
        labelInfohash1->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelInfohash1, 3, 0, 1, 1);

        labelInfohash1Val = new QLabel(groupInfosBox);
        labelInfohash1Val->setObjectName("labelInfohash1Val");
        sizePolicy1.setHeightForWidth(labelInfohash1Val->sizePolicy().hasHeightForWidth());
        labelInfohash1Val->setSizePolicy(sizePolicy1);
        labelInfohash1Val->setTextFormat(Qt::TextFormat::PlainText);
        labelInfohash1Val->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelInfohash1Val, 3, 1, 1, 5);

        labelInfohash2 = new QLabel(groupInfosBox);
        labelInfohash2->setObjectName("labelInfohash2");
        sizePolicy.setHeightForWidth(labelInfohash2->sizePolicy().hasHeightForWidth());
        labelInfohash2->setSizePolicy(sizePolicy);
        labelInfohash2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelInfohash2, 4, 0, 1, 1);

        labelInfohash2Val = new QLabel(groupInfosBox);
        labelInfohash2Val->setObjectName("labelInfohash2Val");
        sizePolicy1.setHeightForWidth(labelInfohash2Val->sizePolicy().hasHeightForWidth());
        labelInfohash2Val->setSizePolicy(sizePolicy1);
        labelInfohash2Val->setTextFormat(Qt::TextFormat::PlainText);
        labelInfohash2Val->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelInfohash2Val, 4, 1, 1, 5);

        labelSavePath = new QLabel(groupInfosBox);
        labelSavePath->setObjectName("labelSavePath");
        sizePolicy.setHeightForWidth(labelSavePath->sizePolicy().hasHeightForWidth());
        labelSavePath->setSizePolicy(sizePolicy);
        labelSavePath->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTop|Qt::AlignmentFlag::AlignTrailing);

        gridLayout->addWidget(labelSavePath, 5, 0, 1, 1);

        labelSavePathVal = new QLabel(groupInfosBox);
        labelSavePathVal->setObjectName("labelSavePathVal");
        sizePolicy1.setHeightForWidth(labelSavePathVal->sizePolicy().hasHeightForWidth());
        labelSavePathVal->setSizePolicy(sizePolicy1);
        labelSavePathVal->setTextFormat(Qt::TextFormat::PlainText);
        labelSavePathVal->setWordWrap(true);
        labelSavePathVal->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(labelSavePathVal, 5, 1, 1, 5);

        labelComment = new QLabel(groupInfosBox);
        labelComment->setObjectName("labelComment");
        sizePolicy.setHeightForWidth(labelComment->sizePolicy().hasHeightForWidth());
        labelComment->setSizePolicy(sizePolicy);
        labelComment->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTop|Qt::AlignmentFlag::AlignTrailing);

        gridLayout->addWidget(labelComment, 6, 0, 1, 1);

        labelCommentVal = new QLabel(groupInfosBox);
        labelCommentVal->setObjectName("labelCommentVal");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(labelCommentVal->sizePolicy().hasHeightForWidth());
        labelCommentVal->setSizePolicy(sizePolicy2);
        labelCommentVal->setTextFormat(Qt::TextFormat::RichText);
        labelCommentVal->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        labelCommentVal->setWordWrap(true);
        labelCommentVal->setOpenExternalLinks(true);
        labelCommentVal->setTextInteractionFlags(Qt::TextInteractionFlag::TextBrowserInteraction);
        labelCommentVal->setProperty("openLinks", QVariant(true));

        gridLayout->addWidget(labelCommentVal, 6, 1, 1, 5);


        verticalLayout_2->addWidget(groupInfosBox);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_7->addWidget(scrollArea);

        stackedProperties->addWidget(pageGeneral);
        pageTrackers = new QWidget();
        pageTrackers->setObjectName("pageTrackers");
        hBoxLayoutTrackers = new QHBoxLayout(pageTrackers);
        hBoxLayoutTrackers->setObjectName("hBoxLayoutTrackers");
        hBoxLayoutTrackers->setContentsMargins(0, 0, 0, 0);
        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_2);

        trackerUpButton = new QPushButton(pageTrackers);
        trackerUpButton->setObjectName("trackerUpButton");

        verticalLayout_10->addWidget(trackerUpButton);

        trackerDownButton = new QPushButton(pageTrackers);
        trackerDownButton->setObjectName("trackerDownButton");

        verticalLayout_10->addWidget(trackerDownButton);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_3);


        hBoxLayoutTrackers->addLayout(verticalLayout_10);

        stackedProperties->addWidget(pageTrackers);
        pagePeers = new QWidget();
        pagePeers->setObjectName("pagePeers");
        vBoxLayoutPeerPage = new QVBoxLayout(pagePeers);
        vBoxLayoutPeerPage->setObjectName("vBoxLayoutPeerPage");
        vBoxLayoutPeerPage->setContentsMargins(0, 0, 0, 0);
        stackedProperties->addWidget(pagePeers);
        pageSources = new QWidget();
        pageSources->setObjectName("pageSources");
        verticalLayout_9 = new QVBoxLayout(pageSources);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(0, 0, 0, 0);
        listWebSeeds = new QListWidget(pageSources);
        listWebSeeds->setObjectName("listWebSeeds");
        listWebSeeds->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        listWebSeeds->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);

        verticalLayout_9->addWidget(listWebSeeds);

        stackedProperties->addWidget(pageSources);
        pageContents = new QWidget();
        pageContents->setObjectName("pageContents");
        verticalLayout_3 = new QVBoxLayout(pageContents);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        contentFilterLayout = new QHBoxLayout();
        contentFilterLayout->setObjectName("contentFilterLayout");
        selectAllButton = new QPushButton(pageContents);
        selectAllButton->setObjectName("selectAllButton");

        contentFilterLayout->addWidget(selectAllButton);

        selectNoneButton = new QPushButton(pageContents);
        selectNoneButton->setObjectName("selectNoneButton");

        contentFilterLayout->addWidget(selectNoneButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        contentFilterLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(contentFilterLayout);

        filesList = new TorrentContentWidget(pageContents);
        filesList->setObjectName("filesList");
        filesList->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        filesList->setEditTriggers(QAbstractItemView::EditTrigger::AllEditTriggers);
        filesList->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        filesList->setAllColumnsShowFocus(true);

        verticalLayout_3->addWidget(filesList);

        stackedProperties->addWidget(pageContents);
        pageSpeed = new QWidget();
        pageSpeed->setObjectName("pageSpeed");
        speedLayout = new QVBoxLayout(pageSpeed);
        speedLayout->setObjectName("speedLayout");
        speedLayout->setContentsMargins(0, 0, 0, 0);
        stackedProperties->addWidget(pageSpeed);

        verticalLayout->addWidget(stackedProperties);


        retranslateUi(PropertiesWidget);

        stackedProperties->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *PropertiesWidget)
    {
        labelDownloadedPieces->setText(QCoreApplication::translate("PropertiesWidget", "Progress:", nullptr));
        labelPiecesAvailability->setText(QCoreApplication::translate("PropertiesWidget", "Availability:", nullptr));
        groupTransferBox->setTitle(QCoreApplication::translate("PropertiesWidget", "Transfer", nullptr));
        labelTimeActive->setText(QCoreApplication::translate("PropertiesWidget", "Time Active:", nullptr));
        labelETA->setText(QCoreApplication::translate("PropertiesWidget", "ETA:", nullptr));
        labelConnections->setText(QCoreApplication::translate("PropertiesWidget", "Connections:", nullptr));
        labelDownloaded->setText(QCoreApplication::translate("PropertiesWidget", "Downloaded:", nullptr));
        labelUploaded->setText(QCoreApplication::translate("PropertiesWidget", "Uploaded:", nullptr));
        labelSeeds->setText(QCoreApplication::translate("PropertiesWidget", "Seeds:", nullptr));
        labelDlSpeed->setText(QCoreApplication::translate("PropertiesWidget", "Download Speed:", nullptr));
        labelUpSpeed->setText(QCoreApplication::translate("PropertiesWidget", "Upload Speed:", nullptr));
        labelPeers->setText(QCoreApplication::translate("PropertiesWidget", "Peers:", nullptr));
        labelDlLimit->setText(QCoreApplication::translate("PropertiesWidget", "Download Limit:", nullptr));
        labelUpLimit->setText(QCoreApplication::translate("PropertiesWidget", "Upload Limit:", nullptr));
        labelWasted->setText(QCoreApplication::translate("PropertiesWidget", "Wasted:", nullptr));
        labelRatio->setText(QCoreApplication::translate("PropertiesWidget", "Share Ratio:", nullptr));
        labelReannounceIn->setText(QCoreApplication::translate("PropertiesWidget", "Reannounce In:", nullptr));
        labelLastSeenComplete->setText(QCoreApplication::translate("PropertiesWidget", "Last Seen Complete:", nullptr));
#if QT_CONFIG(tooltip)
        labelPopularity->setToolTip(QCoreApplication::translate("PropertiesWidget", "Ratio / Time Active (in months), indicates how popular the torrent is", nullptr));
#endif // QT_CONFIG(tooltip)
        labelPopularity->setText(QCoreApplication::translate("PropertiesWidget", "Popularity:", nullptr));
#if QT_CONFIG(tooltip)
        labelPopularityVal->setToolTip(QCoreApplication::translate("PropertiesWidget", "Ratio / Time Active (in months), indicates how popular the torrent is", nullptr));
#endif // QT_CONFIG(tooltip)
        groupInfosBox->setTitle(QCoreApplication::translate("PropertiesWidget", "Information", nullptr));
        labelTotalSize->setText(QCoreApplication::translate("PropertiesWidget", "Total Size:", nullptr));
        labelTotalPieces->setText(QCoreApplication::translate("PropertiesWidget", "Pieces:", nullptr));
        labelCreatedBy->setText(QCoreApplication::translate("PropertiesWidget", "Created By:", nullptr));
        labelAddedOn->setText(QCoreApplication::translate("PropertiesWidget", "Added On:", nullptr));
        labelCompletedOn->setText(QCoreApplication::translate("PropertiesWidget", "Completed On:", nullptr));
        labelCreatedOn->setText(QCoreApplication::translate("PropertiesWidget", "Created On:", nullptr));
        labelPrivate->setText(QCoreApplication::translate("PropertiesWidget", "Private:", nullptr));
        labelInfohash1->setText(QCoreApplication::translate("PropertiesWidget", "Info Hash v1:", nullptr));
        labelInfohash2->setText(QCoreApplication::translate("PropertiesWidget", "Info Hash v2:", nullptr));
        labelSavePath->setText(QCoreApplication::translate("PropertiesWidget", "Save Path:", nullptr));
        labelComment->setText(QCoreApplication::translate("PropertiesWidget", "Comment:", nullptr));
        selectAllButton->setText(QCoreApplication::translate("PropertiesWidget", "Select All", nullptr));
        selectNoneButton->setText(QCoreApplication::translate("PropertiesWidget", "Select None", nullptr));
        (void)PropertiesWidget;
    } // retranslateUi

};

namespace Ui {
    class PropertiesWidget: public Ui_PropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROPERTIESWIDGET_H
