/****************************************************************************
** Meta object code from reading C++ file 'pluginselectdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/search/pluginselectdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginselectdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PluginSelectDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginSelectDialog::qt_create_metaobjectdata<qt_meta_tag_ZN18PluginSelectDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginSelectDialog",
        "on_actionUninstall_triggered",
        "",
        "on_updateButton_clicked",
        "on_installButton_clicked",
        "on_closeButton_clicked",
        "togglePluginState",
        "QTreeWidgetItem*",
        "setRowColor",
        "row",
        "color",
        "displayContextMenu",
        "enableSelection",
        "enable",
        "askForLocalPlugin",
        "askForPluginUrl",
        "iconDownloadFinished",
        "Net::DownloadResult",
        "result",
        "checkForUpdatesFinished",
        "QHash<QString,PluginVersion>",
        "updateInfo",
        "checkForUpdatesFailed",
        "reason",
        "pluginInstalled",
        "name",
        "pluginInstallationFailed",
        "pluginUpdated",
        "pluginUpdateFailed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'on_actionUninstall_triggered'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_updateButton_clicked'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_installButton_clicked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_closeButton_clicked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'togglePluginState'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'setRowColor'
        QtMocHelpers::SlotData<void(int, const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'displayContextMenu'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableSelection'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'askForLocalPlugin'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'askForPluginUrl'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'iconDownloadFinished'
        QtMocHelpers::SlotData<void(const Net::DownloadResult &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'checkForUpdatesFinished'
        QtMocHelpers::SlotData<void(const QHash<QString,PluginVersion> &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'checkForUpdatesFailed'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'pluginInstalled'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'pluginInstallationFailed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'pluginUpdated'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'pluginUpdateFailed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginSelectDialog, qt_meta_tag_ZN18PluginSelectDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PluginSelectDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PluginSelectDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PluginSelectDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PluginSelectDialogE_t>.metaTypes,
    nullptr
} };

void PluginSelectDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginSelectDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->on_actionUninstall_triggered(); break;
        case 1: _t->on_updateButton_clicked(); break;
        case 2: _t->on_installButton_clicked(); break;
        case 3: _t->on_closeButton_clicked(); break;
        case 4: _t->togglePluginState((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->setRowColor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->displayContextMenu(); break;
        case 7: _t->enableSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->askForLocalPlugin(); break;
        case 9: _t->askForPluginUrl(); break;
        case 10: _t->iconDownloadFinished((*reinterpret_cast<std::add_pointer_t<Net::DownloadResult>>(_a[1]))); break;
        case 11: _t->checkForUpdatesFinished((*reinterpret_cast<std::add_pointer_t<QHash<QString,PluginVersion>>>(_a[1]))); break;
        case 12: _t->checkForUpdatesFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->pluginInstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->pluginInstallationFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->pluginUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->pluginUpdateFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *PluginSelectDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginSelectDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PluginSelectDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int PluginSelectDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
