/****************************************************************************
** Meta object code from reading C++ file 'rss_autodownloader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/base/rss/rss_autodownloader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rss_autodownloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3RSS14AutoDownloaderE_t {};
} // unnamed namespace

template <> constexpr inline auto RSS::AutoDownloader::qt_create_metaobjectdata<qt_meta_tag_ZN3RSS14AutoDownloaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RSS::AutoDownloader",
        "processingStateChanged",
        "",
        "enabled",
        "ruleAdded",
        "ruleName",
        "ruleChanged",
        "ruleRenamed",
        "oldRuleName",
        "ruleAboutToBeRemoved",
        "process",
        "handleTorrentAdded",
        "source",
        "handleAddTorrentFailed",
        "url",
        "BitTorrent::AddTorrentError",
        "error",
        "handleNewArticle",
        "const Article*",
        "article",
        "handleFeedURLChanged",
        "Feed*",
        "feed",
        "oldURL"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'processingStateChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'ruleAdded'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ruleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ruleRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'ruleAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'process'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleTorrentAdded'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'handleAddTorrentFailed'
        QtMocHelpers::SlotData<void(const QString &, const BitTorrent::AddTorrentError &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'handleNewArticle'
        QtMocHelpers::SlotData<void(const Article *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'handleFeedURLChanged'
        QtMocHelpers::SlotData<void(Feed *, const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AutoDownloader, qt_meta_tag_ZN3RSS14AutoDownloaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RSS::AutoDownloader::staticMetaObject = { {
    QMetaObject::SuperData::link<ApplicationComponent<QObject>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS14AutoDownloaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS14AutoDownloaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3RSS14AutoDownloaderE_t>.metaTypes,
    nullptr
} };

void RSS::AutoDownloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AutoDownloader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->processingStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->ruleAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->ruleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->ruleRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->ruleAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->process(); break;
        case 6: _t->handleTorrentAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->handleAddTorrentFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<BitTorrent::AddTorrentError>>(_a[2]))); break;
        case 8: _t->handleNewArticle((*reinterpret_cast<std::add_pointer_t<const Article*>>(_a[1]))); break;
        case 9: _t->handleFeedURLChanged((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AutoDownloader::*)(bool )>(_a, &AutoDownloader::processingStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoDownloader::*)(const QString & )>(_a, &AutoDownloader::ruleAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoDownloader::*)(const QString & )>(_a, &AutoDownloader::ruleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoDownloader::*)(const QString & , const QString & )>(_a, &AutoDownloader::ruleRenamed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoDownloader::*)(const QString & )>(_a, &AutoDownloader::ruleAboutToBeRemoved, 4))
            return;
    }
}

const QMetaObject *RSS::AutoDownloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RSS::AutoDownloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3RSS14AutoDownloaderE_t>.strings))
        return static_cast<void*>(this);
    return ApplicationComponent<QObject>::qt_metacast(_clname);
}

int RSS::AutoDownloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ApplicationComponent<QObject>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void RSS::AutoDownloader::processingStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void RSS::AutoDownloader::ruleAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void RSS::AutoDownloader::ruleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void RSS::AutoDownloader::ruleRenamed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void RSS::AutoDownloader::ruleAboutToBeRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
