/********************************************************************************
** Form generated from reading UI file 'deletionconfirmationdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DELETIONCONFIRMATIONDIALOG_H
#define UI_DELETIONCONFIRMATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DeletionConfirmationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *labelWarning;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *rememberBtn;
    QCheckBox *checkRemoveContent;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DeletionConfirmationDialog)
    {
        if (DeletionConfirmationDialog->objectName().isEmpty())
            DeletionConfirmationDialog->setObjectName("DeletionConfirmationDialog");
        DeletionConfirmationDialog->resize(463, 128);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DeletionConfirmationDialog->sizePolicy().hasHeightForWidth());
        DeletionConfirmationDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(DeletionConfirmationDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        labelWarning = new QLabel(DeletionConfirmationDialog);
        labelWarning->setObjectName("labelWarning");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelWarning->sizePolicy().hasHeightForWidth());
        labelWarning->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(labelWarning);

        label = new QLabel(DeletionConfirmationDialog);
        label->setObjectName("label");
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setText(QString::fromUtf8("message goes here"));
        label->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);
        label->setWordWrap(true);

        horizontalLayout->addWidget(label);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        rememberBtn = new QToolButton(DeletionConfirmationDialog);
        rememberBtn->setObjectName("rememberBtn");
        rememberBtn->setEnabled(false);
        rememberBtn->setIconSize(QSize(24, 24));

        horizontalLayout_2->addWidget(rememberBtn);

        checkRemoveContent = new QCheckBox(DeletionConfirmationDialog);
        checkRemoveContent->setObjectName("checkRemoveContent");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(checkRemoveContent->sizePolicy().hasHeightForWidth());
        checkRemoveContent->setSizePolicy(sizePolicy2);
        QFont font;
        font.setItalic(true);
        checkRemoveContent->setFont(font);

        horizontalLayout_2->addWidget(checkRemoveContent);


        verticalLayout->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(DeletionConfirmationDialog);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy3);
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DeletionConfirmationDialog);

        QMetaObject::connectSlotsByName(DeletionConfirmationDialog);
    } // setupUi

    void retranslateUi(QDialog *DeletionConfirmationDialog)
    {
        DeletionConfirmationDialog->setWindowTitle(QCoreApplication::translate("DeletionConfirmationDialog", "Remove torrent(s)", nullptr));
        labelWarning->setText(QString());
#if QT_CONFIG(tooltip)
        rememberBtn->setToolTip(QCoreApplication::translate("DeletionConfirmationDialog", "Remember choice", nullptr));
#endif // QT_CONFIG(tooltip)
        checkRemoveContent->setText(QCoreApplication::translate("DeletionConfirmationDialog", "Also remove the content files", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DeletionConfirmationDialog: public Ui_DeletionConfirmationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DELETIONCONFIRMATIONDIALOG_H
