/********************************************************************************
** Form generated from reading UI file 'torrentsharelimitswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TORRENTSHARELIMITSWIDGET_H
#define UI_TORRENTSHARELIMITSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TorrentShareLimitsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *limitsLayout;
    QLabel *labelRatio;
    QComboBox *comboBoxRatioMode;
    QDoubleSpinBox *spinBoxRatioValue;
    QLabel *labelSeedingTime;
    QComboBox *comboBoxSeedingTimeMode;
    QSpinBox *spinBoxSeedingTimeValue;
    QLabel *labelInactiveSeedingTime;
    QComboBox *comboBoxInactiveSeedingTimeMode;
    QSpinBox *spinBoxInactiveSeedingTimeValue;
    QHBoxLayout *actionLayout;
    QLabel *labelAction;
    QComboBox *comboBoxAction;
    QSpacerItem *actionLayoutSpacer;

    void setupUi(QWidget *TorrentShareLimitsWidget)
    {
        if (TorrentShareLimitsWidget->objectName().isEmpty())
            TorrentShareLimitsWidget->setObjectName("TorrentShareLimitsWidget");
        TorrentShareLimitsWidget->resize(445, 132);
        verticalLayout = new QVBoxLayout(TorrentShareLimitsWidget);
        verticalLayout->setObjectName("verticalLayout");
        limitsLayout = new QGridLayout();
        limitsLayout->setObjectName("limitsLayout");
        labelRatio = new QLabel(TorrentShareLimitsWidget);
        labelRatio->setObjectName("labelRatio");

        limitsLayout->addWidget(labelRatio, 0, 0, 1, 1);

        comboBoxRatioMode = new QComboBox(TorrentShareLimitsWidget);
        comboBoxRatioMode->setObjectName("comboBoxRatioMode");

        limitsLayout->addWidget(comboBoxRatioMode, 0, 1, 1, 1);

        spinBoxRatioValue = new QDoubleSpinBox(TorrentShareLimitsWidget);
        spinBoxRatioValue->setObjectName("spinBoxRatioValue");
        spinBoxRatioValue->setEnabled(false);
        spinBoxRatioValue->setSingleStep(0.050000000000000);
        spinBoxRatioValue->setValue(1.000000000000000);

        limitsLayout->addWidget(spinBoxRatioValue, 0, 2, 1, 1);

        labelSeedingTime = new QLabel(TorrentShareLimitsWidget);
        labelSeedingTime->setObjectName("labelSeedingTime");

        limitsLayout->addWidget(labelSeedingTime, 1, 0, 1, 1);

        comboBoxSeedingTimeMode = new QComboBox(TorrentShareLimitsWidget);
        comboBoxSeedingTimeMode->setObjectName("comboBoxSeedingTimeMode");

        limitsLayout->addWidget(comboBoxSeedingTimeMode, 1, 1, 1, 1);

        spinBoxSeedingTimeValue = new QSpinBox(TorrentShareLimitsWidget);
        spinBoxSeedingTimeValue->setObjectName("spinBoxSeedingTimeValue");
        spinBoxSeedingTimeValue->setEnabled(false);
        spinBoxSeedingTimeValue->setMaximum(9999999);
        spinBoxSeedingTimeValue->setValue(1440);

        limitsLayout->addWidget(spinBoxSeedingTimeValue, 1, 2, 1, 1);

        labelInactiveSeedingTime = new QLabel(TorrentShareLimitsWidget);
        labelInactiveSeedingTime->setObjectName("labelInactiveSeedingTime");

        limitsLayout->addWidget(labelInactiveSeedingTime, 2, 0, 1, 1);

        comboBoxInactiveSeedingTimeMode = new QComboBox(TorrentShareLimitsWidget);
        comboBoxInactiveSeedingTimeMode->setObjectName("comboBoxInactiveSeedingTimeMode");

        limitsLayout->addWidget(comboBoxInactiveSeedingTimeMode, 2, 1, 1, 1);

        spinBoxInactiveSeedingTimeValue = new QSpinBox(TorrentShareLimitsWidget);
        spinBoxInactiveSeedingTimeValue->setObjectName("spinBoxInactiveSeedingTimeValue");
        spinBoxInactiveSeedingTimeValue->setEnabled(false);
        spinBoxInactiveSeedingTimeValue->setMaximum(9999999);
        spinBoxInactiveSeedingTimeValue->setValue(1440);

        limitsLayout->addWidget(spinBoxInactiveSeedingTimeValue, 2, 2, 1, 1);


        verticalLayout->addLayout(limitsLayout);

        actionLayout = new QHBoxLayout();
        actionLayout->setObjectName("actionLayout");
        labelAction = new QLabel(TorrentShareLimitsWidget);
        labelAction->setObjectName("labelAction");

        actionLayout->addWidget(labelAction);

        comboBoxAction = new QComboBox(TorrentShareLimitsWidget);
        comboBoxAction->setObjectName("comboBoxAction");

        actionLayout->addWidget(comboBoxAction);

        actionLayoutSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        actionLayout->addItem(actionLayoutSpacer);


        verticalLayout->addLayout(actionLayout);


        retranslateUi(TorrentShareLimitsWidget);

        QMetaObject::connectSlotsByName(TorrentShareLimitsWidget);
    } // setupUi

    void retranslateUi(QWidget *TorrentShareLimitsWidget)
    {
        labelRatio->setText(QCoreApplication::translate("TorrentShareLimitsWidget", "Ratio:", nullptr));
        labelSeedingTime->setText(QCoreApplication::translate("TorrentShareLimitsWidget", "Seeding time:", nullptr));
        spinBoxSeedingTimeValue->setSuffix(QCoreApplication::translate("TorrentShareLimitsWidget", " min", nullptr));
        labelInactiveSeedingTime->setText(QCoreApplication::translate("TorrentShareLimitsWidget", "Inactive seeding time:", nullptr));
        spinBoxInactiveSeedingTimeValue->setSuffix(QCoreApplication::translate("TorrentShareLimitsWidget", " min", nullptr));
        labelAction->setText(QCoreApplication::translate("TorrentShareLimitsWidget", "Action when the limit is reached:", nullptr));
        (void)TorrentShareLimitsWidget;
    } // retranslateUi

};

namespace Ui {
    class TorrentShareLimitsWidget: public Ui_TorrentShareLimitsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TORRENTSHARELIMITSWIDGET_H
