/********************************************************************************
** Form generated from reading UI file 'trackersadditiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRACKERSADDITIONDIALOG_H
#define UI_TRACKERSADDITIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TrackersAdditionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTextEdit *textEditTrackersList;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QLineEdit *lineEditListURL;
    QPushButton *downloadButton;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TrackersAdditionDialog)
    {
        if (TrackersAdditionDialog->objectName().isEmpty())
            TrackersAdditionDialog->setObjectName("TrackersAdditionDialog");
        TrackersAdditionDialog->resize(367, 274);
        verticalLayout = new QVBoxLayout(TrackersAdditionDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(TrackersAdditionDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        textEditTrackersList = new QTextEdit(TrackersAdditionDialog);
        textEditTrackersList->setObjectName("textEditTrackersList");
        textEditTrackersList->setTabChangesFocus(true);
        textEditTrackersList->setLineWrapMode(QTextEdit::LineWrapMode::NoWrap);
        textEditTrackersList->setAcceptRichText(false);

        verticalLayout->addWidget(textEditTrackersList);

        label_2 = new QLabel(TrackersAdditionDialog);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lineEditListURL = new QLineEdit(TrackersAdditionDialog);
        lineEditListURL->setObjectName("lineEditListURL");

        horizontalLayout->addWidget(lineEditListURL);

        downloadButton = new QPushButton(TrackersAdditionDialog);
        downloadButton->setObjectName("downloadButton");

        horizontalLayout->addWidget(downloadButton);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(TrackersAdditionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TrackersAdditionDialog);

        QMetaObject::connectSlotsByName(TrackersAdditionDialog);
    } // setupUi

    void retranslateUi(QDialog *TrackersAdditionDialog)
    {
        TrackersAdditionDialog->setWindowTitle(QCoreApplication::translate("TrackersAdditionDialog", "Add trackers", nullptr));
        label->setText(QCoreApplication::translate("TrackersAdditionDialog", "List of trackers to add (one per line):", nullptr));
        label_2->setText(QCoreApplication::translate("TrackersAdditionDialog", "\302\265Torrent compatible list URL:", nullptr));
#if QT_CONFIG(tooltip)
        downloadButton->setToolTip(QCoreApplication::translate("TrackersAdditionDialog", "Download trackers list", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class TrackersAdditionDialog: public Ui_TrackersAdditionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TRACKERSADDITIONDIALOG_H
