/********************************************************************************
** Form generated from reading UI file 'torrentoptionsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TORRENTOPTIONSDIALOG_H
#define UI_TORRENTOPTIONSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "gui/fspathedit.h"
#include "gui/torrentsharelimitswidget.h"

QT_BEGIN_NAMESPACE

class Ui_TorrentOptionsDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QCheckBox *checkAutoTMM;
    QGroupBox *groupBoxSavePath;
    QVBoxLayout *verticalLayout_2;
    FileSystemPathComboEdit *savePath;
    QCheckBox *checkUseDownloadPath;
    FileSystemPathComboEdit *downloadPath;
    QGridLayout *gridLayout_4;
    QLabel *labelCategory;
    QComboBox *comboCategory;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QSlider *sliderUploadLimit;
    QSpinBox *spinUploadLimit;
    QLabel *label_2;
    QSlider *sliderDownloadLimit;
    QSpinBox *spinDownloadLimit;
    QLabel *labelWarning;
    QGroupBox *torrentShareLimitsBox;
    QVBoxLayout *torrentShareLimitsBoxLayout;
    TorrentShareLimitsWidget *torrentShareLimitsWidget;
    QGridLayout *gridLayout_3;
    QCheckBox *checkDisableDHT;
    QCheckBox *checkSequential;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *checkDisablePEX;
    QCheckBox *checkFirstLastPieces;
    QCheckBox *checkDisableLSD;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TorrentOptionsDialog)
    {
        if (TorrentOptionsDialog->objectName().isEmpty())
            TorrentOptionsDialog->setObjectName("TorrentOptionsDialog");
        TorrentOptionsDialog->resize(450, 540);
        verticalLayout_3 = new QVBoxLayout(TorrentOptionsDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        checkAutoTMM = new QCheckBox(TorrentOptionsDialog);
        checkAutoTMM->setObjectName("checkAutoTMM");

        verticalLayout_3->addWidget(checkAutoTMM);

        groupBoxSavePath = new QGroupBox(TorrentOptionsDialog);
        groupBoxSavePath->setObjectName("groupBoxSavePath");
        verticalLayout_2 = new QVBoxLayout(groupBoxSavePath);
        verticalLayout_2->setObjectName("verticalLayout_2");
        savePath = new FileSystemPathComboEdit(groupBoxSavePath);
        savePath->setObjectName("savePath");

        verticalLayout_2->addWidget(savePath);

        checkUseDownloadPath = new QCheckBox(groupBoxSavePath);
        checkUseDownloadPath->setObjectName("checkUseDownloadPath");

        verticalLayout_2->addWidget(checkUseDownloadPath);

        downloadPath = new FileSystemPathComboEdit(groupBoxSavePath);
        downloadPath->setObjectName("downloadPath");
        downloadPath->setEnabled(false);

        verticalLayout_2->addWidget(downloadPath);


        verticalLayout_3->addWidget(groupBoxSavePath);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        labelCategory = new QLabel(TorrentOptionsDialog);
        labelCategory->setObjectName("labelCategory");

        gridLayout_4->addWidget(labelCategory, 0, 0, 1, 1);

        comboCategory = new QComboBox(TorrentOptionsDialog);
        comboCategory->setObjectName("comboCategory");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboCategory->sizePolicy().hasHeightForWidth());
        comboCategory->setSizePolicy(sizePolicy);
        comboCategory->setEditable(true);
        comboCategory->setMaxVisibleItems(2147483647);
        comboCategory->setInsertPolicy(QComboBox::InsertPolicy::InsertAtTop);

        gridLayout_4->addWidget(comboCategory, 0, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_4);

        groupBox = new QGroupBox(TorrentOptionsDialog);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        sliderUploadLimit = new QSlider(groupBox);
        sliderUploadLimit->setObjectName("sliderUploadLimit");
        sliderUploadLimit->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_2->addWidget(sliderUploadLimit, 0, 1, 1, 1);

        spinUploadLimit = new QSpinBox(groupBox);
        spinUploadLimit->setObjectName("spinUploadLimit");
        spinUploadLimit->setMaximum(2000000);
        spinUploadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);

        gridLayout_2->addWidget(spinUploadLimit, 0, 2, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        sliderDownloadLimit = new QSlider(groupBox);
        sliderDownloadLimit->setObjectName("sliderDownloadLimit");
        sliderDownloadLimit->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_2->addWidget(sliderDownloadLimit, 1, 1, 1, 1);

        spinDownloadLimit = new QSpinBox(groupBox);
        spinDownloadLimit->setObjectName("spinDownloadLimit");
        spinDownloadLimit->setMaximum(2000000);
        spinDownloadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);

        gridLayout_2->addWidget(spinDownloadLimit, 1, 2, 1, 1);

        labelWarning = new QLabel(groupBox);
        labelWarning->setObjectName("labelWarning");

        gridLayout_2->addWidget(labelWarning, 2, 1, 1, 2);


        verticalLayout_3->addWidget(groupBox);

        torrentShareLimitsBox = new QGroupBox(TorrentOptionsDialog);
        torrentShareLimitsBox->setObjectName("torrentShareLimitsBox");
        torrentShareLimitsBoxLayout = new QVBoxLayout(torrentShareLimitsBox);
        torrentShareLimitsBoxLayout->setObjectName("torrentShareLimitsBoxLayout");
        torrentShareLimitsWidget = new TorrentShareLimitsWidget(torrentShareLimitsBox);
        torrentShareLimitsWidget->setObjectName("torrentShareLimitsWidget");

        torrentShareLimitsBoxLayout->addWidget(torrentShareLimitsWidget);


        verticalLayout_3->addWidget(torrentShareLimitsBox);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        checkDisableDHT = new QCheckBox(TorrentOptionsDialog);
        checkDisableDHT->setObjectName("checkDisableDHT");

        gridLayout_3->addWidget(checkDisableDHT, 0, 0, 1, 1);

        checkSequential = new QCheckBox(TorrentOptionsDialog);
        checkSequential->setObjectName("checkSequential");

        gridLayout_3->addWidget(checkSequential, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        checkDisablePEX = new QCheckBox(TorrentOptionsDialog);
        checkDisablePEX->setObjectName("checkDisablePEX");

        gridLayout_3->addWidget(checkDisablePEX, 1, 0, 1, 1);

        checkFirstLastPieces = new QCheckBox(TorrentOptionsDialog);
        checkFirstLastPieces->setObjectName("checkFirstLastPieces");

        gridLayout_3->addWidget(checkFirstLastPieces, 1, 1, 1, 1);

        checkDisableLSD = new QCheckBox(TorrentOptionsDialog);
        checkDisableLSD->setObjectName("checkDisableLSD");

        gridLayout_3->addWidget(checkDisableLSD, 2, 0, 1, 1);


        verticalLayout_3->addLayout(gridLayout_3);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(TorrentOptionsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_3->addWidget(buttonBox);


        retranslateUi(TorrentOptionsDialog);

        QMetaObject::connectSlotsByName(TorrentOptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *TorrentOptionsDialog)
    {
        TorrentOptionsDialog->setWindowTitle(QCoreApplication::translate("TorrentOptionsDialog", "Torrent Options", nullptr));
#if QT_CONFIG(tooltip)
        checkAutoTMM->setToolTip(QCoreApplication::translate("TorrentOptionsDialog", "Automatic mode means that various torrent properties (e.g. save path) will be decided by the associated category", nullptr));
#endif // QT_CONFIG(tooltip)
        checkAutoTMM->setText(QCoreApplication::translate("TorrentOptionsDialog", "Automatic Torrent Management", nullptr));
        groupBoxSavePath->setTitle(QCoreApplication::translate("TorrentOptionsDialog", "Save at", nullptr));
        checkUseDownloadPath->setText(QCoreApplication::translate("TorrentOptionsDialog", "Use another path for incomplete torrent", nullptr));
        labelCategory->setText(QCoreApplication::translate("TorrentOptionsDialog", "Category:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("TorrentOptionsDialog", "Torrent Speed Limits", nullptr));
        label->setText(QCoreApplication::translate("TorrentOptionsDialog", "Upload:", nullptr));
        spinUploadLimit->setSpecialValueText(QCoreApplication::translate("TorrentOptionsDialog", "\342\210\236", nullptr));
        spinUploadLimit->setSuffix(QCoreApplication::translate("TorrentOptionsDialog", " KiB/s", nullptr));
        label_2->setText(QCoreApplication::translate("TorrentOptionsDialog", "Download:", nullptr));
        spinDownloadLimit->setSpecialValueText(QCoreApplication::translate("TorrentOptionsDialog", "\342\210\236", nullptr));
        spinDownloadLimit->setSuffix(QCoreApplication::translate("TorrentOptionsDialog", " KiB/s", nullptr));
        labelWarning->setText(QCoreApplication::translate("TorrentOptionsDialog", "These will not exceed the global limits", nullptr));
        torrentShareLimitsBox->setTitle(QCoreApplication::translate("TorrentOptionsDialog", "Torrent Share Limits", nullptr));
        checkDisableDHT->setText(QCoreApplication::translate("TorrentOptionsDialog", "Disable DHT for this torrent", nullptr));
        checkSequential->setText(QCoreApplication::translate("TorrentOptionsDialog", "Download in sequential order", nullptr));
        checkDisablePEX->setText(QCoreApplication::translate("TorrentOptionsDialog", "Disable PeX for this torrent", nullptr));
        checkFirstLastPieces->setText(QCoreApplication::translate("TorrentOptionsDialog", "Download first and last pieces first", nullptr));
        checkDisableLSD->setText(QCoreApplication::translate("TorrentOptionsDialog", "Disable LSD for this torrent", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TorrentOptionsDialog: public Ui_TorrentOptionsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TORRENTOPTIONSDIALOG_H
