/****************************************************************************
** Meta object code from reading C++ file 'session.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/base/bittorrent/session.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10BitTorrent7SessionE_t {};
} // unnamed namespace

template <> constexpr inline auto BitTorrent::Session::qt_create_metaobjectdata<qt_meta_tag_ZN10BitTorrent7SessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BitTorrent::Session",
        "startupProgressUpdated",
        "",
        "progress",
        "addTorrentFailed",
        "InfoHash",
        "infoHash",
        "AddTorrentError",
        "reason",
        "allTorrentsFinished",
        "categoryAdded",
        "categoryName",
        "categoryRemoved",
        "categoryOptionsChanged",
        "fullDiskError",
        "Torrent*",
        "torrent",
        "msg",
        "IPFilterParsed",
        "error",
        "ruleCount",
        "metadataDownloaded",
        "TorrentInfo",
        "info",
        "restored",
        "paused",
        "resumed",
        "speedLimitModeChanged",
        "alternative",
        "statsUpdated",
        "subcategoriesSupportChanged",
        "tagAdded",
        "Tag",
        "tag",
        "tagRemoved",
        "torrentAboutToBeRemoved",
        "torrentAdded",
        "torrentCategoryChanged",
        "oldCategory",
        "torrentFinished",
        "torrentFinishedChecking",
        "torrentMetadataReceived",
        "torrentStopped",
        "torrentStarted",
        "torrentSavePathChanged",
        "torrentSavingModeChanged",
        "torrentsLoaded",
        "QList<Torrent*>",
        "torrents",
        "torrentsUpdated",
        "torrentTagAdded",
        "torrentTagRemoved",
        "trackerError",
        "tracker",
        "trackersAdded",
        "QList<TrackerEntry>",
        "trackers",
        "trackersReset",
        "QList<TrackerEntryStatus>",
        "oldEntries",
        "newEntries",
        "trackersRemoved",
        "trackerSuccess",
        "trackerWarning",
        "trackerEntryStatusesUpdated",
        "QHash<QString,TrackerEntryStatus>",
        "updatedTrackers",
        "freeDiskSpaceChecked",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startupProgressUpdated'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'addTorrentFailed'
        QtMocHelpers::SignalData<void(const InfoHash &, const AddTorrentError &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'allTorrentsFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoryAdded'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'categoryRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'categoryOptionsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'fullDiskError'
        QtMocHelpers::SignalData<void(Torrent *, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'IPFilterParsed'
        QtMocHelpers::SignalData<void(bool, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 }, { QMetaType::Int, 20 },
        }}),
        // Signal 'metadataDownloaded'
        QtMocHelpers::SignalData<void(const TorrentInfo &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'restored'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumed'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speedLimitModeChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'statsUpdated'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subcategoriesSupportChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tagAdded'
        QtMocHelpers::SignalData<void(const Tag &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'tagRemoved'
        QtMocHelpers::SignalData<void(const Tag &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'torrentAboutToBeRemoved'
        QtMocHelpers::SignalData<void(Torrent *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentAdded'
        QtMocHelpers::SignalData<void(Torrent *)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentCategoryChanged'
        QtMocHelpers::SignalData<void(Torrent *, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 38 },
        }}),
        // Signal 'torrentFinished'
        QtMocHelpers::SignalData<void(Torrent *)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentFinishedChecking'
        QtMocHelpers::SignalData<void(Torrent *)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentMetadataReceived'
        QtMocHelpers::SignalData<void(Torrent *)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentStopped'
        QtMocHelpers::SignalData<void(Torrent *)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentStarted'
        QtMocHelpers::SignalData<void(Torrent *)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentSavePathChanged'
        QtMocHelpers::SignalData<void(Torrent *)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentSavingModeChanged'
        QtMocHelpers::SignalData<void(Torrent *)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'torrentsLoaded'
        QtMocHelpers::SignalData<void(const QList<Torrent*> &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Signal 'torrentsUpdated'
        QtMocHelpers::SignalData<void(const QList<Torrent*> &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Signal 'torrentTagAdded'
        QtMocHelpers::SignalData<void(Torrent *, const Tag &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 32, 33 },
        }}),
        // Signal 'torrentTagRemoved'
        QtMocHelpers::SignalData<void(Torrent *, const Tag &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 32, 33 },
        }}),
        // Signal 'trackerError'
        QtMocHelpers::SignalData<void(Torrent *, const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 53 },
        }}),
        // Signal 'trackersAdded'
        QtMocHelpers::SignalData<void(Torrent *, const QList<TrackerEntry> &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 55, 56 },
        }}),
        // Signal 'trackersReset'
        QtMocHelpers::SignalData<void(Torrent *, const QList<TrackerEntryStatus> &, const QList<TrackerEntry> &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 58, 59 }, { 0x80000000 | 55, 60 },
        }}),
        // Signal 'trackersRemoved'
        QtMocHelpers::SignalData<void(Torrent *, const QStringList &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QStringList, 56 },
        }}),
        // Signal 'trackerSuccess'
        QtMocHelpers::SignalData<void(Torrent *, const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 53 },
        }}),
        // Signal 'trackerWarning'
        QtMocHelpers::SignalData<void(Torrent *, const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 53 },
        }}),
        // Signal 'trackerEntryStatusesUpdated'
        QtMocHelpers::SignalData<void(Torrent *, const QHash<QString,TrackerEntryStatus> &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 65, 66 },
        }}),
        // Signal 'freeDiskSpaceChecked'
        QtMocHelpers::SignalData<void(qint64)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 68 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Session, qt_meta_tag_ZN10BitTorrent7SessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BitTorrent::Session::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BitTorrent7SessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BitTorrent7SessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10BitTorrent7SessionE_t>.metaTypes,
    nullptr
} };

void BitTorrent::Session::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Session *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startupProgressUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->addTorrentFailed((*reinterpret_cast<std::add_pointer_t<InfoHash>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AddTorrentError>>(_a[2]))); break;
        case 2: _t->allTorrentsFinished(); break;
        case 3: _t->categoryAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->categoryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->categoryOptionsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->fullDiskError((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->IPFilterParsed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->metadataDownloaded((*reinterpret_cast<std::add_pointer_t<TorrentInfo>>(_a[1]))); break;
        case 9: _t->restored(); break;
        case 10: _t->paused(); break;
        case 11: _t->resumed(); break;
        case 12: _t->speedLimitModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->statsUpdated(); break;
        case 14: _t->subcategoriesSupportChanged(); break;
        case 15: _t->tagAdded((*reinterpret_cast<std::add_pointer_t<Tag>>(_a[1]))); break;
        case 16: _t->tagRemoved((*reinterpret_cast<std::add_pointer_t<Tag>>(_a[1]))); break;
        case 17: _t->torrentAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 18: _t->torrentAdded((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 19: _t->torrentCategoryChanged((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->torrentFinished((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 21: _t->torrentFinishedChecking((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 22: _t->torrentMetadataReceived((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 23: _t->torrentStopped((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 24: _t->torrentStarted((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 25: _t->torrentSavePathChanged((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 26: _t->torrentSavingModeChanged((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1]))); break;
        case 27: _t->torrentsLoaded((*reinterpret_cast<std::add_pointer_t<QList<Torrent*>>>(_a[1]))); break;
        case 28: _t->torrentsUpdated((*reinterpret_cast<std::add_pointer_t<QList<Torrent*>>>(_a[1]))); break;
        case 29: _t->torrentTagAdded((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Tag>>(_a[2]))); break;
        case 30: _t->torrentTagRemoved((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Tag>>(_a[2]))); break;
        case 31: _t->trackerError((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 32: _t->trackersAdded((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<TrackerEntry>>>(_a[2]))); break;
        case 33: _t->trackersReset((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<TrackerEntryStatus>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<TrackerEntry>>>(_a[3]))); break;
        case 34: _t->trackersRemoved((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 35: _t->trackerSuccess((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 36: _t->trackerWarning((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 37: _t->trackerEntryStatusesUpdated((*reinterpret_cast<std::add_pointer_t<Torrent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,TrackerEntryStatus>>>(_a[2]))); break;
        case 38: _t->freeDiskSpaceChecked((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Tag >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Tag >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Torrent*> >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Torrent*> >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Tag >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Tag >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Torrent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Session::*)(int )>(_a, &Session::startupProgressUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const InfoHash & , const AddTorrentError & )>(_a, &Session::addTorrentFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::allTorrentsFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const QString & )>(_a, &Session::categoryAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const QString & )>(_a, &Session::categoryRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const QString & )>(_a, &Session::categoryOptionsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QString & )>(_a, &Session::fullDiskError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(bool , int )>(_a, &Session::IPFilterParsed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const TorrentInfo & )>(_a, &Session::metadataDownloaded, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::restored, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::paused, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::resumed, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(bool )>(_a, &Session::speedLimitModeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::statsUpdated, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::subcategoriesSupportChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const Tag & )>(_a, &Session::tagAdded, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const Tag & )>(_a, &Session::tagRemoved, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentAboutToBeRemoved, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentAdded, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QString & )>(_a, &Session::torrentCategoryChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentFinished, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentFinishedChecking, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentMetadataReceived, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentStopped, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentStarted, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentSavePathChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * )>(_a, &Session::torrentSavingModeChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const QList<Torrent*> & )>(_a, &Session::torrentsLoaded, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const QList<Torrent*> & )>(_a, &Session::torrentsUpdated, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const Tag & )>(_a, &Session::torrentTagAdded, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const Tag & )>(_a, &Session::torrentTagRemoved, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QString & )>(_a, &Session::trackerError, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QList<TrackerEntry> & )>(_a, &Session::trackersAdded, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QList<TrackerEntryStatus> & , const QList<TrackerEntry> & )>(_a, &Session::trackersReset, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QStringList & )>(_a, &Session::trackersRemoved, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QString & )>(_a, &Session::trackerSuccess, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QString & )>(_a, &Session::trackerWarning, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Torrent * , const QHash<QString,TrackerEntryStatus> & )>(_a, &Session::trackerEntryStatusesUpdated, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(qint64 )>(_a, &Session::freeDiskSpaceChecked, 38))
            return;
    }
}

const QMetaObject *BitTorrent::Session::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BitTorrent::Session::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BitTorrent7SessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BitTorrent::Session::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void BitTorrent::Session::startupProgressUpdated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BitTorrent::Session::addTorrentFailed(const InfoHash & _t1, const AddTorrentError & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void BitTorrent::Session::allTorrentsFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BitTorrent::Session::categoryAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BitTorrent::Session::categoryRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BitTorrent::Session::categoryOptionsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BitTorrent::Session::fullDiskError(Torrent * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void BitTorrent::Session::IPFilterParsed(bool _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void BitTorrent::Session::metadataDownloaded(const TorrentInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BitTorrent::Session::restored()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void BitTorrent::Session::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void BitTorrent::Session::resumed()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void BitTorrent::Session::speedLimitModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void BitTorrent::Session::statsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void BitTorrent::Session::subcategoriesSupportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void BitTorrent::Session::tagAdded(const Tag & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void BitTorrent::Session::tagRemoved(const Tag & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void BitTorrent::Session::torrentAboutToBeRemoved(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void BitTorrent::Session::torrentAdded(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void BitTorrent::Session::torrentCategoryChanged(Torrent * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void BitTorrent::Session::torrentFinished(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void BitTorrent::Session::torrentFinishedChecking(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void BitTorrent::Session::torrentMetadataReceived(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void BitTorrent::Session::torrentStopped(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void BitTorrent::Session::torrentStarted(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void BitTorrent::Session::torrentSavePathChanged(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void BitTorrent::Session::torrentSavingModeChanged(Torrent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void BitTorrent::Session::torrentsLoaded(const QList<Torrent*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void BitTorrent::Session::torrentsUpdated(const QList<Torrent*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void BitTorrent::Session::torrentTagAdded(Torrent * _t1, const Tag & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2);
}

// SIGNAL 30
void BitTorrent::Session::torrentTagRemoved(Torrent * _t1, const Tag & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2);
}

// SIGNAL 31
void BitTorrent::Session::trackerError(Torrent * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1, _t2);
}

// SIGNAL 32
void BitTorrent::Session::trackersAdded(Torrent * _t1, const QList<TrackerEntry> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1, _t2);
}

// SIGNAL 33
void BitTorrent::Session::trackersReset(Torrent * _t1, const QList<TrackerEntryStatus> & _t2, const QList<TrackerEntry> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1, _t2, _t3);
}

// SIGNAL 34
void BitTorrent::Session::trackersRemoved(Torrent * _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1, _t2);
}

// SIGNAL 35
void BitTorrent::Session::trackerSuccess(Torrent * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1, _t2);
}

// SIGNAL 36
void BitTorrent::Session::trackerWarning(Torrent * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1, _t2);
}

// SIGNAL 37
void BitTorrent::Session::trackerEntryStatusesUpdated(Torrent * _t1, const QHash<QString,TrackerEntryStatus> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1, _t2);
}

// SIGNAL 38
void BitTorrent::Session::freeDiskSpaceChecked(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN10BitTorrent20SessionSettingsEnumsE_t {};
} // unnamed namespace

template <> constexpr inline auto BitTorrent::SessionSettingsEnums::qt_create_metaobjectdata<qt_meta_tag_ZN10BitTorrent20SessionSettingsEnumsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BitTorrent::SessionSettingsEnums",
        "BTProtocol",
        "Both",
        "TCP",
        "UTP",
        "ChokingAlgorithm",
        "FixedSlots",
        "RateBased",
        "DiskIOReadMode",
        "DisableOSCache",
        "EnableOSCache",
        "DiskIOType",
        "Default",
        "MMap",
        "Posix",
        "SimplePreadPwrite",
        "DiskIOWriteMode",
        "WriteThrough",
        "MixedModeAlgorithm",
        "Proportional",
        "SeedChokingAlgorithm",
        "RoundRobin",
        "FastestUpload",
        "AntiLeech",
        "ResumeDataStorageType",
        "Legacy",
        "SQLite"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BTProtocol'
        QtMocHelpers::EnumData<BTProtocol>(1, 1, QMC::EnumIsScoped).add({
            {    2, BTProtocol::Both },
            {    3, BTProtocol::TCP },
            {    4, BTProtocol::UTP },
        }),
        // enum 'ChokingAlgorithm'
        QtMocHelpers::EnumData<ChokingAlgorithm>(5, 5, QMC::EnumIsScoped).add({
            {    6, ChokingAlgorithm::FixedSlots },
            {    7, ChokingAlgorithm::RateBased },
        }),
        // enum 'DiskIOReadMode'
        QtMocHelpers::EnumData<DiskIOReadMode>(8, 8, QMC::EnumIsScoped).add({
            {    9, DiskIOReadMode::DisableOSCache },
            {   10, DiskIOReadMode::EnableOSCache },
        }),
        // enum 'DiskIOType'
        QtMocHelpers::EnumData<DiskIOType>(11, 11, QMC::EnumIsScoped).add({
            {   12, DiskIOType::Default },
            {   13, DiskIOType::MMap },
            {   14, DiskIOType::Posix },
            {   15, DiskIOType::SimplePreadPwrite },
        }),
        // enum 'DiskIOWriteMode'
        QtMocHelpers::EnumData<DiskIOWriteMode>(16, 16, QMC::EnumIsScoped).add({
            {    9, DiskIOWriteMode::DisableOSCache },
            {   10, DiskIOWriteMode::EnableOSCache },
            {   17, DiskIOWriteMode::WriteThrough },
        }),
        // enum 'MixedModeAlgorithm'
        QtMocHelpers::EnumData<MixedModeAlgorithm>(18, 18, QMC::EnumIsScoped).add({
            {    3, MixedModeAlgorithm::TCP },
            {   19, MixedModeAlgorithm::Proportional },
        }),
        // enum 'SeedChokingAlgorithm'
        QtMocHelpers::EnumData<SeedChokingAlgorithm>(20, 20, QMC::EnumIsScoped).add({
            {   21, SeedChokingAlgorithm::RoundRobin },
            {   22, SeedChokingAlgorithm::FastestUpload },
            {   23, SeedChokingAlgorithm::AntiLeech },
        }),
        // enum 'ResumeDataStorageType'
        QtMocHelpers::EnumData<ResumeDataStorageType>(24, 24, QMC::EnumIsScoped).add({
            {   25, ResumeDataStorageType::Legacy },
            {   26, ResumeDataStorageType::SQLite },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10BitTorrent20SessionSettingsEnumsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN10BitTorrent20SessionSettingsEnumsE =
    BitTorrent::SessionSettingsEnums::qt_create_metaobjectdata<qt_meta_tag_ZN10BitTorrent20SessionSettingsEnumsE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10BitTorrent20SessionSettingsEnumsE =
    qt_staticMetaObjectContent_ZN10BitTorrent20SessionSettingsEnumsE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10BitTorrent20SessionSettingsEnumsE =
    qt_staticMetaObjectContent_ZN10BitTorrent20SessionSettingsEnumsE.relocatingData;

Q_CONSTINIT const QMetaObject BitTorrent::SessionSettingsEnums::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10BitTorrent20SessionSettingsEnumsE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10BitTorrent20SessionSettingsEnumsE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10BitTorrent20SessionSettingsEnumsE.metaTypes,
    nullptr
} };

QT_WARNING_POP
