/********************************************************************************
** Form generated from reading UI file 'speedlimitdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPEEDLIMITDIALOG_H
#define UI_SPEEDLIMITDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SpeedLimitDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *labelGlobalSpeedIcon;
    QLabel *label;
    QSlider *sliderUploadLimit;
    QSpinBox *spinUploadLimit;
    QLabel *label_2;
    QSlider *sliderDownloadLimit;
    QSpinBox *spinDownloadLimit;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QLabel *labelAltGlobalSpeedIcon;
    QLabel *label_3;
    QSlider *sliderAltUploadLimit;
    QSpinBox *spinAltUploadLimit;
    QLabel *label_4;
    QSlider *sliderAltDownloadLimit;
    QSpinBox *spinAltDownloadLimit;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SpeedLimitDialog)
    {
        if (SpeedLimitDialog->objectName().isEmpty())
            SpeedLimitDialog->setObjectName("SpeedLimitDialog");
        SpeedLimitDialog->resize(481, 272);
        verticalLayout = new QVBoxLayout(SpeedLimitDialog);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(SpeedLimitDialog);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        labelGlobalSpeedIcon = new QLabel(groupBox);
        labelGlobalSpeedIcon->setObjectName("labelGlobalSpeedIcon");

        gridLayout->addWidget(labelGlobalSpeedIcon, 0, 0, 2, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 1, 1, 1);

        sliderUploadLimit = new QSlider(groupBox);
        sliderUploadLimit->setObjectName("sliderUploadLimit");
        sliderUploadLimit->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(sliderUploadLimit, 0, 2, 1, 1);

        spinUploadLimit = new QSpinBox(groupBox);
        spinUploadLimit->setObjectName("spinUploadLimit");
        spinUploadLimit->setMaximum(2000000);
        spinUploadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);

        gridLayout->addWidget(spinUploadLimit, 0, 3, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 1, 1, 1);

        sliderDownloadLimit = new QSlider(groupBox);
        sliderDownloadLimit->setObjectName("sliderDownloadLimit");
        sliderDownloadLimit->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(sliderDownloadLimit, 1, 2, 1, 1);

        spinDownloadLimit = new QSpinBox(groupBox);
        spinDownloadLimit->setObjectName("spinDownloadLimit");
        spinDownloadLimit->setMaximum(2000000);
        spinDownloadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);

        gridLayout->addWidget(spinDownloadLimit, 1, 3, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(SpeedLimitDialog);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        labelAltGlobalSpeedIcon = new QLabel(groupBox_2);
        labelAltGlobalSpeedIcon->setObjectName("labelAltGlobalSpeedIcon");

        gridLayout_2->addWidget(labelAltGlobalSpeedIcon, 0, 0, 2, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 1, 1, 1);

        sliderAltUploadLimit = new QSlider(groupBox_2);
        sliderAltUploadLimit->setObjectName("sliderAltUploadLimit");
        sliderAltUploadLimit->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_2->addWidget(sliderAltUploadLimit, 0, 2, 1, 1);

        spinAltUploadLimit = new QSpinBox(groupBox_2);
        spinAltUploadLimit->setObjectName("spinAltUploadLimit");
        spinAltUploadLimit->setMaximum(2000000);
        spinAltUploadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);

        gridLayout_2->addWidget(spinAltUploadLimit, 0, 3, 1, 1);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 1, 1, 1, 1);

        sliderAltDownloadLimit = new QSlider(groupBox_2);
        sliderAltDownloadLimit->setObjectName("sliderAltDownloadLimit");
        sliderAltDownloadLimit->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_2->addWidget(sliderAltDownloadLimit, 1, 2, 1, 1);

        spinAltDownloadLimit = new QSpinBox(groupBox_2);
        spinAltDownloadLimit->setObjectName("spinAltDownloadLimit");
        spinAltDownloadLimit->setMaximum(2000000);
        spinAltDownloadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);

        gridLayout_2->addWidget(spinAltDownloadLimit, 1, 3, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(SpeedLimitDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SpeedLimitDialog);

        QMetaObject::connectSlotsByName(SpeedLimitDialog);
    } // setupUi

    void retranslateUi(QDialog *SpeedLimitDialog)
    {
        SpeedLimitDialog->setWindowTitle(QCoreApplication::translate("SpeedLimitDialog", "Global Speed Limits", nullptr));
        groupBox->setTitle(QCoreApplication::translate("SpeedLimitDialog", "Speed limits", nullptr));
        labelGlobalSpeedIcon->setText(QString());
        label->setText(QCoreApplication::translate("SpeedLimitDialog", "Upload:", nullptr));
        spinUploadLimit->setSpecialValueText(QCoreApplication::translate("SpeedLimitDialog", "\342\210\236", nullptr));
        spinUploadLimit->setSuffix(QCoreApplication::translate("SpeedLimitDialog", " KiB/s", nullptr));
        label_2->setText(QCoreApplication::translate("SpeedLimitDialog", "Download:", nullptr));
        spinDownloadLimit->setSpecialValueText(QCoreApplication::translate("SpeedLimitDialog", "\342\210\236", nullptr));
        spinDownloadLimit->setSuffix(QCoreApplication::translate("SpeedLimitDialog", " KiB/s", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("SpeedLimitDialog", "Alternative speed limits", nullptr));
        labelAltGlobalSpeedIcon->setText(QString());
        label_3->setText(QCoreApplication::translate("SpeedLimitDialog", "Upload:", nullptr));
        spinAltUploadLimit->setSpecialValueText(QCoreApplication::translate("SpeedLimitDialog", "\342\210\236", nullptr));
        spinAltUploadLimit->setSuffix(QCoreApplication::translate("SpeedLimitDialog", " KiB/s", nullptr));
        label_4->setText(QCoreApplication::translate("SpeedLimitDialog", "Download:", nullptr));
        spinAltDownloadLimit->setSpecialValueText(QCoreApplication::translate("SpeedLimitDialog", "\342\210\236", nullptr));
        spinAltDownloadLimit->setSuffix(QCoreApplication::translate("SpeedLimitDialog", " KiB/s", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SpeedLimitDialog: public Ui_SpeedLimitDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SPEEDLIMITDIALOG_H
