/********************************************************************************
** Form generated from reading UI file 'rssfeeddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RSSFEEDDIALOG_H
#define UI_RSSFEEDDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_RSSFeedDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelFeedURL;
    QLineEdit *textFeedURL;
    QLabel *labelRefreshInterval;
    QSpinBox *spinRefreshInterval;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *RSSFeedDialog)
    {
        if (RSSFeedDialog->objectName().isEmpty())
            RSSFeedDialog->setObjectName("RSSFeedDialog");
        RSSFeedDialog->resize(555, 106);
        verticalLayout = new QVBoxLayout(RSSFeedDialog);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelFeedURL = new QLabel(RSSFeedDialog);
        labelFeedURL->setObjectName("labelFeedURL");

        gridLayout->addWidget(labelFeedURL, 0, 0, 1, 1);

        textFeedURL = new QLineEdit(RSSFeedDialog);
        textFeedURL->setObjectName("textFeedURL");

        gridLayout->addWidget(textFeedURL, 0, 1, 1, 1);

        labelRefreshInterval = new QLabel(RSSFeedDialog);
        labelRefreshInterval->setObjectName("labelRefreshInterval");

        gridLayout->addWidget(labelRefreshInterval, 1, 0, 1, 1);

        spinRefreshInterval = new QSpinBox(RSSFeedDialog);
        spinRefreshInterval->setObjectName("spinRefreshInterval");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(spinRefreshInterval->sizePolicy().hasHeightForWidth());
        spinRefreshInterval->setSizePolicy(sizePolicy);

        gridLayout->addWidget(spinRefreshInterval, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        buttonBox = new QDialogButtonBox(RSSFeedDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(RSSFeedDialog);

        QMetaObject::connectSlotsByName(RSSFeedDialog);
    } // setupUi

    void retranslateUi(QDialog *RSSFeedDialog)
    {
        RSSFeedDialog->setWindowTitle(QCoreApplication::translate("RSSFeedDialog", "RSS Feed Options", nullptr));
        labelFeedURL->setText(QCoreApplication::translate("RSSFeedDialog", "URL:", nullptr));
        labelRefreshInterval->setText(QCoreApplication::translate("RSSFeedDialog", "Refresh interval:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RSSFeedDialog: public Ui_RSSFeedDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_RSSFEEDDIALOG_H
