/****************************************************************************
** Meta object code from reading C++ file 'automatedrssdownloader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qBittorrent/src/gui/rss/automatedrssdownloader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'automatedrssdownloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22AutomatedRssDownloaderE_t {};
} // unnamed namespace

template <> constexpr inline auto AutomatedRssDownloader::qt_create_metaobjectdata<qt_meta_tag_ZN22AutomatedRssDownloaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AutomatedRssDownloader",
        "onAddRuleBtnClicked",
        "",
        "onRemoveRuleBtnClicked",
        "onExportBtnClicked",
        "onImportBtnClicked",
        "onRenameRuleBtnClicked",
        "handleRuleCheckStateChange",
        "QListWidgetItem*",
        "ruleItem",
        "handleFeedCheckStateChange",
        "feedItem",
        "displayRulesListMenu",
        "renameSelectedRule",
        "updateRuleDefinitionBox",
        "clearSelectedRuleDownloadedEpisodeList",
        "updateFieldsToolTips",
        "regex",
        "updateMustLineValidity",
        "updateMustNotLineValidity",
        "updateEpisodeFilterValidity",
        "handleRuleDefinitionChanged",
        "handleRuleAdded",
        "ruleName",
        "handleRuleRenamed",
        "oldRuleName",
        "handleRuleChanged",
        "handleRuleAboutToBeRemoved",
        "handleProcessingStateChanged",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onAddRuleBtnClicked'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRemoveRuleBtnClicked'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onExportBtnClicked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onImportBtnClicked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRenameRuleBtnClicked'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRuleCheckStateChange'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'handleFeedCheckStateChange'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 11 },
        }}),
        // Slot 'displayRulesListMenu'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameSelectedRule'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRuleDefinitionBox'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearSelectedRuleDownloadedEpisodeList'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFieldsToolTips'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'updateMustLineValidity'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMustNotLineValidity'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEpisodeFilterValidity'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRuleDefinitionChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRuleAdded'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'handleRuleRenamed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'handleRuleChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'handleRuleAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'handleProcessingStateChanged'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AutomatedRssDownloader, qt_meta_tag_ZN22AutomatedRssDownloaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AutomatedRssDownloader::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AutomatedRssDownloaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AutomatedRssDownloaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AutomatedRssDownloaderE_t>.metaTypes,
    nullptr
} };

void AutomatedRssDownloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AutomatedRssDownloader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAddRuleBtnClicked(); break;
        case 1: _t->onRemoveRuleBtnClicked(); break;
        case 2: _t->onExportBtnClicked(); break;
        case 3: _t->onImportBtnClicked(); break;
        case 4: _t->onRenameRuleBtnClicked(); break;
        case 5: _t->handleRuleCheckStateChange((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 6: _t->handleFeedCheckStateChange((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 7: _t->displayRulesListMenu(); break;
        case 8: _t->renameSelectedRule(); break;
        case 9: _t->updateRuleDefinitionBox(); break;
        case 10: _t->clearSelectedRuleDownloadedEpisodeList(); break;
        case 11: _t->updateFieldsToolTips((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->updateMustLineValidity(); break;
        case 13: _t->updateMustNotLineValidity(); break;
        case 14: _t->updateEpisodeFilterValidity(); break;
        case 15: _t->handleRuleDefinitionChanged(); break;
        case 16: _t->handleRuleAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->handleRuleRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->handleRuleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->handleRuleAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->handleProcessingStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *AutomatedRssDownloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AutomatedRssDownloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AutomatedRssDownloaderE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int AutomatedRssDownloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
