/********************************************************************************
** Form generated from reading UI file 'autoexpandabledialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOEXPANDABLEDIALOG_H
#define UI_AUTOEXPANDABLEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AutoExpandableDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *textLabel;
    QLineEdit *textEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AutoExpandableDialog)
    {
        if (AutoExpandableDialog->objectName().isEmpty())
            AutoExpandableDialog->setObjectName("AutoExpandableDialog");
        AutoExpandableDialog->resize(222, 105);
        verticalLayout = new QVBoxLayout(AutoExpandableDialog);
        verticalLayout->setObjectName("verticalLayout");
        textLabel = new QLabel(AutoExpandableDialog);
        textLabel->setObjectName("textLabel");

        verticalLayout->addWidget(textLabel);

        textEdit = new QLineEdit(AutoExpandableDialog);
        textEdit->setObjectName("textEdit");

        verticalLayout->addWidget(textEdit);

        buttonBox = new QDialogButtonBox(AutoExpandableDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AutoExpandableDialog);

        QMetaObject::connectSlotsByName(AutoExpandableDialog);
    } // setupUi

    void retranslateUi(QDialog *AutoExpandableDialog)
    {
        (void)AutoExpandableDialog;
    } // retranslateUi

};

namespace Ui {
    class AutoExpandableDialog: public Ui_AutoExpandableDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOEXPANDABLEDIALOG_H
